@@ -395,6 +395,11 @@ static gint number_playlist_second_status_cb(NumberData *number, const gchar *ke
 	return dsp_total_s;
 }
 
+static gint number_track_status_cb(NumberData *number, const gchar *key, gpointer data)
+{
+	return current_song_get_track();
+}
+
 /* items */
 
 static gint item_balance_status_cb(ItemData *item, const gchar *key, gpointer data)
@@ -872,6 +877,8 @@ void display_register_widgets(UIData *ui)
 	number_register_key("playlist_minute", ui, number_playlist_minute_status_cb, NULL);
 	number_register_key("playlist_second", ui, number_playlist_second_status_cb, NULL);
 
+	number_register_key("track", ui, number_track_status_cb, NULL);
+
 	/* items */
 
 	item_register_key("balance", ui, item_balance_status_cb, NULL);
@@ -1330,6 +1337,7 @@ void display_set_song_text_info(gint n, gint current)
 		text_set_text("title", main_window, current_song_get_title());
 		text_set_text("year", main_window, current_song_get_year());
 		text_set_text("comment", main_window, current_song_get_comment());
+		number_value_set("track", main_window, current_song_get_track());
 		}
 	else
 		{
@@ -1339,6 +1347,7 @@ void display_set_song_text_info(gint n, gint current)
 		text_set_text("title", main_window, playlist_get_title(n));
 		text_set_text("year", main_window, playlist_get_year(n));
 		text_set_text("comment", main_window, playlist_get_comment(n));
+		number_value_set("track", main_window, playlist_get_track(n));
 		}
 
 	text_set_autoscroll("title", main_window, title_scrolls_always);
