@@ -14,9 +14,6 @@
 #define DNDUTIL_H
 
 
-GList *uri_get_list(gchar *data);
-gchar *uri_create_text(GList *list, gint *t, gint plain_text);
-void uri_parse_encoded_chars(GList *list);
 void dnd_init(void);
 
 
