@@ -27,6 +27,7 @@ void windowmaker_setup_dock(void)
 	Display *dpy;
 	Window win;
 	XWMHints *hints;
+	XEvent event;
 
 	dpy = GDK_DISPLAY();
 	/* Get the X Window corresponding to mainwindow */
@@ -58,8 +59,10 @@ void windowmaker_setup_dock(void)
 	 * will not stay mapped because of the withdrawn initial state. */
 	XMapWindow(dpy, hints->window_group);
 	XFree(hints);
-	XFlush(dpy);
+
+	/* Wait until our window is mapped by WM */
+	do {
+		XWindowEvent(dpy, win, StructureNotifyMask, &event);
+	   } while (event.type != MapNotify);
 }
 
-
-
