@@ -1136,7 +1136,7 @@ static GtkWidget *mpg123_http_entry_setup(const gchar *path)
 	gtk_box_pack_start(GTK_BOX(vbox), entry, FALSE, FALSE, 0);
 	gtk_widget_show(entry);
 
-	gtk_object_set_data(GTK_OBJECT(vbox), "http_URL", entry);
+	g_object_set_data(G_OBJECT(vbox), "http_URL", entry);
 
 	return vbox;
 }
@@ -1153,14 +1153,14 @@ static GtkWidget *mpg123_http_edit(SongData *sd)
 	gtk_box_pack_start(GTK_BOX(vbox), entry, FALSE, FALSE, 0);
 	gtk_widget_show(entry);
 
-	gtk_object_set_data(GTK_OBJECT(vbox), "http_URL", entry);
+	g_object_set_data(G_OBJECT(vbox), "http_URL", entry);
 
 	return vbox;
 }
 
 static gchar *mpg123_http_get_path(GtkWidget *widget)
 {
-	GtkWidget *entry = gtk_object_get_data(GTK_OBJECT(widget), "http_URL");
+	GtkWidget *entry = g_object_get_data(G_OBJECT(widget), "http_URL");
 
 	if (!entry) return NULL;
 
