@@ -55,6 +55,7 @@ struct _ID3_Data
 	gchar *comment;
 	guint8 genre;
 	gchar *genre_description;
+	guint8 track;	/* id3 v1.1 spec */
 };
 
 extern gint mpg123_enabled;
@@ -103,7 +104,7 @@ Mpg_Data *get_mpg_header_info(const gchar *path);
 gchar* get_id3_genre(gint g);
 ID3_Data *get_id3_tag(const gchar *path);
 gint set_id3_tag(const gchar *path, const gchar *title, const gchar *artist, const gchar *album,
-		 const gchar *year, const gchar *comment, guint8 genre);
+		 const gchar *year, const gchar *comment, guint8 genre, guint8 track);
 void free_id3_tag(ID3_Data *d);
 
 /*
