@@ -153,8 +153,9 @@ static GtkWidget *checkbox_new(gchar *text, gint n, gint *c_n)
 
 	*c_n = n;
 	button = gtk_check_button_new_with_label(text);
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON(button), n);
-	gtk_signal_connect (GTK_OBJECT(button), "clicked", (GtkSignalFunc)checkbox_cb, c_n);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), n);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(checkbox_cb), c_n);
 
 	return button;
 }
@@ -244,8 +245,7 @@ GtkWidget *mpg123_config_init(void)
 	GtkWidget *tabcomp;
 
 	mpg123_vbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_border_width (GTK_CONTAINER (mpg123_vbox), 5);
-
+	gtk_container_set_border_width(GTK_CONTAINER(mpg123_vbox), 5);
 
 	button = checkbox_new(_("Use ID3 tags when available"),
 		 mpg123_read_id3_tags, &c_mpg123_read_id3_tags);
@@ -264,14 +264,13 @@ GtkWidget *mpg123_config_init(void)
 	c_mpg123_buffer = mpg123_buffer;
 	mpg123_buffer_adjustment = (GtkAdjustment *)gtk_adjustment_new ((float)c_mpg123_buffer,0.0,8192.0,8.0,8.0,8.0);
 	mpg123_buffer_spinbutton = gtk_spin_button_new (mpg123_buffer_adjustment, (float)8, 0);
-	gtk_widget_set_usize(mpg123_buffer_spinbutton,60,-1);
 	gtk_box_pack_start(GTK_BOX(hbox), mpg123_buffer_spinbutton, FALSE, FALSE, 0);
 	gtk_widget_show(mpg123_buffer_spinbutton);
 
 	/* downsampling */
 
 	frame = gtk_frame_new(_("Downsampling"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(mpg123_vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
@@ -281,20 +280,34 @@ GtkWidget *mpg123_config_init(void)
 
 	c_mpg123_downsample = mpg123_downsample;
 	radiobutton = gtk_radio_button_new_with_label (NULL,_("Auto or(1:1)"));
-	if (c_mpg123_downsample == MPG123_DOWNSAMPLE_AUTO) gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON(radiobutton), 1);
-	gtk_signal_connect (GTK_OBJECT(radiobutton),"clicked",(GtkSignalFunc) downsample_auto_selected, NULL);
+	if (c_mpg123_downsample == MPG123_DOWNSAMPLE_AUTO)
+		{
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radiobutton), TRUE);
+		}
+	g_signal_connect(G_OBJECT(radiobutton), "clicked",
+			 G_CALLBACK(downsample_auto_selected), NULL);
 	gtk_box_pack_start(GTK_BOX(vbox1), radiobutton, FALSE, FALSE, 0);
 	gtk_widget_show(radiobutton);
 
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group(GTK_RADIO_BUTTON(radiobutton)),_("22Khz (2:1)"));
-	if (c_mpg123_downsample == MPG123_DOWNSAMPLE_22) gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON(button), 1);
-	gtk_signal_connect (GTK_OBJECT(button),"clicked",(GtkSignalFunc) downsample_22_selected, NULL);
+	button = gtk_radio_button_new_with_label(gtk_radio_button_get_group(GTK_RADIO_BUTTON(radiobutton)),
+						 _("22Khz (2:1)"));
+	if (c_mpg123_downsample == MPG123_DOWNSAMPLE_22)
+		{
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+		}
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(downsample_22_selected), NULL);
 	gtk_box_pack_start(GTK_BOX(vbox1), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group(GTK_RADIO_BUTTON(radiobutton)),_("11Khz (4:1)"));
-	if (c_mpg123_downsample == MPG123_DOWNSAMPLE_11) gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON(button), 1);
-	gtk_signal_connect (GTK_OBJECT(button),"clicked",(GtkSignalFunc) downsample_11_selected, NULL);
+	button = gtk_radio_button_new_with_label(gtk_radio_button_get_group(GTK_RADIO_BUTTON(radiobutton)),
+						 _("11Khz (4:1)"));
+	if (c_mpg123_downsample == MPG123_DOWNSAMPLE_11)
+		{
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+		}
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(downsample_11_selected), NULL);
 	gtk_box_pack_start(GTK_BOX(vbox1), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 
@@ -302,16 +315,20 @@ GtkWidget *mpg123_config_init(void)
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group(GTK_RADIO_BUTTON(radiobutton)),_("Custom (bits/sec):"));
-	if (c_mpg123_downsample == MPG123_DOWNSAMPLE_CUSTOM) gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON(button), 1);
-	gtk_signal_connect (GTK_OBJECT(button),"clicked",(GtkSignalFunc) downsample_custom_selected, NULL);
+	button = gtk_radio_button_new_with_label(gtk_radio_button_get_group(GTK_RADIO_BUTTON(radiobutton)),
+						 _("Custom (bits/sec):"));
+	if (c_mpg123_downsample == MPG123_DOWNSAMPLE_CUSTOM)
+		{
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+		}
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(downsample_custom_selected), NULL);
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 
 	c_mpg123_custom_sample_size = mpg123_custom_sample_size;
 	mpg123_sample_adjustment = (GtkAdjustment *)gtk_adjustment_new ((float)c_mpg123_custom_sample_size,8000.0,49152.0,8.0,8.0,8.0);
 	mpg123_sample_spinbutton = gtk_spin_button_new (mpg123_sample_adjustment, (float)8, 0);
-	gtk_widget_set_usize(mpg123_sample_spinbutton,60,-1);
 	gtk_box_pack_start(GTK_BOX(hbox), mpg123_sample_spinbutton, FALSE, FALSE, 0);
 	gtk_widget_show(mpg123_sample_spinbutton);
 
@@ -334,7 +351,7 @@ GtkWidget *mpg123_config_init(void)
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 
-	mpg123_device_entry = gtk_entry_new_with_max_length(128);
+	mpg123_device_entry = gtk_entry_new();
 	if (mpg123_device)
 		{
 		gtk_entry_set_text(GTK_ENTRY(mpg123_device_entry), mpg123_device);
@@ -353,7 +370,7 @@ GtkWidget *mpg123_config_init(void)
 	gtk_widget_show(button);
 
 	frame = gtk_frame_new(_("Output to Wave"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(mpg123_vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
@@ -376,19 +393,20 @@ GtkWidget *mpg123_config_init(void)
 
 	c_mpg123_to_raw = mpg123_to_raw;
 	radiobutton = gtk_radio_button_new_with_label (NULL,_("Wave (.wav)"));
-	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(radiobutton), !c_mpg123_to_raw);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radiobutton), !c_mpg123_to_raw);
 	gtk_box_pack_start(GTK_BOX(hbox), radiobutton, FALSE, FALSE, 0);
 	gtk_widget_show(radiobutton);
 
-	button = gtk_radio_button_new_with_label(gtk_radio_button_group(GTK_RADIO_BUTTON(radiobutton)), _("CDR raw (.raw)"));
-	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(button), c_mpg123_to_raw);
+	button = gtk_radio_button_new_with_label(gtk_radio_button_get_group(GTK_RADIO_BUTTON(radiobutton)),
+						  _("CDR raw (.raw)"));
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), c_mpg123_to_raw);
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 
-	gtk_signal_connect(GTK_OBJECT(radiobutton), "clicked",
-			   GTK_SIGNAL_FUNC(output_type_cb), GINT_TO_POINTER(FALSE));
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			   GTK_SIGNAL_FUNC(output_type_cb), GINT_TO_POINTER(TRUE));
+	g_signal_connect(G_OBJECT(radiobutton), "clicked",
+			 G_CALLBACK(output_type_cb), GINT_TO_POINTER(FALSE));
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(output_type_cb), GINT_TO_POINTER(TRUE));
 
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
@@ -405,7 +423,7 @@ GtkWidget *mpg123_config_init(void)
 	gtk_widget_show(tabcomp);
 
 	hbox = gtk_hbox_new (FALSE, 5);
-	gtk_container_border_width (GTK_CONTAINER(hbox), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
 	gtk_box_pack_start(GTK_BOX(mpg123_vbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
@@ -413,7 +431,7 @@ GtkWidget *mpg123_config_init(void)
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
-	mpg123_extra_options_entry = gtk_entry_new_with_max_length(255);
+	mpg123_extra_options_entry = gtk_entry_new();
 	if (mpg123_extra_options)
 		{
 		gtk_entry_set_text(GTK_ENTRY(mpg123_extra_options_entry), mpg123_extra_options);
