@@ -476,6 +476,8 @@ gint ogg123_comment_set(const gchar *path, GList *comments)
 		{
 		GenericDialog *gd;
 		GtkWidget *tw;
+		GtkTextIter iter;
+		GtkTextBuffer *buffer;
 		gchar *msg;
 
 		msg = g_strdup_printf(_("Failed to set comments for file:\n%s"), path);
@@ -485,18 +487,24 @@ gint ogg123_comment_set(const gchar *path, GList *comments)
 
 	        generic_dialog_add(gd, _("Ok"), NULL, TRUE);
 
-		tw = gtk_text_new(NULL, NULL);
-		gtk_widget_set_usize(tw, 400, 200);
-		gtk_text_set_editable(GTK_TEXT(tw), FALSE);
+		tw = gtk_text_view_new();
+		gtk_widget_set_size_request(tw, 400, 200);
+		gtk_text_view_set_editable(GTK_TEXT_VIEW(tw), FALSE);
 		gtk_box_pack_start(GTK_BOX(gd->vbox), tw, TRUE, TRUE, 5);
 		gtk_widget_show(tw);
 
+		buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(tw));
+		gtk_text_buffer_create_tag(buffer, "monospace",
+					   "family", "monospace", NULL);
+		gtk_text_buffer_get_iter_at_offset(buffer, &iter, 0);
+
 		work = errlist;
 		while (work)
 			{
 			gchar *txt = work->data;
 
-			gtk_text_insert(GTK_TEXT(tw), NULL, NULL, NULL, txt, strlen(txt));
+			gtk_text_buffer_insert_with_tags_by_name(buffer, &iter, txt, -1,
+								 "monospace", NULL);
 			work = work->next;
 			}
 
