@@ -25,6 +25,7 @@ struct _OGGInfo
 	gint bitrate_nominal;
 	gint length;		/* seconds */
 	gint bytes;		/* file size */
+	gchar *vendor;
 };
 
 
@@ -42,6 +43,7 @@ const gchar *ogg123_get_device(gint device);
 GList *ogg123_get_device_list(void);
 
 OGGInfo *ogg123_info_get(const gchar *path);
+void ogg123_info_free(OGGInfo *info);
 GList *ogg123_comment_get(const gchar *path);
 const gchar *ogg123_comment_value(GList *list, const gchar *key);
 gint ogg123_comment_set(const gchar *path, GList *comments);
