@@ -566,12 +566,12 @@ static GtkWidget *radio_info_window(const gchar *file)
 	gtk_widget_show(label);
 
 	frame = gtk_frame_new(_("Song info"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
 	vbox1 = gtk_vbox_new(FALSE, 0);
-	gtk_container_border_width (GTK_CONTAINER (vbox1), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox1), 5);
 	gtk_container_add(GTK_CONTAINER(frame), vbox1);
 	gtk_widget_show(vbox1);
 
@@ -666,12 +666,12 @@ static gint radio_scan_cb(gpointer data)
 
 	radio_real_set_freq(radio_scan_point);
 
-	gtk_progress_bar_update(GTK_PROGRESS_BAR(progress),
-				(radio_scan_point - radio_limit_lower) / (radio_limit_upper - radio_limit_lower));
+	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(progress),
+		(radio_scan_point - radio_limit_lower) / (radio_limit_upper - radio_limit_lower));
 
-	label = gtk_object_get_data(GTK_OBJECT(progress), "current_station");
+	label = g_object_get_data(G_OBJECT(progress), "current_station");
 	buf = g_strdup_printf("%.2f", radio_scan_point);
-	gtk_label_set(GTK_LABEL(label), buf);
+	gtk_label_set_text(GTK_LABEL(label), buf);
 	g_free(buf);
 
 
@@ -702,7 +702,7 @@ static gint radio_scan_begin(void)
 	label = gtk_label_new("");
 	gtk_box_pack_start(GTK_BOX(gd->vbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
-	gtk_object_set_data(GTK_OBJECT(progress), "current_station", label);
+	g_object_set_data(G_OBJECT(progress), "current_station", label);
 
 	gd->data = progress;
 
@@ -771,7 +771,7 @@ static GtkWidget *radio_entry_new(double freq, const gchar *title, gint scan)
         gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
         gtk_widget_show(label);
 
-	entry = gtk_entry_new_with_max_length(128);
+	entry = gtk_entry_new();
 	if (title) gtk_entry_set_text(GTK_ENTRY(entry), title);
 	gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
 	gtk_widget_show(entry);
@@ -785,16 +785,16 @@ static GtkWidget *radio_entry_new(double freq, const gchar *title, gint scan)
         	gtk_widget_show(hbox);
 
 		button = gtk_button_new_with_label(_("Auto scan"));
-		gtk_signal_connect(GTK_OBJECT(button), "clicked",
-				   GTK_SIGNAL_FUNC(radio_entry_scan_cb), NULL);
+		g_signal_connect(G_OBJECT(button), "clicked",
+				 G_CALLBACK(radio_entry_scan_cb), NULL);
 		gtk_box_pack_end(GTK_BOX(hbox), button, FALSE, FALSE, 0);
 		gtk_widget_show(button);
 
 		if (!radio_enabled) gtk_widget_set_sensitive(button, FALSE);
 		}
 
-	gtk_object_set_data(GTK_OBJECT(vbox), "radio_station", spin);
-	gtk_object_set_data(GTK_OBJECT(vbox), "radio_station_title", entry);
+	g_object_set_data(G_OBJECT(vbox), "radio_station", spin);
+	g_object_set_data(G_OBJECT(vbox), "radio_station_title", entry);
 
         return vbox;
 }
@@ -836,17 +836,17 @@ static gchar *radio_get_path(GtkWidget *widget)
 	GtkWidget *entry;
 	const gchar *title = NULL;
 
-	spin = gtk_object_get_data(GTK_OBJECT(widget), "radio_station");
+	spin = g_object_get_data(G_OBJECT(widget), "radio_station");
 	if (spin)
 		{
-		freq = (double)gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(spin));
+		freq = gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin));
 		}
 	else
 		{
 		freq = 0.0;
 		}
 
-	entry = gtk_object_get_data(GTK_OBJECT(widget), "radio_station_title");
+	entry = g_object_get_data(G_OBJECT(widget), "radio_station_title");
 	if (entry) title = gtk_entry_get_text(GTK_ENTRY(entry));
 
 	return radio_freq_to_path(freq, title);
