@@ -152,7 +152,7 @@ static gint xmp_real_seconds(SongData *sd, gint position)
 static void xmp_time_restart(void)
 {
 	xmp_seconds_offset = seconds;
-	xmp_start_time = gdk_time_get() / 1000;
+	xmp_start_time = elapsed_run_time();;
 }
 
 static void xmp_time_reset(SongData *sd, gint position)
@@ -185,7 +185,7 @@ static void xmp_time_do(void)
 
 	if (!xmp_current_sd) return;
 
-	passed = (gdk_time_get() / 1000) - xmp_start_time;
+	passed = elapsed_run_time() - xmp_start_time;
 	seconds = xmp_seconds_offset + passed;
 	if (xmp_current_sd->length > 0) seconds_remaining = xmp_current_sd->length - seconds;
 
