@@ -57,10 +57,13 @@ static gint pid_lock_file_create(void)
 {
 	FILE *f;
 	gchar *lock_file;
+	gchar *pathl;
 
 	lock_file = g_strconcat(homedir(), "/", GQMPEG_FILE_IPC_LOCK, NULL);
 
-	f = fopen(lock_file, "w");
+	pathl = path_from_utf8(lock_file);
+	f = fopen(pathl, "w");
+	g_free(pathl);
 	if (!f)
 		{
 		printf(_("error opening file for write %s\n"), lock_file);
@@ -83,7 +86,11 @@ static void pid_lock_file_destroy(void)
 	lock_file = g_strconcat(homedir(), "/", GQMPEG_FILE_IPC_LOCK, NULL);
 	if (isfile(lock_file))
 		{
-		unlink(lock_file);
+		gchar *pathl;
+
+		pathl = path_from_utf8(lock_file);
+		unlink(pathl);
+		g_free(pathl);
 		}
 
 	g_free(lock_file);
@@ -93,12 +100,15 @@ static gint pid_lock_file_locked(void)
 {
 	FILE *f;
 	gchar *lock_file;
+	gchar *pathl;
 	gchar buf[64];
         pid_t pid_v = -1;
 
 	lock_file = g_strconcat(homedir(), "/", GQMPEG_FILE_IPC_LOCK, NULL);
 
-        f = fopen(lock_file, "r");
+	pathl = path_from_utf8(lock_file);
+        f = fopen(pathl, "r");
+	g_free(pathl);
 	g_free(lock_file);
         if(!f) return FALSE;
 
@@ -122,12 +132,21 @@ void ipc_send(gchar *command)
 
 	if (ipc_file)
 		{
-		f = fopen(ipc_file, "w");
+		gchar *pathl;
+
+		pathl = path_from_utf8(ipc_file);
+		f = fopen(pathl, "w");
+		g_free(pathl);
 		}
 	else
 		{
-		gchar *path = g_strconcat(homedir(), "/.gqmpeg/command", NULL);
-		f = fopen(path, "w"); /* blocking, huh ? */
+		gchar *path;
+		gchar *pathl;
+
+		path = g_strconcat(homedir(), "/.gqmpeg/command", NULL);
+		pathl = path_from_utf8(path);
+		f = fopen(pathl, "w"); /* blocking, huh ? */
+		g_free(pathl);
 		g_free(path);
 		}
 
@@ -301,26 +320,26 @@ static gint ipc_read_data(gpointer data)
 			}
 		else if (!strncmp(i_buf, "help", 4))
 			{
-			printf(_("available ipc commands:\n"));
-			printf(_("play, pause, stop, next, prev, quit\n"));
-			printf(_("seek [+|-]n                seek n seconds into file, or +/-n\n"));
-			printf(_("pladd {\"file\"|file}        add file to playlist\n"));
-			printf(_("pladd_play {\"file\"|file}   add file to playlist and play it\n"));
-			printf(_("plremove {\"file\"|file}     remove file from playlist\n"));
-			printf(_("plclr                      clear playlist\n"));
-			printf(_("plload {playlist}          load playlist\n"));
-			printf(_("plappend {playlist}        append playlist\n"));
-			printf(_("play_file {\"file\"|file}    play file, do not add to playlist\n"));
-			printf(_("                           or, if playlist, load playlist\n"));
-			printf(_("   file is a path or http://server:port\n"));
-			printf(_("skin \"file\"                set skin\n"));
-			printf(_("volume [+|-]n              set volume to n (0 - 100) or +/-n\n"));
-			printf(_("getting a status printed to a file is also possible:\n"));
-			printf(_("status_add \"key\" \"file\"    start status printing to file\n"));
-			printf(_("status_rm \"key\"|\"file\"     stop printing to file or key\n"));
-			printf(_("these commands open file requestors, windows, etc.\n"));
-			printf(_("show_playlist\n"));
-			printf(_("show_open_file, show_open_custom, show_open_playlist\n"));
+			print_term(_("available ipc commands:\n"));
+			print_term(_("play, pause, stop, next, prev, quit\n"));
+			print_term(_("seek [+|-]n                seek n seconds into file, or +/-n\n"));
+			print_term(_("pladd {\"file\"|file}        add file to playlist\n"));
+			print_term(_("pladd_play {\"file\"|file}   add file to playlist and play it\n"));
+			print_term(_("plremove {\"file\"|file}     remove file from playlist\n"));
+			print_term(_("plclr                      clear playlist\n"));
+			print_term(_("plload {playlist}          load playlist\n"));
+			print_term(_("plappend {playlist}        append playlist\n"));
+			print_term(_("play_file {\"file\"|file}    play file, do not add to playlist\n"));
+			print_term(_("                           or, if playlist, load playlist\n"));
+			print_term(_("   file is a path or http://server:port\n"));
+			print_term(_("skin \"file\"                set skin\n"));
+			print_term(_("volume [+|-]n              set volume to n (0 - 100) or +/-n\n"));
+			print_term(_("getting a status printed to a file is also possible:\n"));
+			print_term(_("status_add \"key\" \"file\"    start status printing to file\n"));
+			print_term(_("status_rm \"key\"|\"file\"     stop printing to file or key\n"));
+			print_term(_("these commands open file requestors, windows, etc.\n"));
+			print_term(_("show_playlist\n"));
+			print_term(_("show_open_file, show_open_custom, show_open_playlist\n"));
 			}
 		else
 			{
@@ -338,6 +357,8 @@ static gint ipc_read_data(gpointer data)
 
 void ipc_on(void)
 {
+	gchar *pathl;
+
 	if (ipc_file_id || ipc_cb_id > -1) return;
 
 	if (pid_lock_file_locked())
@@ -350,14 +371,18 @@ void ipc_on(void)
 		{
 		ipc_file = g_strconcat(homedir(), "/", GQMPEG_FILE_IPC_COMMAND, NULL);
 		}
-	unlink(ipc_file);
-	if (mkfifo(ipc_file, S_IRUSR | S_IWUSR) != 0)
+
+	pathl = path_from_utf8(ipc_file);
+	unlink(pathl);
+	if (mkfifo(pathl, S_IRUSR | S_IWUSR) != 0)
 		{
 		printf(_("Failed to mkfifo for %s\n"), ipc_file);
+		g_free(pathl);
 		return;
 		}
 
-	ipc_fd_id = open(ipc_file, O_RDWR | O_NONBLOCK);
+	ipc_fd_id = open(pathl, O_RDWR | O_NONBLOCK);
+	g_free(pathl);
 
 	if (ipc_fd_id == -1)
 		{
@@ -396,7 +421,12 @@ void ipc_off(void)
 
 	if (ipc_file)
 		{
-		unlink(ipc_file);
+		gchar *pathl;
+
+		pathl = path_from_utf8(ipc_file);
+		unlink(pathl);
+		g_free(pathl);
+
 		g_free(ipc_file);
 		ipc_file = NULL;
 		pid_lock_file_destroy();
