@@ -28,6 +28,7 @@
 #include "ui2_editor.h"
 #include "ui2_main.h"
 #include "ui2_util.h"
+#include "ui_bookmark.h"
 #include "ui_fileops.h"
 #include "ui_help.h"
 #include "ui_tabcomp.h"
@@ -70,6 +71,35 @@ gint convert_chars(gchar *text, gchar s, gchar d)
 	return c;
 }
 
+/*
+ * Returns time in thousandths (1/1000) of a second since very first call
+ * it is also called once in startup in main to initialize the zero point,
+ * so this will return time since app start as well.
+ */
+guint32 elapsed_run_time(void)
+{
+	static GTimeVal *start_tv = NULL;
+	GTimeVal tv;
+
+	g_get_current_time(&tv);
+
+	if (!start_tv)
+		{
+		start_tv = g_new0(GTimeVal, 1);
+		start_tv->tv_sec = tv.tv_sec;
+		start_tv->tv_usec = tv.tv_usec;
+		}
+
+	if (start_tv->tv_usec > tv.tv_usec)
+		{
+		tv.tv_usec += G_USEC_PER_SEC;
+		tv.tv_sec--;
+		}
+
+	return (guint32)((tv.tv_sec - start_tv->tv_sec) * 1000 +
+			 ((tv.tv_usec - start_tv->tv_usec) * 1000 / G_USEC_PER_SEC) );
+}
+
 /*
  *-----------------------------------------------------------------------------
  * load a preset, smartly (public)
@@ -679,6 +709,10 @@ static void ipc_status(void)
 	tmp_file = unique_filename(buf, NULL, NULL, FALSE);
 	g_free(buf);
 
+	buf = tmp_file;
+	tmp_file = path_from_utf8(buf);
+	g_free(buf);
+
 	if (!tmp_file || mkfifo(tmp_file, S_IRUSR | S_IWUSR) != 0)
 		{
 		printf("unable to create fifo: %s\n", tmp_file);
@@ -770,7 +804,7 @@ static void check_for_home_path(gchar *path)
 	if (!isdir(buf))
 		{
 		printf(_("Creating GQmpeg dir:%s\n"), buf);
-		if (mkdir (buf, 0755) < 0)
+		if (!mkdir_utf8(buf, 0755))
 			{
 			printf(_("Could not create dir:%s\n"), buf);
 			}
@@ -855,44 +889,44 @@ void help_window_show(const gchar *key)
 
 	help_window = help_window_new(_("Help - GQmpeg"), "GQmpeg", "help",
 				      GQMPEG_SKINDIR "/README", key);
-	gtk_signal_connect(GTK_OBJECT(help_window), "destroy",
-			   GTK_SIGNAL_FUNC(help_window_destroy_cb), NULL);
+	g_signal_connect(G_OBJECT(help_window), "destroy",
+			 G_CALLBACK(help_window_destroy_cb), NULL);
 }
 
 static void show_help(void)
 {
 	printf("GQmpeg %s\n", VERSION);
-	printf(_("usage: gqmpeg [option(s)] [file(s) | ipc_command(s)]\n"));
-	printf(_(" standard options:\n"));
-	printf(_("  --skin:<skindir>             load specified skin\n"));
-	printf(_("  --dock                       enable docking behavior\n"));
-	printf(_("  --dockwm                     enable Window Maker docking\n"));
-	printf(_("  --skinhelp                   print mouse event coordinates\n"));
-	printf(_("  --debug                      enable debug output\n"));
-	printf(_("  -h,  --help                  displays this message\n"));
-	printf(_("  -v,  --version               shows version info\n"));
-	printf(_("  --blank                      start with empty playlist\n"));
-	printf(_("  --geometry [+|-]xxx[+|-]yyy  specify window position\n"));
-	printf(_("  --crack                      reserved\n"));
-	printf(_(" available ipc_commands:\n"));
-	printf(_("  -p          --play\n"));
-	printf(_("  -s          --stop\n"));
-	printf(_("  -n          --next\n"));
-	printf(_("  -b          --back\n"));
-	printf(_("  -ps         --pause\n"));
-	printf(_("  -pladd      --playlist_add <f>[..]    add file to playlist\n"));
-	printf(_("  -pladdplay  --playlist_add_play <f>   add file to playlist and play it\n"));
-	printf(_("  -plrm       --playlist_remove <f>[..] remove file from playlist\n"));
-	printf(_("  -plclr      --playlist_clear          clear playlist\n"));
-	printf(_("  -pl         --playlist <f>            load playlist\n"));
-	printf(_("  -plappend   --playlist_append <f>[..] append playlist\n"));
-	printf(_("  -f          --file <f>[..]            play file, do not add to playlist\n"));
-	printf(_("                                        or, if playlist, load playlist\n"));
-	printf(_("  -q          --quit                    tell GQmpeg to quit\n"));
-	printf(_("              --skin_set <f>            set skin\n"));
-	printf(_("              --status                  print current status, song, time\n"));
-	printf(_("              --volume [+|-]#           set, or increment volume (0-100)\n"));
-	printf(_("              * files can also be of the format http://server:port\n"));
+	print_term(_("usage: gqmpeg [option(s)] [file(s) | ipc_command(s)]\n"));
+	print_term(_(" standard options:\n"));
+	print_term(_("  --skin:<skindir>             load specified skin\n"));
+	print_term(_("  --dock                       enable docking behavior\n"));
+	print_term(_("  --dockwm                     enable Window Maker docking\n"));
+	print_term(_("  --skinhelp                   print mouse event coordinates\n"));
+	print_term(_("  --debug                      enable debug output\n"));
+	print_term(_("  -h,  --help                  displays this message\n"));
+	print_term(_("  -v,  --version               shows version info\n"));
+	print_term(_("  --blank                      start with empty playlist\n"));
+	print_term(_("  --geometry [+|-]xxx[+|-]yyy  specify window position\n"));
+	print_term(_("  --crack                      reserved\n"));
+	print_term(_(" available ipc_commands:\n"));
+	print_term(_("  -p          --play\n"));
+	print_term(_("  -s          --stop\n"));
+	print_term(_("  -n          --next\n"));
+	print_term(_("  -b          --back\n"));
+	print_term(_("  -ps         --pause\n"));
+	print_term(_("  -pladd      --playlist_add <f>[..]    add file to playlist\n"));
+	print_term(_("  -pladdplay  --playlist_add_play <f>   add file to playlist and play it\n"));
+	print_term(_("  -plrm       --playlist_remove <f>[..] remove file from playlist\n"));
+	print_term(_("  -plclr      --playlist_clear          clear playlist\n"));
+	print_term(_("  -pl         --playlist <f>            load playlist\n"));
+	print_term(_("  -plappend   --playlist_append <f>[..] append playlist\n"));
+	print_term(_("  -f          --file <f>[..]            play file, do not add to playlist\n"));
+	print_term(_("                                        or, if playlist, load playlist\n"));
+	print_term(_("  -q          --quit                    tell GQmpeg to quit\n"));
+	print_term(_("              --skin_set <f>            set skin\n"));
+	print_term(_("              --status                  print current status, song, time\n"));
+	print_term(_("              --volume [+|-]#           set, or increment volume (0-100)\n"));
+	print_term(_("              * files can also be of the format http://server:port\n"));
 }
 
 /*
@@ -1146,12 +1180,6 @@ int main (int argc, char *argv[])
 
 	gdk_rgb_init();
 
-	/* push the correct color depths to gtk, (for 8-bit psuedo color displays)
-	 * they should be popped, too, I guess...
-	 */
-	gtk_widget_push_visual(gdk_rgb_get_visual());
-	gtk_widget_push_colormap(gdk_rgb_get_cmap());
-
 	buf = g_strconcat(homedir(), "/.gqmpeg/gtkrc", NULL);
 	if (isfile(buf)) gtk_rc_parse(buf);
 	g_free(buf);
@@ -1270,6 +1298,9 @@ int main (int argc, char *argv[])
 		filelist_refresh();
 		}
 
+	/* start our timer */
+	elapsed_run_time();
+
 	/* set up mixer */
 
 	if (!mixer_command) mixer_command = g_strdup("xmixer");
