@@ -36,7 +36,7 @@
 #endif
 
 #ifdef __FreeBSD__
-#include <machine/soundcard.h>
+#include <sys/soundcard.h>
 #endif
 
 #if defined(__NetBSD__) || defined(__OpenBSD__)
