@@ -94,11 +94,14 @@ ID3_Data *get_id3_tag(const gchar *path)
 	FILE *f;
 	gchar buf[130];
 	gchar *ptr;
+	gchar *pathl;
 
 	if (filesize(path) < 129)
 		return NULL;
 
-	f = fopen(path,"r");
+	pathl = path_from_utf8(path);
+	f = fopen(pathl,"r");
+	g_free(pathl);
         if (!f)
                 {
                 printf(_("error opening file for tag: %s\n"), path);
@@ -162,8 +165,11 @@ gint set_id3_tag(const gchar *path, const gchar *title, const gchar *artist, con
 	FILE *f;
 	gchar buf[130];
 	gint i;
+	gchar *pathl;
 
-	f = fopen(path,"r+");
+	pathl = path_from_utf8(path);
+	f = fopen(pathl,"r+");
+	g_free(pathl);
         if (!f)
                 {
                 printf(_("error opening file for tag: %s\n"), path);
