@@ -85,7 +85,7 @@ GList *player_modules_config_init(void)
 			}
 		if (widget)
 			{
-			gtk_object_set_user_data(GTK_OBJECT(widget), imd->title);
+			g_object_set_data(G_OBJECT(widget), "title", imd->title);
 			list = g_list_append(list, widget);
 			}
 		work = work->next;
