@@ -45,8 +45,6 @@ static gint shuffle_list_get_first(void);
 static gint shuffle_list_get_next(gint p);
 static gint shuffle_list_get_prev(gint p);
 
-static void playlist_append_dir_func(const gchar *d, gint recursive);
-
 static void real_playlist_init(void);
 static void real_playlist_clear(void);
 static SongData *real_playlist_add_item(const gchar *path, gint read_info);
@@ -543,7 +541,8 @@ static gint playlist_load_idle_cb(gpointer data)
 		return FALSE;
 		}
 
-	new_time = gdk_time_get();
+	new_time = elapsed_run_time();
+
 	if (new_time - playlist_load_timer > DISPLAY_LOADING_ANIMATE_TIME)
 		{
 		playlist_load_timer = new_time;
@@ -575,6 +574,7 @@ static gint playlist_load_idle_cb(gpointer data)
 gint playlist_load_start(const gchar *fn, gint append, gint strict, gint parse_background, gint info_background)
 {
 	gchar s_buf[1025];
+	gchar *pathl;
 
 	if (playlist_load_idle_id || playlist_load_fp)
 		{
@@ -591,7 +591,9 @@ gint playlist_load_start(const gchar *fn, gint append, gint strict, gint parse_b
 	playlist_load_set_next_title(NULL);
 	playlist_load_set_next_comment(NULL);
 
-	playlist_load_fp = fopen (playlist_load_path, "r");
+	pathl = path_from_utf8(playlist_load_path);
+	playlist_load_fp = fopen(pathl, "r");
+	g_free(pathl);
 	if (!playlist_load_fp)
 		{
 		/* file open failed */
@@ -674,7 +676,8 @@ gint playlist_load_start(const gchar *fn, gint append, gint strict, gint parse_b
 			display_set_song_count(playlist_count);
 
 			display_set_loading(TRUE);
-			playlist_load_timer = gdk_time_get();
+
+			playlist_load_timer = elapsed_run_time();
 			}
 		else
 			{
@@ -743,10 +746,13 @@ gint playlist_load_from_file(const gchar *path, gint append, gint strict, gint s
 
 gint playlist_save(const gchar *fn)
 {
+	gchar *pathl;
 	int i;
 	FILE *f;
 
-	f = fopen (fn,"w");
+	pathl = path_from_utf8(fn);
+	f = fopen (pathl, "w");
+	g_free(pathl);
 	if (!f)
 		{
 		/* file open failed */
@@ -805,13 +811,13 @@ gint playlist_save(const gchar *fn)
  *-----------------------------------------------------------------------------
  */
 
-static void playlist_append_dir_func(const gchar *d, gint recursive)
+static gint playlist_append_dir_func(const gchar *d, gint recursive, gint row)
 {
 	GList *files;
 	GList *dirs;
 	GList *work;
 
-	if (!path_list(d, &files, &dirs)) return;
+	if (!path_list(d, &files, &dirs)) return row;
 
 	files = path_list_filter(files, FALSE);
 	files = path_list_sort(files);
@@ -821,7 +827,15 @@ static void playlist_append_dir_func(const gchar *d, gint recursive)
 		{
 		gchar *path = work->data;
 		work = work->next;
-		playlist_add(path, TRUE);
+		if (row < 0)
+			{
+			playlist_add(path, TRUE);
+			}
+		else
+			{
+			playlist_insert(path, row, TRUE);
+			row ++;
+			}
 		}
 	path_list_free(files);
 
@@ -834,18 +848,28 @@ static void playlist_append_dir_func(const gchar *d, gint recursive)
 			{
 			gchar *path = work->data;
 			work = work->next;
-			playlist_append_dir_func(path, TRUE);
+			row = playlist_append_dir_func(path, row, TRUE);
 			}
 		}
 	path_list_free(dirs);
+
+	return row;
 }
 
 void playlist_append_from_dir(const gchar *path, gint recursive)
 {
-	playlist_append_dir_func(path, recursive);
+	playlist_append_dir_func(path, recursive, -1);
 	display_set_song_count(playlist_count);
 }
 
+gint playlist_insert_from_dir(const gchar *path, gint row, gint recursive)
+{
+	row = playlist_append_dir_func(path, recursive, row);
+	display_set_song_count(playlist_count);
+
+	return row;
+}
+
 /*
  *-----------------------------------------------------------------------------
  * playlist data functions (public)
@@ -1057,7 +1081,7 @@ static gint real_playlist_move_item(gint s, gint t)
 	SongData *sd;
 	GList *list = NULL;
 
-	if (s >= playlist_count || t >= playlist_count || s == t) return FALSE;
+	if (s >= playlist_count || t >= playlist_count || s == t || s < 0 || t < 0) return FALSE;
 	list = g_list_nth(playlist, s);
 
 	if (!list) return FALSE;
@@ -1335,7 +1359,7 @@ void playlist_update_all_info(void)
 		playlist_recalc_length();
 		}
 
-	playlist_window_clist_populate();
+	playlist_window_populate();
 }
 
 void playlist_sort_by_func(GCompareFunc sort_func)
@@ -1356,7 +1380,7 @@ SongData *playlist_add(const gchar *path, gint read_info)
 
 	sd = real_playlist_add_item(path, read_info);
 
-	playlist_window_clist_append(playlist_count - 1);
+	playlist_window_append(playlist_count - 1);
 
 	if (playlist_count == 1 && current_song_get_path() == NULL)
 		{
@@ -1374,7 +1398,7 @@ SongData *playlist_insert(const gchar *path, gint n, gint read_info)
 
 	sd = real_playlist_insert_item(path, n, read_info);
 
-	playlist_window_clist_insert(n);
+	playlist_window_insert(n);
 
 	if (n <= current_song_get_number())
 		{
@@ -1393,7 +1417,7 @@ gint playlist_move(gint s, gint t)
 	display_set_song_number(current_song_get_number());
 	display_total_time_changed();
 
-	playlist_window_clist_move(s, t);
+	playlist_window_move(s, t);
 
 	return TRUE;
 }
@@ -1415,7 +1439,7 @@ gint playlist_remove(const gchar *path, gint n, gint all)
 
 		if (removed)
 			{
-			playlist_window_clist_remove(n);
+			playlist_window_remove(n);
 
 			if (p == n)
 				{
@@ -1468,7 +1492,7 @@ void playlist_update_by_data_full(SongData *sd, gint force)
 
 	if (current_song_get_data() == sd) display_set_song_text_info(-1, TRUE);
 
-	playlist_window_clist_update_item(n);
+	playlist_window_update_item(n);
 
 	playlist_length += sd->length;
 	display_total_time_changed();
@@ -1488,7 +1512,7 @@ void playlist_update(gint n, const gchar *path)
 	if (path)
 		{
 		real_playlist_insert_item(path, n, TRUE);
-		playlist_window_clist_update_item(n);
+		playlist_window_update_item(n);
 		if (n == p)
 			{
 			current_song_set(n, NULL);
@@ -1496,7 +1520,7 @@ void playlist_update(gint n, const gchar *path)
 		}
 	else
 		{
-		playlist_window_clist_remove(n);
+		playlist_window_remove(n);
 		if (n == p)
 			{
 			current_song_set_to_next();
@@ -1533,7 +1557,7 @@ void playlist_clear(void)
 	display_set_song_count(0);
 	real_playlist_clear();
 	display_total_time_changed();
-	playlist_window_clist_clear();
+	playlist_window_clear();
 }
 
 /*
@@ -1573,7 +1597,7 @@ void playlist_data_customize_title(SongData *sd, const gchar *title)
 	if (current_song_get_data() == sd) display_set_song_text_info(-1, TRUE);
 
 	n = playlist_get_index_by_data(sd);
-	playlist_window_clist_update_item(n);
+	playlist_window_update_item(n);
 }
 
 void playlist_data_customize_comment(SongData *sd, const gchar *comment)
@@ -1593,7 +1617,7 @@ void playlist_data_customize_comment(SongData *sd, const gchar *comment)
 	if (current_song_get_data() == sd) display_set_song_text_info(-1, TRUE);
 
 	n = playlist_get_index_by_data(sd);
-	playlist_window_clist_update_item(n);
+	playlist_window_update_item(n);
 }
 
 /*
@@ -1660,7 +1684,7 @@ void playlist_randomize(void)
 		playlist = g_list_prepend(playlist, node->data);
 		list = g_list_remove(list, node->data);
 		}
-	playlist_window_clist_populate();
+	playlist_window_populate();
 	display_total_time_changed();
 	display_set_song_number(current_song_get_number());
 }
@@ -1688,7 +1712,7 @@ static gint playlist_background_cb(gpointer data)
 		return FALSE;
 		}
 
-	new_time = gdk_time_get();
+	new_time = elapsed_run_time();
 	if (new_time - old_time > DISPLAY_LOADING_ANIMATE_TIME)
 		{
 		old_time = new_time;
