@@ -1,6 +1,6 @@
 /*
  * GQmpeg
- * (C) 2003 John Ellis
+ * (C) 2004 John Ellis
  *
  * Author: John Ellis
  *
@@ -21,10 +21,20 @@
 #include "players.h"
 #include "playlist.h"
 #include "playlist-window.h"
+#include "ui2_editor.h"
 #include "ui2_main.h"
 #include "ui_fileops.h"
+#include "ui_menu.h"
 #include "ui_tabcomp.h"
 
+
+enum {
+	SKIN_COLUMN_PATH = 0,
+	SKIN_COLUMN_NAME,
+	SKIN_COLUMN_COUNT
+};
+
+
 static GtkWidget *configwindow;
 static GtkWidget *mixer_entry;
 static GtkWidget *initial_playlist_entry;
@@ -104,7 +114,8 @@ static GtkWidget *hscale_new(gint n, gint *c_n)
         hscale = gtk_hscale_new (GTK_ADJUSTMENT(adj));
         gtk_range_set_update_policy (GTK_RANGE (hscale), GTK_UPDATE_DELAYED);
         gtk_scale_set_digits (GTK_SCALE (hscale), 0);
-        gtk_signal_connect( GTK_OBJECT(adj),"value_changed", GTK_SIGNAL_FUNC(hscale_cb), c_n);
+        g_signal_connect(G_OBJECT(adj), "value_changed",
+			 G_CALLBACK(hscale_cb), c_n);
 
 	return hscale;
 }
@@ -113,7 +124,7 @@ static void checkbox_cb(GtkWidget *w, gpointer data)
 {
 	gint *c_n = data;
 
-	*c_n = GTK_TOGGLE_BUTTON (w)->active;
+	*c_n = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(w));
 }
 
 static GtkWidget *checkbox_new(gchar *text, gint n, gint *c_n)
@@ -122,8 +133,9 @@ static GtkWidget *checkbox_new(gchar *text, gint n, gint *c_n)
 
 	*c_n = n;
 	button = gtk_check_button_new_with_label(text);
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON(button), n);
-	gtk_signal_connect (GTK_OBJECT(button), "clicked", (GtkSignalFunc)checkbox_cb, c_n);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), n);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(checkbox_cb), c_n);
 
 	return button;
 }
@@ -170,11 +182,16 @@ static void flyby_location_cb(GtkWidget *w, gpointer data)
 	c_flyby_location = GPOINTER_TO_INT(data);
 }
 
-static void skin_item_selected(GtkWidget *clist, gint row, gint column,
-		GdkEventButton *bevent, gpointer data)
+static void skin_item_selected(GtkTreeSelection *selection, gpointer data)
 {
-	gchar *text = gtk_clist_get_row_data(GTK_CLIST(clist), row);
-	if (text) gtk_entry_set_text(GTK_ENTRY(default_skin_entry),text);
+	GtkTreeModel *store;
+	GtkTreeIter iter;
+	gchar *path;
+
+	if (!gtk_tree_selection_get_selected(selection, &store, &iter)) return;
+
+	gtk_tree_model_get(store, &iter, SKIN_COLUMN_PATH, &path, -1);
+	gtk_entry_set_text(GTK_ENTRY(default_skin_entry), (path) ? path : "");
 }
 
 static gint sort_skin_list_cb(void *a, void *b)
@@ -194,19 +211,18 @@ static GList *skin_list_add_dir(GList *list, gchar *skinpath)
 	return g_list_concat(list, dirs);
 }
 
-static void populate_skin_list(GtkWidget *clist)
+static void populate_skin_list(GtkListStore *store)
 {
 	gchar *skinpath;
 	GList *skin_list = NULL;
 	GList *work;
-	gchar *buf[2];
-	gint row;
+	GtkTreeIter iter;
 
 	/* add default skin */
-	buf[0] = _("None (default)");
-	buf[1] = NULL;
-	row = gtk_clist_append(GTK_CLIST(clist), buf);
-	gtk_clist_set_row_data(GTK_CLIST(clist), row, "");
+	gtk_list_store_append(store, &iter);
+	gtk_list_store_set(store, &iter,
+			   SKIN_COLUMN_PATH, NULL,
+			   SKIN_COLUMN_NAME, _("None (default)"), -1);
 
 	/* add home dir skins */
 	skinpath = g_strconcat(homedir(), "/", GQMPEG_RC_DIR_SKIN, NULL);
@@ -223,40 +239,41 @@ static void populate_skin_list(GtkWidget *clist)
 	work = skin_list;
 	while (work)
 		{
-		gchar *skindata_file = g_strconcat(work->data, "/skindata", NULL);
+		gchar *path = work->data;
+		gchar *skindata_file = g_strconcat(path, "/skindata", NULL);
+
 		if (isfile(skindata_file))
 			{
-			buf[0] = (gchar *)filename_from_path(work->data);
-			row = gtk_clist_append(GTK_CLIST(clist),buf);
-			gtk_clist_set_row_data_full(GTK_CLIST(clist), row,
-					work->data, (GtkDestroyNotify) g_free);
+			gtk_list_store_append(store, &iter);
+			gtk_list_store_set(store, &iter,
+					   SKIN_COLUMN_PATH, path,
+					   SKIN_COLUMN_NAME, filename_from_path(path), -1);
 			}
 		else
 			{
 			g_free(skindata_file);
-			skindata_file = g_strconcat(work->data, "/main.bmp", NULL);
+			skindata_file = g_strconcat(path, "/main.bmp", NULL);
 			if (isfile(skindata_file))
 				{
-				gchar *amp_txt = g_strconcat (filename_from_path(work->data), " (amp)", NULL);
-				buf[0] = amp_txt;
-				row = gtk_clist_append(GTK_CLIST(clist),buf);
-				gtk_clist_set_row_data_full(GTK_CLIST(clist), row,
-						work->data, (GtkDestroyNotify) g_free);
+				gchar *amp_txt = g_strconcat(filename_from_path(path), " (amp)", NULL);
+
+				gtk_list_store_append(store, &iter);
+				gtk_list_store_set(store, &iter,
+						   SKIN_COLUMN_PATH, path,
+						   SKIN_COLUMN_NAME, amp_txt, -1);
 				g_free(amp_txt);
 				}
 			else
 				{
-				gchar *name = work->data;
-				printf(_("Valid skin not found in:%s\n"), name);
+				printf(_("Valid skin not found in:%s\n"), path);
 				printf(_("File named skindata (gqmpeg skins) or main.bmp (winamp skins) not found.\n"));
-				g_free(work->data);
 				}
 			}
 		g_free(skindata_file);
 		work = work->next;
 		}
 
-	g_list_free(skin_list);
+	path_list_free(skin_list);
 }
 
 void show_configuration_window(void)
@@ -468,8 +485,8 @@ static void create_config_window(gint start_tab)
 	GtkWidget *vbox1;
 	GtkWidget *label;
 	GtkWidget *frame;
-	GtkWidget *scrolled;
-	GtkWidget *skin_clist;
+	GtkListStore *store;
+	GtkWidget *skin_view;
 	GtkWidget *table;
 	GtkWidget *sep;
 
@@ -486,7 +503,6 @@ static void create_config_window(gint start_tab)
 
 	GtkWidget *tabcomp;
 
-	gchar *skin_title [] = { _("Available skins:"), };
 	gchar *skin_label_text;
 
 	GtkWidget *playertabs;
@@ -494,24 +510,26 @@ static void create_config_window(gint start_tab)
 	GList *work;
 
 	configwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_type_hint(GTK_WINDOW(configwindow), GDK_WINDOW_TYPE_HINT_DIALOG);
 	gtk_window_set_wmclass(GTK_WINDOW(configwindow), "preferences", "GQmpeg");
-	gtk_signal_connect (GTK_OBJECT (configwindow), "delete_event",(GtkSignalFunc) hide_configuration_window, NULL);
-	gtk_window_set_policy (GTK_WINDOW (configwindow), FALSE, FALSE, TRUE);
+	g_signal_connect(G_OBJECT(configwindow), "delete_event",
+			 G_CALLBACK(hide_configuration_window), NULL);
+	gtk_window_set_resizable(GTK_WINDOW(configwindow), FALSE);
 	gtk_window_set_title (GTK_WINDOW (configwindow), _("GQmpeg configuration"));
-	gtk_container_border_width (GTK_CONTAINER (configwindow), 5);
+	gtk_container_set_border_width (GTK_CONTAINER (configwindow), 5);
 
 	configvbox = gtk_vbox_new(FALSE, 5);
 	gtk_container_add(GTK_CONTAINER(configwindow),configvbox);
 	gtk_widget_show(configvbox);
 
 	hbox = gtk_hbutton_box_new();
-	gtk_button_box_set_spacing(GTK_BUTTON_BOX(hbox), 0);
-	gtk_button_box_set_child_size(GTK_BUTTON_BOX(hbox), 95, 40);
+	gtk_box_set_spacing(GTK_BOX(hbox), 10);
 	gtk_box_pack_end(GTK_BOX(configvbox), hbox, FALSE, FALSE, 0);
 	gtk_widget_show(hbox);
 
 	button = gtk_button_new_with_label(_("Ok"));
-	gtk_signal_connect(GTK_OBJECT (button), "clicked",(GtkSignalFunc) ok_configuration_window, NULL);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(ok_configuration_window), NULL);
 	gtk_container_add(GTK_CONTAINER(hbox), button);
 	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
 	gtk_widget_grab_default(button);
@@ -519,13 +537,15 @@ static void create_config_window(gint start_tab)
 
 
 	button = gtk_button_new_with_label(_("Apply"));
-	gtk_signal_connect (GTK_OBJECT (button), "clicked",(GtkSignalFunc) apply_configuration_window, NULL);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(apply_configuration_window), NULL);
 	gtk_container_add(GTK_CONTAINER(hbox), button);
 	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
 	gtk_widget_show(button);
 
 	button = gtk_button_new_with_label(_("Cancel"));
-	gtk_signal_connect (GTK_OBJECT (button), "clicked",(GtkSignalFunc) hide_configuration_window, NULL);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(hide_configuration_window), NULL);
 	gtk_container_add(GTK_CONTAINER(hbox), button);
 	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
 	gtk_widget_show(button);
@@ -537,18 +557,18 @@ static void create_config_window(gint start_tab)
 	/* general tab */
 
 	frame = gtk_frame_new(NULL);
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_widget_show(frame);
 	label = gtk_label_new(_("General"));
 	gtk_notebook_append_page (GTK_NOTEBOOK (configtabs), frame, label);
 
 	vbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_border_width (GTK_CONTAINER (vbox), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add (GTK_CONTAINER(frame),vbox);
 	gtk_widget_show(vbox);
 	
 	frame = gtk_frame_new(_("Song Information"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
@@ -561,7 +581,7 @@ static void create_config_window(gint start_tab)
 	gtk_widget_show(button);
 
 	frame = gtk_frame_new(_("Window"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
@@ -586,7 +606,7 @@ static void create_config_window(gint start_tab)
 	gtk_widget_show(button);
 
 	frame = gtk_frame_new(_("Title Display"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
@@ -607,7 +627,7 @@ static void create_config_window(gint start_tab)
 	gtk_widget_show(button);
 
 	frame = gtk_frame_new(_("Mixer"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
@@ -650,11 +670,9 @@ static void create_config_window(gint start_tab)
 	while (list)
 		{
 		gchar *dev_text = list->data;
-	        item = gtk_menu_item_new_with_label(dev_text);
-	        gtk_signal_connect(GTK_OBJECT(item), "activate",
-				   GTK_SIGNAL_FUNC(mixer_device_id_cb), dev_text);
-		gtk_menu_append(GTK_MENU(menu), item);
-		gtk_widget_show(item);
+
+		item = menu_item_add(menu, dev_text,
+				     G_CALLBACK(mixer_device_id_cb), dev_text);
 		if (get_mixer_device_id(dev_text) == mixer_device_id) lh = cnt;
 		cnt++;
 		list = list->next;
@@ -686,26 +704,26 @@ static void create_config_window(gint start_tab)
 	c_change_delay = change_delay;
 	adj = gtk_adjustment_new((gfloat)change_delay, 0.0, 300.0, 1.0, 1.0, 1.0);
 	spin = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 1.0, 0);
-	gtk_signal_connect(adj, "value_changed",
-			   GTK_SIGNAL_FUNC(spin_cb), &c_change_delay);
+	g_signal_connect(adj, "value_changed",
+			   G_CALLBACK(spin_cb), &c_change_delay);
 	gtk_box_pack_start(GTK_BOX(hbox), spin, FALSE, FALSE, 0);
 	gtk_widget_show(spin);
 
 	/* Startup tab */
 
 	frame = gtk_frame_new(NULL);
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_widget_show(frame);
 	label = gtk_label_new(_("Startup"));
 	gtk_notebook_append_page (GTK_NOTEBOOK (configtabs), frame, label);
 
 	vbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_border_width (GTK_CONTAINER (vbox), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add (GTK_CONTAINER(frame),vbox);
 	gtk_widget_show(vbox);
 	
 	frame = gtk_frame_new(_("Initial playlist"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
@@ -715,20 +733,34 @@ static void create_config_window(gint start_tab)
 
 	c_initial_playlist_mode = initial_playlist_mode;
 	radiobutton = gtk_radio_button_new_with_label (NULL, _("Empty"));
-	if (c_initial_playlist_mode == PLAYLIST_MODE_EMPTY) gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON(radiobutton), 1);
-	gtk_signal_connect (GTK_OBJECT(radiobutton),"clicked",(GtkSignalFunc) initial_playlist_empty_selected, NULL);
+	if (c_initial_playlist_mode == PLAYLIST_MODE_EMPTY)
+		{
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radiobutton), TRUE);
+		}
+	g_signal_connect(G_OBJECT(radiobutton), "clicked",
+			 G_CALLBACK(initial_playlist_empty_selected), NULL);
 	gtk_box_pack_start(GTK_BOX(vbox1), radiobutton, FALSE, FALSE, 0);
 	gtk_widget_show(radiobutton);
 
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group(GTK_RADIO_BUTTON(radiobutton)), _("Save playlist between sessions"));
-	if (c_initial_playlist_mode == PLAYLIST_MODE_SESSION) gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON(button), 1);
-	gtk_signal_connect (GTK_OBJECT(button),"clicked",(GtkSignalFunc) initial_playlist_session_selected, NULL);
+	button = gtk_radio_button_new_with_label(gtk_radio_button_get_group(GTK_RADIO_BUTTON(radiobutton)),
+						 _("Save playlist between sessions"));
+	if (c_initial_playlist_mode == PLAYLIST_MODE_SESSION)
+		{
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+		}
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(initial_playlist_session_selected), NULL);
 	gtk_box_pack_start(GTK_BOX(vbox1), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 
-	button = gtk_radio_button_new_with_label (gtk_radio_button_group(GTK_RADIO_BUTTON(radiobutton)), _("Open specific playlist:"));
-	if (c_initial_playlist_mode == PLAYLIST_MODE_FILE) gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON(button), 1);
-	gtk_signal_connect (GTK_OBJECT(button),"clicked",(GtkSignalFunc) initial_playlist_file_selected, NULL);
+	button = gtk_radio_button_new_with_label(gtk_radio_button_get_group(GTK_RADIO_BUTTON(radiobutton)),
+						 _("Open specific playlist:"));
+	if (c_initial_playlist_mode == PLAYLIST_MODE_FILE)
+			{
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+			}
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(initial_playlist_file_selected), NULL);
 	gtk_box_pack_start(GTK_BOX(vbox1), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 
@@ -741,12 +773,13 @@ static void create_config_window(gint start_tab)
 	gtk_widget_show(tabcomp);
 
 	button = gtk_button_new_with_label(_("Use current"));
-	gtk_signal_connect (GTK_OBJECT(button),"clicked",(GtkSignalFunc)set_current_playlist_clicked, NULL);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(set_current_playlist_clicked), NULL);
 	gtk_box_pack_end(GTK_BOX(hbox),button,FALSE,FALSE,0);
 	gtk_widget_show(button);
 
 	frame = gtk_frame_new(_("When program starts:"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
@@ -775,14 +808,15 @@ static void create_config_window(gint start_tab)
 	gtk_widget_show(tabcomp);
 
 	button = gtk_button_new_with_label(_("Use current"));
-	gtk_signal_connect (GTK_OBJECT(button),"clicked",(GtkSignalFunc)set_current_dir_clicked, NULL);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(set_current_dir_clicked), NULL);
 	gtk_box_pack_end(GTK_BOX(hbox),button,FALSE,FALSE,0);
 	gtk_widget_show(button);
 
 	/* output player tab */
 	frame = gtk_frame_new(NULL);
 	gtk_frame_set_shadow_type (GTK_FRAME(frame), GTK_SHADOW_NONE);
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_widget_show(frame);
 	label = gtk_label_new(_("Output"));
 	gtk_notebook_append_page (GTK_NOTEBOOK (configtabs), frame, label);
@@ -798,7 +832,7 @@ static void create_config_window(gint start_tab)
 		{
 		GtkWidget *w = work->data;
 		GtkWidget *wlabel;
-		gchar *wtext = gtk_object_get_user_data(GTK_OBJECT(w));
+		gchar *wtext = g_object_get_data(G_OBJECT(w), "title");
 
 		wlabel = gtk_label_new(wtext);
 		gtk_notebook_append_page (GTK_NOTEBOOK (playertabs), w, wlabel);
@@ -811,13 +845,13 @@ static void create_config_window(gint start_tab)
 	/* playlist tab */
 
 	frame = gtk_frame_new(NULL);
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_widget_show(frame);
 	label = gtk_label_new(_("Playlist"));
 	gtk_notebook_append_page (GTK_NOTEBOOK (configtabs), frame, label);
 
 	vbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_border_width (GTK_CONTAINER (vbox), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add (GTK_CONTAINER(frame),vbox);
 	gtk_widget_show(vbox);
 
@@ -842,7 +876,7 @@ static void create_config_window(gint start_tab)
 	gtk_widget_show(button);
 
 	frame = gtk_frame_new(_("Flybys"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
@@ -865,14 +899,8 @@ static void create_config_window(gint start_tab)
 
 	for (i = 0; i < 4; i++)
 		{
-		const gchar *loc_text;
-
-		loc_text = display_flyby_location_to_text(i);
-		item = gtk_menu_item_new_with_label(loc_text);
-		gtk_signal_connect(GTK_OBJECT(item), "activate",
-				   GTK_SIGNAL_FUNC(flyby_location_cb), GINT_TO_POINTER(i));
-		gtk_menu_append(GTK_MENU(menu), item);
-		gtk_widget_show(item);
+		menu_item_add(menu, display_flyby_location_to_text(i),
+			      G_CALLBACK(flyby_location_cb), GINT_TO_POINTER(i));
 		}
 
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(omenu), menu);
@@ -883,13 +911,13 @@ static void create_config_window(gint start_tab)
 	/* preset tab */
 
 	frame = gtk_frame_new(NULL);
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_widget_show(frame);
 	label = gtk_label_new(_("Presets"));
 	gtk_notebook_append_page (GTK_NOTEBOOK (configtabs), frame, label);
 
 	vbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_border_width (GTK_CONTAINER (vbox), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add (GTK_CONTAINER(frame),vbox);
 	gtk_widget_show(vbox);
 
@@ -919,8 +947,8 @@ static void create_config_window(gint start_tab)
 		gtk_table_attach_defaults(GTK_TABLE (table),label,0,1,i+1,i+2);
 		gtk_widget_show(label);
 
-		preset_name_entry[i] = gtk_entry_new_with_max_length(255);
-                gtk_widget_set_usize(preset_name_entry[i],80,-1);
+		preset_name_entry[i] = gtk_entry_new();
+                gtk_widget_set_size_request(preset_name_entry[i], 80, -1);
 		if (preset_name[i]) gtk_entry_set_text(GTK_ENTRY(preset_name_entry[i]), preset_name[i]);
 		gtk_table_attach_defaults(GTK_TABLE (table),preset_name_entry[i],1,2,i+1,i+2);
                 gtk_widget_show(preset_name_entry[i]);
@@ -941,13 +969,13 @@ static void create_config_window(gint start_tab)
 	/* skin tab */
 
 	frame = gtk_frame_new(NULL);
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_widget_show(frame);
 	label = gtk_label_new(_("Skins"));
 	gtk_notebook_append_page (GTK_NOTEBOOK (configtabs), frame, label);
 
 	vbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_border_width (GTK_CONTAINER (vbox), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add (GTK_CONTAINER(frame),vbox);
 	gtk_widget_show(vbox);
 
@@ -965,20 +993,15 @@ static void create_config_window(gint start_tab)
 	gtk_box_pack_start(GTK_BOX(hbox), tabcomp, TRUE, TRUE, 0);
 	gtk_widget_show(tabcomp);
 
-	scrolled = gtk_scrolled_window_new(NULL, NULL);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
-				GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
-	gtk_box_pack_start(GTK_BOX(vbox),scrolled,TRUE,TRUE,0);
-	gtk_widget_show(scrolled);
-
 	/* skin list */
-	skin_clist=gtk_clist_new_with_titles (1, skin_title);
-	gtk_clist_column_titles_passive (GTK_CLIST (skin_clist)); 
-	gtk_signal_connect (GTK_OBJECT (skin_clist), "select_row",(GtkSignalFunc) skin_item_selected, NULL);
-	gtk_container_add (GTK_CONTAINER (scrolled), skin_clist);
-	gtk_widget_show (skin_clist);
+	store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_STRING);
+	skin_view = ui_edit_list_new(vbox, store,
+				    G_CALLBACK(skin_item_selected), NULL);
+	g_object_unref(store);
 
-	populate_skin_list(skin_clist);
+	ui_edit_list_add_column(skin_view, _("Available skins:"), SKIN_COLUMN_NAME, FALSE, FALSE);
+
+	populate_skin_list(store);
 
 	skin_label_text = g_strconcat(homedir(), "/", GQMPEG_RC_DIR_SKIN, NULL);
 
@@ -995,7 +1018,7 @@ static void create_config_window(gint start_tab)
 /*---*/
 
 	frame = gtk_frame_new(_("Skin Adjustment"));
-	gtk_container_border_width (GTK_CONTAINER (frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_box_pack_start(GTK_BOX(vbox), frame, FALSE, FALSE, 0);
 	gtk_widget_show(frame);
 
@@ -1059,7 +1082,7 @@ static void create_config_window(gint start_tab)
 	gtk_box_pack_start(GTK_BOX(vbox), sep, FALSE, FALSE, 0);
 	gtk_widget_show(sep);
 
-	gtk_notebook_set_page (GTK_NOTEBOOK(configtabs), start_tab);
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(configtabs), start_tab);
 	gtk_widget_show(configtabs);
 
 }
@@ -1085,13 +1108,9 @@ void show_about_info(void)
 	GtkWidget *frame;
 	GtkWidget *vbox;
 	GtkWidget *label;
-	GtkWidget *pixmap;
+	GtkWidget *image;
+	GdkPixbuf *pixbuf;
 	GtkWidget *cred;
-	GtkStyle *style;
-
-	GdkPixmap *pmap;
-	GdkBitmap *mask;
-
 	gchar *buf;
 
 	if (about)
@@ -1101,37 +1120,39 @@ void show_about_info(void)
 		}
 
 	about = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_type_hint(GTK_WINDOW(about), GDK_WINDOW_TYPE_HINT_DIALOG);
 	gtk_window_set_wmclass(GTK_WINDOW(about), "about", "GQmpeg");
-	gtk_signal_connect(GTK_OBJECT(about), "delete_event", GTK_SIGNAL_FUNC(about_delete_cb), NULL);
+	g_signal_connect(G_OBJECT(about), "delete_event",
+			 G_CALLBACK(about_delete_cb), NULL);
 
 	gtk_window_set_title(GTK_WINDOW(about), _("About - GQmpeg"));
-	gtk_container_border_width(GTK_CONTAINER(about), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(about), 5);
 
 	frame = gtk_frame_new(NULL);
-	gtk_container_border_width(GTK_CONTAINER(frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_container_add(GTK_CONTAINER(about), frame);
 	gtk_widget_show(frame);
 
 	vbox = gtk_vbox_new(FALSE, 0);
-	gtk_container_border_width(GTK_CONTAINER(vbox), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 	gtk_widget_show(vbox);
 
-	gtk_widget_realize(about);
+	pixbuf = gdk_pixbuf_new_from_xpm_data((const gchar **)gqmpeg_icon_xpm);
+	image = gtk_image_new_from_pixbuf(pixbuf);
+	gdk_pixbuf_unref(pixbuf);
 
-	style = gtk_widget_get_style(about);
-	pmap = gdk_pixmap_create_from_xpm_d(about->window, &mask,
-		&style->bg[GTK_STATE_NORMAL], gqmpeg_icon_xpm);
-	pixmap = gtk_pixmap_new(pmap, mask);
-	gdk_pixmap_unref(pmap);
-	if (mask) gdk_bitmap_unref(mask);
+	gtk_box_pack_start(GTK_BOX(vbox), image, FALSE, FALSE, 0);
+	gtk_widget_show(image);
 
-	gtk_box_pack_start(GTK_BOX(vbox), pixmap, FALSE, FALSE, 0);
-	gtk_widget_show(pixmap);
-
-	buf = g_strdup_printf(_("GQmpeg %s\nA frontend to mpg123\n\nCopyright (c) 2003 by John Ellis\nhttp://gqmpeg.sourceforge.net\ngqview@users.sourceforge.net\n\nReleased under the GNU General Public License"), VERSION);
+	buf = g_strdup_printf(_("GQmpeg %s\nA frontend to mpg123\n\nCopyright (c) %s John Ellis\nwebsite: %s\nemail: %s\n\nReleased under the GNU General Public License"),
+			      VERSION,
+			      "2004",
+			      "gqmpeg.sourceforge.net",
+			      "gqview@users.sourceforge.net");
 	label = gtk_label_new(buf);
 	g_free(buf);
+	gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
@@ -1139,7 +1160,7 @@ void show_about_info(void)
 	gtk_box_pack_end(GTK_BOX(vbox), cred, FALSE, FALSE, 0);
 	gtk_widget_show(cred);
 
-	window_set_icon(about, (const gchar **)gqmpeg_icon_xpm, NULL);
+	window_set_icon(about, (const gchar **)gqmpeg_icon_xpm, NULL, NULL);
 	gtk_widget_show(about);
 }
 
