@@ -109,6 +109,7 @@ void save_options(void)
 {
 	FILE *f;
 	gchar *rc_path;
+	gchar *rc_pathl;
 	gchar *rcdir;
 	gint i;
 
@@ -116,7 +117,7 @@ void save_options(void)
 	if (!isdir(rcdir))
 		{
 		printf(_("Creating gqmpeg dir:%s\n"), rcdir);
-		if ( (mkdir (rcdir, 0755) < 0) )
+		if (!mkdir_utf8(rcdir, 0755))
 			{
 			printf(_("Could not create dir:%s\n"), rcdir);
 			printf(_("Config not saved!\n"));
@@ -128,7 +129,9 @@ void save_options(void)
 	rc_path = g_strconcat(rcdir, "/", GQMPEG_RC_FILE, NULL);
 	g_free(rcdir);
 
-	f = fopen(rc_path,"w");
+	rc_pathl = path_from_utf8(rc_path);
+	f = fopen(rc_pathl, "w");
+	g_free(rc_pathl);
 	if (!f)
 		{
 		printf(_("error saving config file: %s\n"), rc_path);
@@ -263,6 +266,7 @@ void load_options(void)
 {
 	FILE *f;
 	gchar *rc_path;
+	gchar *rc_pathl;
 	gchar s_buf[1024];
 	gchar *s_buf_ptr;
 	gchar option[1024];
@@ -272,7 +276,9 @@ void load_options(void)
 
 	rc_path = g_strconcat(homedir(), "/", GQMPEG_RC_DIR, "/", GQMPEG_RC_FILE, NULL);
 
-	f = fopen(rc_path,"r");
+	rc_pathl = path_from_utf8(rc_path);
+	f = fopen(rc_pathl, "r");
+	g_free(rc_pathl);
 	if (!f)
 		{
 		g_free(rc_path);
