@@ -537,8 +537,11 @@ SkinData *skin_parse_v1(const gchar *skin_path, const gchar *datafile, gint edit
 	FILE *f;
 	char buf[1024];
 	WidgetData *wd;
+	gchar *pathl;
 
-	f = fopen(datafile, "r");
+	pathl = path_from_utf8(datafile);
+	f = fopen(pathl, "r");
+	g_free(pathl);
 
 	if (!f)
 		{
@@ -594,7 +597,7 @@ SkinData *skin_parse_v1(const gchar *skin_path, const gchar *datafile, gint edit
 
 			filename = g_strconcat(skin_path, "/", vector[1], NULL);
 
-			s->real_overlay = util_size_pixbuf(gdk_pixbuf_new_from_file(filename), TRUE);
+			s->real_overlay = util_size_pixbuf(util_pixbuf_new_from_file(filename), TRUE);
 			if (s->real_overlay)
 				{
 				s->width = gdk_pixbuf_get_width(s->real_overlay);
@@ -610,7 +613,7 @@ SkinData *skin_parse_v1(const gchar *skin_path, const gchar *datafile, gint edit
 
 			filename = g_strconcat(skin_path, "/", vector[1], NULL);
 
-			s->mask = util_size_pixbuf(gdk_pixbuf_new_from_file(filename), FALSE);
+			s->mask = util_size_pixbuf(util_pixbuf_new_from_file(filename), FALSE);
 			if (s->mask && edit) s->background_mask_filename = g_strdup(filename);
 
 			g_free(filename);
