@@ -23,6 +23,9 @@
 #include "ui2_widget.h"
 
 
+#define GQMPEG_SKIN_FONT "-*-helvetica-bold-r-*-*-14-*-*-*-*-*-*-*"
+
+
 #include "default_skin/back.xpm"
 #include "default_skin/back_mini.xpm"
 #include "default_skin/btn_config.xpm"
@@ -68,10 +71,22 @@
 #include "default_skin/itm_mminus.xpm"
 #include "default_skin/itm_stereo.xpm"
 #include "default_skin/itm_time.xpm"
-#include "default_skin/letters.xpm"
 #include "default_skin/slider_pos.xpm"
 #include "default_skin/slider_vol.xpm"
 
+#include "default_skin/back_playlist.xpm"
+#include "default_skin/btn_list.xpm"
+#include "default_skin/btn_up.xpm"
+#include "default_skin/btn_down.xpm"
+#include "default_skin/btn_sizer.xpm"
+#include "default_skin/btn_vert.xpm"
+#include "default_skin/list_back.xpm"
+#include "default_skin/list_row.xpm"
+#include "default_skin/list_flags.xpm"
+
+#include "default_skin/back_vert.xpm"
+#include "default_skin/itm_vcolon.xpm"
+
 #include "default_skin/flyby_back.xpm"
 #include "default_skin/btn_snext.xpm"
 #include "default_skin/btn_sprev.xpm"
@@ -82,12 +97,13 @@
 #include "default_skin/menu_list_icons.xpm"
 
 
-static void add_item(const gchar *key, gchar **data, gint sections, gint x, gint y, SkinData *skin, const gchar *text_id)
+static WidgetData *add_item(const gchar *key, gchar **data, gint sections,
+			    gint x, gint y, SkinData *skin, const gchar *text_id)
 {
 	ItemData *item;
 
 	item = item_new_from_data(data, x, y, sections);
-	item_register(skin, item, key, text_id);
+	return item_register(skin, item, key, text_id);
 }
 
 static DigitData *add_digit(const gchar *key, gchar **data, SkinData *skin, const gchar *text_id)
@@ -101,13 +117,13 @@ static DigitData *add_digit(const gchar *key, gchar **data, SkinData *skin, cons
 	return digit;
 }
 
-static void add_number(const gchar *key, gint length, gint zeros, gint centered, gint x, gint y,
-		       DigitData *digit, SkinData *skin, const gchar *text_id)
+static WidgetData *add_number(const gchar *key, gint length, gint rotation, gint zeros, gint centered, gint x, gint y,
+			      DigitData *digit, SkinData *skin, const gchar *text_id)
 {
 	NumberData *number;
 
-	number = number_new(digit, x, y, length, zeros, centered);
-	number_register(skin, number, key, text_id);
+	number = number_new(digit, x, y, length, zeros, centered, rotation);
+	return number_register(skin, number, key, text_id);
 }
 
 static WidgetData *add_button(const gchar *key, gchar **data, gint prelight, gint light, gint x, gint y,
@@ -119,22 +135,66 @@ static WidgetData *add_button(const gchar *key, gchar **data, gint prelight, gin
 	return button_register(skin, button, key, text_id);
 }
 
-static void add_slider(const gchar *key, gchar **data, gint has_press, gint prelight, gint vertical, gint reversed,
-		       gint length, gint x, gint y, SkinData *skin, const gchar *text_id)
+static WidgetData *add_slider(const gchar *key, gchar **data, gint has_press, gint prelight, gint vertical, gint reversed,
+			      gint length, gint x, gint y, SkinData *skin, const gchar *text_id,
+			      gint sizeable, gint real_length, gint border_1, gint border_2, gint stretch)
 {
 	SliderData *slider;
 
 	slider = slider_new_from_data(data, x, y, length, vertical, reversed, has_press, prelight, NULL);
-	slider_register(skin, slider, key, text_id);
+	if (sizeable) slider_set_attributes(slider, sizeable, real_length, border_1, border_2, stretch);
+	return slider_register(skin, slider, key, text_id);
 }
 
-static void add_text(const gchar *key, gchar **data, gint length, gint extended, gint sizeable,
-		     gint x, gint y, SkinData *skin, const gchar *text_id)
+static WidgetData *add_text(const gchar *key, const gchar *font, gint width, gint sizeable, gint rotation,
+			    guint8 r, guint8 g, guint8 b, guint8 a,
+			    gint x, gint y, SkinData *skin, const gchar *text_id)
 {
 	TextData *text;
 
-	text = text_new_from_data(data, x, y, length, sizeable, extended);
-	text_register(skin, text, key, text_id);
+	text = text_new_from_x(font, x, y, width, sizeable, rotation);
+	text_set_color(text, r, g, b, a);
+	return text_register(skin, text, key, text_id);
+}
+
+/* double size utilities */
+static void double_window(SkinData *skin)
+{
+	util_size(&skin->width);
+	util_size(&skin->height);
+	util_size(&skin->border_left);
+	util_size(&skin->border_right);
+	util_size(&skin->border_bottom);
+	util_size(&skin->border_top);
+}
+
+static void double_focus(SkinData *skin)
+{
+	util_size(&skin->focus_border_left);
+	util_size(&skin->focus_border_right);
+	util_size(&skin->focus_border_bottom);
+	util_size(&skin->focus_border_top);
+}
+
+static void add_focus(SkinData *skin)
+{
+	skin->focus_overlay = util_size_pixbuf(gdk_pixbuf_new_from_xpm_data((const char **)focus_xpm), TRUE);
+	skin->focus_box_alpha = 150;
+	skin->focus_has_border = TRUE;
+	skin->focus_border_left = 5;
+	skin->focus_border_right = 5;
+	skin->focus_border_bottom = 5;
+	skin->focus_border_top = 5;
+}
+
+static void finish_simple_window(SkinData *skin)
+{
+	skin->width = gdk_pixbuf_get_width(skin->real_overlay);
+	skin->height = gdk_pixbuf_get_height(skin->real_overlay);
+
+	/* this is merely to that the skin editor has sane values for these */
+	skin->width_def = skin->width_min = skin->width_max = skin->width;
+	skin->height_def = skin->height_min = skin->height_max = skin->height;
 }
 
 SkinData *skin_load_default_cb(UIData *ui, const gchar *key, gpointer data)
@@ -145,12 +205,147 @@ SkinData *skin_load_default_cb(UIData *ui, const gchar *key, gpointer data)
 
 	skin = skin_new();
 
-	if (key && strcmp(key, "skindata_alt") == 0)
+	if (key && strcmp(key, "skindata_playlist") == 0)
+		{
+		ListData *ld;
+
+		skin->real_overlay = util_size_pixbuf(gdk_pixbuf_new_from_xpm_data((const char **)back_playlist_xpm), TRUE);
+
+		skin->width_def = skin->width = 337;
+		skin->height_def = skin->height = 242;
+
+		skin->sizeable = TRUE;
+		skin->width_min = 337;
+		skin->height_min = 146;
+		skin->width_max = 449;
+		skin->height_max = 402;
+
+		skin->width_inc = 16;
+		skin->height_inc = 16;
+
+		skin->has_border = TRUE;
+		skin->border_left = 126;
+		skin->border_right = 208;
+		skin->border_top = 60;
+		skin->border_bottom = 66;
+
+		add_text("playlist", GQMPEG_SKIN_FONT, 205, FALSE, 0, 255, 255, 255, 150, 91, 6, skin, NULL);
+
+		wd = add_button("playlist", (gchar **)btn_playlist_xpm, TRUE, FALSE, 10, 202, NULL, skin, NULL);
+		ui_widget_set_anchor(wd, FALSE, TRUE);
+		wd = add_button("play", (gchar **)btn_play_xpm, TRUE, TRUE, 50, 202, NULL, skin, NULL);
+		ui_widget_set_anchor(wd, FALSE, TRUE);
+		wd = add_button("stop", (gchar **)btn_stop_xpm, TRUE, TRUE, 90, 202, NULL, skin, NULL);
+		ui_widget_set_anchor(wd, FALSE, TRUE);
+		wd = add_button("prev", (gchar **)btn_prev_xpm, TRUE, FALSE, 130, 212, NULL, skin, NULL);
+		ui_widget_set_anchor(wd, TRUE, TRUE);
+		wd = add_button("next", (gchar **)btn_next_xpm, TRUE, FALSE, 165, 212, NULL, skin, NULL);
+		ui_widget_set_anchor(wd, TRUE, TRUE);
+
+		ld = list_new(gdk_pixbuf_new_from_xpm_data((const char **)list_back_xpm),
+			      16, 30, 284, 160, TRUE, 3,
+			      0, 0, 0, 0, FALSE);
+		list_image_row(ld, gdk_pixbuf_new_from_xpm_data((const char **)list_row_xpm),
+			       TRUE, TRUE, 1, 1, FALSE, NULL);
+		list_image_row_flag(ld, gdk_pixbuf_new_from_xpm_data((const char **)list_flags_xpm), 4, 0);
+		list_set_font(ld, "-*-helvetica-medium-r-*-*-12-*-*-*-*-*-*-*", NULL, FALSE, 0, 0, 0, 200);
+
+		list_set_column_attributes(ld, 0, 30, UI_LIST_COLUMN_SIZE_FIXED | UI_LIST_COLUMN_JUSTIFY_RIGHT, "number");
+		list_set_column_attributes(ld, 1, 78, UI_LIST_COLUMN_SIZE_PROPORTIONAL, "title");
+		list_set_column_attributes(ld, 2, 30, UI_LIST_COLUMN_SIZE_FIXED | UI_LIST_COLUMN_JUSTIFY_RIGHT, "time");
+
+		wd = list_register(skin, ld, "playlist", NULL);
+
+		wd = add_button("list_playlist_scroll_up", (gchar **)btn_up_xpm, TRUE, FALSE, 313, 24, NULL, skin, NULL);
+		ui_widget_set_anchor(wd, TRUE, FALSE);
+		wd = add_slider("list_playlist_scroll", (gchar **)slider_vol_xpm,
+			       	TRUE, TRUE, TRUE, FALSE, 40, 314, 41, skin, NULL,
+				TRUE, 138, 2, 2, FALSE);
+		ui_widget_set_anchor(wd, TRUE, FALSE);
+		wd = add_button("list_playlist_scroll_down", (gchar **)btn_down_xpm, TRUE, FALSE, 313, 180, NULL, skin, NULL);
+		ui_widget_set_anchor(wd, TRUE, TRUE);
+
+		wd = add_button("skin_size", (gchar **)btn_sizer_xpm, TRUE, FALSE, 305, 210, NULL, skin, NULL);
+		ui_widget_set_anchor(wd, TRUE, TRUE);
+
+		wd = add_button("skin_iconify", (gchar **)btn_iconify_xpm, TRUE, FALSE, 301, 4, NULL, skin, NULL);
+		ui_widget_set_anchor(wd, TRUE, FALSE);
+		wd = add_button("skin_close", (gchar **)btn_exit_xpm, TRUE, FALSE, 317, 4, NULL, skin, NULL);
+		ui_widget_set_anchor(wd, TRUE, FALSE);
+
+		ds = add_digit("small",(gchar **)dig_sml_xpm, skin, NULL);
+		dl = add_digit("large",(gchar **)dig_lrg_xpm, skin, NULL);
+
+		wd = add_number("hour", 2, 0, FALSE, FALSE, 220, 192, dl, skin, NULL);
+		ui_widget_set_anchor(wd, TRUE, TRUE);
+		wd = add_number("minute", 2, 0, TRUE, FALSE, 248, 192, dl, skin, NULL);
+		ui_widget_set_anchor(wd, TRUE, TRUE);
+		wd = add_number("second", 2, 0, TRUE, FALSE, 276, 192, dl, skin, NULL);
+		ui_widget_set_anchor(wd, TRUE, TRUE);
+
+		wd = add_number("song", 3, 0, FALSE, TRUE, 240, 209, ds, skin, NULL);
+		ui_widget_set_anchor(wd, TRUE, TRUE);
+		wd = add_number("song_total", 3, 0, FALSE, TRUE, 269, 209, ds, skin, NULL);
+		ui_widget_set_anchor(wd, TRUE, TRUE);
+
+		wd = add_item("load", (gchar **)itm_load_xpm, 6, 178, 190, skin, NULL);
+		ui_widget_set_anchor(wd, TRUE, TRUE);
+
+		wd = add_button("time_remaining", (gchar **)btn_minus_xpm, TRUE, TRUE, 211, 199, NULL, skin, NULL);
+		ui_widget_set_anchor(wd, TRUE, TRUE);
+
+		skin_finalize(skin);
+		}
+	else if (key && (strcmp(key, "skindata_vert_r") == 0 || strcmp(key, "skindata_vert_l") == 0))
+		{
+		skin->real_overlay = util_size_pixbuf(gdk_pixbuf_new_from_xpm_data((const char **)back_vert_xpm), TRUE);
+
+		ds = add_digit("small",(gchar **)dig_lrg_xpm, skin, NULL);
+
+		if (strcmp(key, "skindata_vert_l") == 0)
+			{
+			add_text("title", GQMPEG_SKIN_FONT, 127, FALSE, 270, 0, 0, 0, 179, 4, 110, skin, NULL);
+			add_number("second", 2, 270, TRUE, FALSE, 4, 57, ds, skin, NULL);
+			add_number("minute", 2, 270, FALSE, FALSE, 4, 85, ds, skin, NULL);
+			add_item("dummycolon", (gchar **)itm_vcolon_xpm, 1, 8, 82, skin, NULL);
+			}
+		else
+			{
+			add_text("title", GQMPEG_SKIN_FONT, 127, FALSE, 90, 0, 0, 0, 179, 4, 58, skin, NULL);
+			add_number("minute", 2, 90, FALSE, FALSE, 5, 186, ds, skin, NULL);
+			add_number("second", 2, 90, TRUE, FALSE, 5, 214, ds, skin, NULL);
+			add_item("dummycolon", (gchar **)itm_vcolon_xpm, 1, 8, 210, skin, NULL);
+			}
+
+		add_button("play", (gchar **)btn_mplay_xpm, TRUE, TRUE, 4, 317, NULL, skin, NULL);
+		add_button("stop", (gchar **)btn_mstop_xpm, TRUE, TRUE, 4, 301, NULL, skin, NULL);
+		add_button("next", (gchar **)btn_mnext_xpm, TRUE, FALSE, 4, 280, NULL, skin, NULL);
+		add_button("prev", (gchar **)btn_mprev_xpm, TRUE, FALSE, 4, 264, NULL, skin, NULL);
+
+		add_button("playlist", (gchar **)btn_mlist_xpm, TRUE, FALSE, 4, 243, NULL, skin, NULL);
+
+		add_button("skin_iconify", (gchar **)btn_iconify_xpm, TRUE, FALSE, 4, 36, NULL, skin, NULL);
+		
+		wd = add_button("skin_toggle", (gchar **)btn_vert_xpm, TRUE, FALSE, 4, 20, NULL, skin, NULL);
+		if (strcmp(key, "skindata_vert_l") == 0)
+			{
+			ui_widget_set_data(wd, "data", "skindata_vert_r");
+			}
+		else
+			{
+			ui_widget_set_data(wd, "data", "skindata_vert_l");
+			}
+
+		add_button("skin_close", (gchar **)btn_exit_xpm, TRUE, FALSE, 4, 4, NULL, skin, NULL);
+
+		finish_simple_window(skin);
+		}
+	else if (key && strcmp(key, "skindata_alt") == 0)
 		{
 		/* small mode */
 		skin->real_overlay = util_size_pixbuf(gdk_pixbuf_new_from_xpm_data((const char **)back_mini_xpm), TRUE);
 
-		add_text("title", (gchar **)letters_xpm, 15, FALSE, FALSE, 6, 4, skin, NULL);
+		add_text("title", GQMPEG_SKIN_FONT, 90, FALSE, 0, 0, 0, 0, 179, 6, 4, skin, NULL);
 
 		add_button("playlist", (gchar **)btn_mlist_xpm, TRUE, FALSE, 174, 4, NULL, skin, NULL);
 
@@ -161,7 +356,7 @@ SkinData *skin_load_default_cb(UIData *ui, const gchar *key, gpointer data)
 		add_button("next", (gchar **)btn_mnext_xpm, TRUE, FALSE, 264, 4, NULL, skin, NULL);
 
 		add_button("skin_toggle", (gchar **)btn_mode_xpm, TRUE, FALSE, 285, 4, NULL, skin, NULL);
-		add_button("iconify", (gchar **)btn_iconify_xpm, TRUE, FALSE, 301, 4, NULL, skin, NULL);
+		add_button("skin_iconify", (gchar **)btn_iconify_xpm, TRUE, FALSE, 301, 4, NULL, skin, NULL);
 		add_button("exit", (gchar **)btn_exit_xpm, TRUE, FALSE, 317, 4, NULL, skin, NULL);
 
 		add_button("repeat", (gchar **)btn_mrepeat_xpm, TRUE, TRUE, 160, 4, NULL, skin, NULL);
@@ -172,18 +367,25 @@ SkinData *skin_load_default_cb(UIData *ui, const gchar *key, gpointer data)
 
 		ds = add_digit("small",(gchar **)dig_lrg_xpm, skin, NULL);
 
-		add_number("minute", 2, FALSE, FALSE, 106, 5, ds, skin, NULL);
-		add_number("second", 2, TRUE, FALSE, 134, 5, ds, skin, NULL);
+		add_number("minute", 2, 0, FALSE, FALSE, 106, 5, ds, skin, NULL);
+		add_number("second", 2, 0, TRUE, FALSE, 134, 5, ds, skin, NULL);
+
+		finish_simple_window(skin);
 		}
 	else
 		{
 		/* main mode */
 		skin->real_overlay = util_size_pixbuf(gdk_pixbuf_new_from_xpm_data((const char **)back_xpm), TRUE);
 
-		add_text("title", (gchar **)letters_xpm, 32, FALSE, FALSE, 104, 32, skin, NULL);
+		add_text("title", GQMPEG_SKIN_FONT, 192, FALSE, 0, 0, 0, 0, 179, 104, 32, skin, NULL);
 
 		add_button("playlist", (gchar **)btn_playlist_xpm, TRUE, FALSE, 10, 47, NULL, skin, NULL);
 
+		wd = add_button("skin_open", (gchar **)btn_list_xpm, TRUE, FALSE, 11, 27, NULL, skin, NULL);
+		ui_widget_set_data(wd, "data", "skindata_playlist");
+		wd = add_button("skin_open", (gchar **)btn_vert_xpm, TRUE, FALSE, 27, 27, NULL, skin, NULL);
+		ui_widget_set_data(wd, "data", "skindata_vert_r");
+
 		add_button("shuffle", (gchar **)btn_shuffle_xpm, TRUE, TRUE, 59, 27, NULL, skin, NULL);
 		add_button("repeat", (gchar **)btn_repeat_xpm, TRUE, TRUE, 59, 44, NULL, skin, NULL);
 		add_button("loop_ab", (gchar **)btn_ab_xpm, TRUE, TRUE, 59, 61, NULL, skin, NULL);
@@ -194,7 +396,9 @@ SkinData *skin_load_default_cb(UIData *ui, const gchar *key, gpointer data)
 		add_button("prev", (gchar **)btn_prev_xpm, TRUE, FALSE, 130, 97, NULL, skin, NULL);
 		add_button("next", (gchar **)btn_next_xpm, TRUE, FALSE, 165, 97, NULL, skin, NULL);
 
-		add_slider("position", (gchar **)slider_pos_xpm, TRUE, TRUE, FALSE, FALSE, 317, 10, 117, skin, NULL);
+		add_slider("position", (gchar **)slider_pos_xpm,
+			    TRUE, TRUE, FALSE, FALSE, 317, 10, 117, skin, NULL,
+			    FALSE, 317, 0, 0, FALSE);
 
 		add_button("preset_1", (gchar **)btn_p1_xpm, TRUE, FALSE, 11, 130, NULL, skin, NULL);
 		add_button("preset_2", (gchar **)btn_p2_xpm, TRUE, FALSE, 43, 130, NULL, skin, NULL);
@@ -209,7 +413,9 @@ SkinData *skin_load_default_cb(UIData *ui, const gchar *key, gpointer data)
 
 		add_button("config", (gchar **)btn_config_xpm, TRUE, FALSE, 311, 97, NULL, skin, NULL);
 		add_button("mixer", (gchar **)btn_mixer_xpm, TRUE, FALSE, 311, 75, NULL, skin, NULL);
-		add_slider("volume", (gchar **)slider_vol_xpm, TRUE, TRUE, TRUE, TRUE, 40, 315, 30, skin, NULL);
+		add_slider("volume", (gchar **)slider_vol_xpm,
+			   TRUE, TRUE, TRUE, TRUE, 40, 315, 30, skin, NULL,
+			   FALSE, 40, 0, 0, FALSE);
 
 		add_button("time_total", (gchar **)btn_time_xpm, TRUE, TRUE, 103, 50, NULL, skin, NULL);
 		add_button("time_remaining", (gchar **)btn_minus_xpm, TRUE, TRUE, 103, 62, NULL, skin, NULL);
@@ -217,7 +423,7 @@ SkinData *skin_load_default_cb(UIData *ui, const gchar *key, gpointer data)
 
 		wd = add_button("skin_toggle", (gchar **)btn_mode_xpm, TRUE, FALSE, 285, 4, NULL, skin, NULL);
 		ui_widget_set_data(wd, "data", "skindata_alt");
-		add_button("iconify", (gchar **)btn_iconify_xpm, TRUE, FALSE, 301, 4, NULL, skin, NULL);
+		add_button("skin_iconify", (gchar **)btn_iconify_xpm, TRUE, FALSE, 301, 4, NULL, skin, NULL);
 		add_button("exit", (gchar **)btn_exit_xpm, TRUE, FALSE, 317, 4, NULL, skin, NULL);
 
 		add_item("stereo", (gchar **)itm_stereo_xpm, 3, 233, 93, skin, NULL);
@@ -225,36 +431,26 @@ SkinData *skin_load_default_cb(UIData *ui, const gchar *key, gpointer data)
 		ds = add_digit("small",(gchar **)dig_sml_xpm, skin, NULL);
 		dl = add_digit("large",(gchar **)dig_lrg_xpm, skin, NULL);
 
-		add_number("hour", 2, FALSE, FALSE, 112, 55, dl, skin, NULL);
-		add_number("minute", 2, TRUE, FALSE, 140, 55, dl, skin, NULL);
-		add_number("second", 2, TRUE, FALSE, 169, 55, dl, skin, NULL);
+		add_number("hour", 2, 0, FALSE, FALSE, 112, 55, dl, skin, NULL);
+		add_number("minute", 2, 0, TRUE, FALSE, 140, 55, dl, skin, NULL);
+		add_number("second", 2, 0, TRUE, FALSE, 169, 55, dl, skin, NULL);
 
-		add_number("song", 4, FALSE, FALSE, 206, 55, dl, skin, NULL);
-		add_number("song_total", 3, FALSE, FALSE, 260, 55, dl, skin, NULL);
+		add_number("song", 4, 0, FALSE, FALSE, 206, 55, dl, skin, NULL);
+		add_number("song_total", 3, 0, FALSE, FALSE, 260, 55, dl, skin, NULL);
 
-		add_number("input_rate", 3, FALSE, FALSE, 214, 75, ds, skin, NULL);
-		add_number("input_hz", 2, FALSE, FALSE, 263, 75, ds, skin, NULL);
-		add_number("cpu", 2, FALSE, FALSE, 263, 91, ds, skin, NULL);
+		add_number("input_rate", 3, 0, FALSE, FALSE, 214, 75, ds, skin, NULL);
+		add_number("input_hz", 2, 0, FALSE, FALSE, 263, 75, ds, skin, NULL);
+		add_number("cpu", 2, 0, FALSE, FALSE, 263, 91, ds, skin, NULL);
 
 		add_item("load", (gchar **)itm_load_xpm, 6, 252, 48, skin, NULL);
 		add_item("time_mode", (gchar **)itm_live_xpm, 3, 172, 49, skin, NULL);
+
+		finish_simple_window(skin);
 		}
 	
-	skin->width = gdk_pixbuf_get_width(skin->real_overlay);
-	skin->height = gdk_pixbuf_get_height(skin->real_overlay);
-
-	/* this is merely to that the skin editor has sane values for these */
-	skin->width_def = skin->width_min = skin->width_max = skin->width;
-	skin->height_def = skin->height_min = skin->height_max = skin->height;
-
 	/* focus */
-	skin->focus_overlay = util_size_pixbuf(gdk_pixbuf_new_from_xpm_data((const char **)focus_xpm), TRUE);
-	skin->focus_box_alpha = 150;
-	skin->focus_has_border = TRUE;
-	skin->focus_border_left = 5;
-	skin->focus_border_right = 5;
-	skin->focus_border_bottom = 5;
-	skin->focus_border_top = 5;
+	add_focus(skin);
+	double_focus(skin);
 
 	return skin;
 }
@@ -267,14 +463,20 @@ SkinData *skin_load_default_flyby_cb(UIData *ui, const gchar *key, gpointer data
 
 	skin->real_overlay = util_size_pixbuf(gdk_pixbuf_new_from_xpm_data((const char **)flyby_back_xpm), TRUE);
 
-	add_text("title", (gchar **)letters_xpm, 31, FALSE, FALSE, 7, 7, skin, NULL);
-	add_text("artist", (gchar **)letters_xpm, 26, FALSE, FALSE, 7, 25, skin, NULL);
+	add_text("title", GQMPEG_SKIN_FONT, 236, FALSE, 0, 0, 0, 0, 179, 7, 7, skin, NULL);
+	add_text("artist", GQMPEG_SKIN_FONT, 206, FALSE, 0, 0, 0, 0, 179, 7, 25, skin, NULL);
 
-	add_button("next", (gchar **)btn_snext_xpm, TRUE, FALSE, 181, 30, NULL, skin, NULL);
-	add_button("prev", (gchar **)btn_sprev_xpm, TRUE, FALSE, 168, 30, NULL, skin, NULL);
+	add_button("next", (gchar **)btn_snext_xpm, TRUE, FALSE, 231, 30, NULL, skin, NULL);
+	add_button("prev", (gchar **)btn_sprev_xpm, TRUE, FALSE, 218, 30, NULL, skin, NULL);
 
-	skin->width = gdk_pixbuf_get_width(skin->real_overlay);
-	skin->height = gdk_pixbuf_get_height(skin->real_overlay);
+	skin->width = 250;
+	skin->height = 48;
+
+	skin->has_border = TRUE;
+	skin->border_left = 8;
+	skin->border_right = 8;
+	skin->border_top = 8;
+	skin->border_bottom = 8;
 
 	/* this is merely to that the skin editor has sane values for these */
 	skin->width_def = skin->width_min = skin->width_max = skin->width;
@@ -293,20 +495,20 @@ SkinData *skin_load_default_menu_cb(UIData *ui, const gchar *key, gpointer data)
 
 	skin->real_overlay = util_size_pixbuf(gdk_pixbuf_new_from_xpm_data((const char **)menu_back_xpm), TRUE);
 	skin->has_border = TRUE;
-	skin->border_left = 4;
-	skin->border_right = 4;
-	skin->border_top = 4;
-	skin->border_bottom = 4;
-	skin->width = 71;
-	skin->height = 22;
+	skin->border_left = 6;
+	skin->border_right = 6;
+	skin->border_top = 6;
+	skin->border_bottom = 6;
+	skin->width = 25;
+	skin->height = 24;
 
 	ld = list_new(gdk_pixbuf_new_from_xpm_data((const char **)menu_list_back_xpm),
-		      2, 2, 67, 18, TRUE, 2,
+		      3, 3, 19, 18, TRUE, 2,
 		      0, 0, 0, 0, FALSE);
 	list_image_row(ld, gdk_pixbuf_new_from_xpm_data((const char **)menu_list_row_xpm),
 		       TRUE, TRUE, 2, 2, FALSE, NULL);
 	list_image_row_flag(ld, gdk_pixbuf_new_from_xpm_data((const char **)menu_list_icons_xpm), 4, 0);
-	list_image_text(ld, gdk_pixbuf_new_from_xpm_data((const char **)letters_xpm), FALSE);
+	list_set_font(ld, GQMPEG_SKIN_FONT, NULL, FALSE, 0, 0, 0, 179);
 
 	wd = list_register(skin, ld, "menu", NULL);
 	
@@ -326,6 +528,7 @@ SkinData *skin_load_default_menu_cb(UIData *ui, const gchar *key, gpointer data)
 		ui_widget_set_data(wd, "data", "skindata_submenu");
 		}
 
+	double_window(skin);
 
 	/* this is merely to that the skin editor has sane values for these */
 	skin->width_def = skin->width_min = skin->width_max = skin->width;
@@ -340,6 +543,8 @@ SkinData *skin_load_default_menu_cb(UIData *ui, const gchar *key, gpointer data)
 	skin->focus_border_bottom = 5;
 	skin->focus_border_top = 5;
 
+	double_focus(skin);
+
 	return skin;
 }
 
