@@ -25,6 +25,8 @@ GtkWidget *songinfo_add_label_number(GtkWidget *vbox, const gchar *text, gint n,
 GtkWidget *songinfo_add_entry(GtkWidget *vbox, const gchar *label, const gchar *text,
 			      gint length, GtkSignalFunc change_cb, gpointer data);
 
+GtkWidget *songinfo_add_spin(GtkWidget *vbox, const gchar *label, gint value,
+			     gint lower, gint upper, GtkSignalFunc change_cb, gpointer data);
 
 #endif
 
