@@ -30,16 +30,24 @@ struct _ButtonData
 	gint clip_mask;
 	gint x;
 	gint y;
+	WidgetData *wd;
 	SkinData *skin;
 };
 
 
-ButtonData *button_new(GdkPixbuf *pb, gint prelight, gint light, gint x, gint y, GdkPixbuf *clip_pb);
-ButtonData *button_new_from_file(const gchar *file, gint prelight, gint light, gint x, gint y, const gchar *clip_file);
-ButtonData *button_new_from_data(gchar **data, gint prelight, gint light, gint x, gint y, gchar **clip_data);
+ButtonData *button_new(GdkPixbuf *pb, gint x, gint y,
+		       gint prelight, gint light, GdkPixbuf *clip_pb);
+ButtonData *button_new_from_file(const gchar *file, gint x, gint y,
+				 gint prelight, gint light, const gchar *clip_file);
+ButtonData *button_new_from_data(gchar **data, gint x, gint y,
+				 gint prelight, gint light, gchar **clip_data);
 void button_free(ButtonData *button);
 
 WidgetData *button_register(SkinData *skin, ButtonData *button, const gchar *key, const gchar *text_id);
+WidgetData *button_register_to_skin(const gchar *key, gchar **data, gint x, gint y,
+				    gint prelight, gint light, gchar **clip_data,
+				    SkinData *skin, const gchar *text_id);
+
 RegisterData *button_register_key(const gchar *key, UIData *ui,
 				  gint (*status_get_func)(ButtonData *button, const gchar *key, gpointer data), gpointer status_get_data,
 				  void (*button_click_func)(ButtonData *button, const gchar *key, gpointer data), gpointer button_click_data,
@@ -55,6 +63,3 @@ void button_type_init(void);
 
 #endif
 
-
-
-
