@@ -234,11 +234,11 @@ DialData *dial_new_from_file(const gchar *file, gint x, gint y,
 	GdkPixbuf *pb;
 	GdkPixbuf *clip_pb;
 
-	pb = gdk_pixbuf_new_from_file(file);
+	pb = util_pixbuf_new_from_file(file);
 
 	if (clip_file)
 		{
-		clip_pb = gdk_pixbuf_new_from_file(clip_file);
+		clip_pb = util_pixbuf_new_from_file(clip_file);
 		}
 	else
 		{
