@@ -23,6 +23,16 @@
 #include "ui_utildlg.h"
 
 
+enum {
+	DIAL_COLUMN_POINTER = 0,
+	DIAL_COLUMN_IMAGE,
+	DIAL_COLUMN_KEY,
+	DIAL_COLUMN_PRESS,
+	DIAL_COLUMN_PRELIGHT,
+	DIAL_COLUMN_COUNT
+};
+
+
 typedef struct _DialDetail DialDetail;
 struct _DialDetail
 {
@@ -102,8 +112,8 @@ struct _DialPage
 	GtkWidget *clip_mask_entry;
 	GtkWidget *item_key_entry;
 
-	GtkWidget *clist;
-	GtkWidget *pixmap;
+	GtkWidget *list;
+	GtkWidget *image;
 
 	EditData *ed;
 };
@@ -396,63 +406,63 @@ static gpointer dial_edit_props(UIData *ui, WidgetData *wd, GtkWidget *vbox, gpo
 		hbox2 = ui_edit_frame_new(hbox, TRUE, _("Rotation axis"));
 
 		dd->spin_center_x = ui_edit_spin_new(hbox2, _("x:"), -1000, 1000, &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(dial_edit_props_spin_cb), dd);
+		g_signal_connect(adj, "value_changed",
+				 G_CALLBACK(dial_edit_props_spin_cb), dd);
 
 		dd->spin_center_y = ui_edit_spin_new(hbox2, _("y:"), -1000, 1000, &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(dial_edit_props_spin_cb), dd);
+		g_signal_connect(adj, "value_changed",
+				 G_CALLBACK(dial_edit_props_spin_cb), dd);
 
 		hbox2 = ui_edit_frame_new(hbox, TRUE, _("Handle rotation axis"));
 
 		dd->spin_handle_x = ui_edit_spin_new(hbox2, _("x:"), -1000, 1000, &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(dial_edit_props_spin_cb), dd);
+		g_signal_connect(adj, "value_changed",
+				 G_CALLBACK(dial_edit_props_spin_cb), dd);
 
 		dd->spin_handle_y = ui_edit_spin_new(hbox2, _("y:"), -1000, 1000, &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(dial_edit_props_spin_cb), dd);
+		g_signal_connect(adj, "value_changed",
+				 G_CALLBACK(dial_edit_props_spin_cb), dd);
 
 		hbox = ui_edit_frame_new(vbox, TRUE, _("Endpoints"));
 
 		dd->spin_begin = ui_edit_spin_new(hbox, _("begin:"), 0, 359, &adj);
 		gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(dd->spin_begin), TRUE);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(dial_edit_props_spin_cb), dd);
+		g_signal_connect(adj, "value_changed",
+				 G_CALLBACK(dial_edit_props_spin_cb), dd);
 
 		dd->spin_end = ui_edit_spin_new(hbox, _("end:"), 0, 359, &adj);
 		gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(dd->spin_end), TRUE);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(dial_edit_props_spin_cb), dd);
+		g_signal_connect(adj, "value_changed",
+				 G_CALLBACK(dial_edit_props_spin_cb), dd);
 
 		dd->reverse_button = ui_edit_toggle_new(hbox, _("Reverse"));
-		gtk_signal_connect(GTK_OBJECT(dd->reverse_button), "clicked",
-				   GTK_SIGNAL_FUNC(dial_edit_props_reversed_cb), dd);
+		g_signal_connect(GTK_OBJECT(dd->reverse_button), "clicked",
+				 G_CALLBACK(dial_edit_props_reversed_cb), dd);
 
 		hbox = ui_edit_frame_new(vbox, TRUE, _("Clipping area"));
 
 		dd->spin_clip_w = ui_edit_spin_new(hbox, _("width:"), 1, 2000, &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(dial_edit_props_spin_cb), dd);
+		g_signal_connect(adj, "value_changed",
+				 G_CALLBACK(dial_edit_props_spin_cb), dd);
 
 		dd->spin_clip_h = ui_edit_spin_new(hbox, _("height:"), 1, 2000, &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(dial_edit_props_spin_cb), dd);
+		g_signal_connect(adj, "value_changed",
+				 G_CALLBACK(dial_edit_props_spin_cb), dd);
 
 		hbox = ui_edit_frame_new(vbox, FALSE, NULL);
 		
 		dd->fixed_button = ui_edit_toggle_new(hbox, _("Fixed handle"));
-		gtk_signal_connect(GTK_OBJECT(dd->fixed_button), "clicked",
-				   GTK_SIGNAL_FUNC(dial_edit_props_fixed_cb), dd);
+		g_signal_connect(GTK_OBJECT(dd->fixed_button), "clicked",
+				 G_CALLBACK(dial_edit_props_fixed_cb), dd);
 		dd->radius_spin = ui_edit_spin_new(hbox, _("Radius:"), 1, 2000, &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(dial_edit_props_radius_cb), dd);
+		g_signal_connect(adj, "value_changed",
+				 G_CALLBACK(dial_edit_props_radius_cb), dd);
 
 		hbox = ui_edit_frame_new(vbox, FALSE, NULL);
 
 		dd->item_key_entry = ui_edit_entry_new(hbox, _("Item link key:"));
-		gtk_signal_connect(GTK_OBJECT(dd->item_key_entry), "changed",
-				   GTK_SIGNAL_FUNC(dial_edit_props_item_key_cb), dd);
+		g_signal_connect(G_OBJECT(dd->item_key_entry), "changed",
+				 G_CALLBACK(dial_edit_props_item_key_cb), dd);
 		}
 
 	dd->dial = dial;
@@ -567,12 +577,16 @@ static void dial_edit_page_sync(DialPage *pd, DialListData *dd)
 	ui_edit_entry_set(pd->item_key_entry, dd->item_key);
 }
 
-static void dial_edit_page_clist_cb(GtkWidget *clist, gint row, gint col, GdkEvent *event, gpointer data)
+static void dial_edit_page_list_cb(GtkTreeSelection *selection, gpointer data)
 {
 	DialPage *pd = data;
 	DialListData *dd;
+	GtkTreeModel *store;
+	GtkTreeIter iter;
 
-	dd = gtk_clist_get_row_data(GTK_CLIST(clist), row);
+	if (!gtk_tree_selection_get_selected(selection, &store, &iter)) return;
+
+	gtk_tree_model_get(store, &iter, DIAL_COLUMN_POINTER, &dd, -1);
 	dial_edit_page_sync(pd, dd);
 }
 
@@ -607,16 +621,16 @@ static GtkWidget *dial_edit_page_new(EditData *ed)
 	GtkWidget *vbox;
 	GtkWidget *button;
 	DialPage *pd;
-	gchar *titles[] = { _("Image"), _("Key"), _("Press"), _("Prelight"), NULL };
+	GtkListStore *store;
 
 	pd = g_new0(DialPage, 1);
 	pd->ed = ed;
 
 	hbox = gtk_hbox_new(FALSE, 5);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
-	gtk_object_set_data(GTK_OBJECT(hbox), "page", pd);
-	gtk_signal_connect(GTK_OBJECT(hbox), "destroy",
-			   GTK_SIGNAL_FUNC(dial_edit_page_destroy_cb), pd);
+	g_object_set_data(G_OBJECT(hbox), "page", pd);
+	g_signal_connect(G_OBJECT(hbox), "destroy",
+			 G_CALLBACK(dial_edit_page_destroy_cb), pd);
 
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
@@ -646,8 +660,8 @@ static GtkWidget *dial_edit_page_new(EditData *ed)
 	pd->clip_h_spin = ui_edit_spin_new(frame, _("height:"), 1, 2000, NULL);
 
 	pd->clip_mask_entry = ui_edit_path_entry_new(vbox, _("Clip mask:"), "SLIK_dial_clip_mask");
-	gtk_signal_connect(GTK_OBJECT(pd->clip_mask_entry), "changed",
-			   GTK_SIGNAL_FUNC(dial_edit_page_clip_cb), pd);
+	g_signal_connect(G_OBJECT(pd->clip_mask_entry), "changed",
+			 G_CALLBACK(dial_edit_page_clip_cb), pd);
 
 	frame = ui_edit_frame_new(vbox, TRUE, _("Handle rotation axis"));
 	pd->offset_x_spin = ui_edit_spin_new(frame, _("x:"), -2000, 2000, NULL);
@@ -655,26 +669,33 @@ static GtkWidget *dial_edit_page_new(EditData *ed)
 
 	frame = ui_edit_frame_new(vbox, FALSE, NULL);
 	pd->fixed_button = ui_edit_toggle_new(frame, _("Fixed handle"));
-	gtk_signal_connect(GTK_OBJECT(pd->fixed_button), "clicked",
-			   GTK_SIGNAL_FUNC(dial_edit_page_fixed_cb), pd);
+	g_signal_connect(G_OBJECT(pd->fixed_button), "clicked",
+			 G_CALLBACK(dial_edit_page_fixed_cb), pd);
 	pd->radius_spin = ui_edit_spin_new(frame, _("Radius:"), 1, 2000, NULL);
 	ui_edit_frame_sensitive(pd->radius_spin, FALSE, TRUE);
 
 	pd->image_entry = ui_edit_path_entry_new(vbox, _("Image:"), "SLIK_dial_image");
-	pd->pixmap = ui_edit_pixmap_new(vbox);
-	ui_edit_path_entry_connect_pixmap(pd->image_entry, pd->pixmap);
+	pd->image = ui_edit_image_new(vbox);
+	ui_edit_path_entry_connect_image(pd->image_entry, pd->image);
 
 	pd->item_key_entry = ui_edit_entry_new(vbox, _("Item link key:"));
 
 	button = gtk_button_new_with_label(_("Add"));
 	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			   GTK_SIGNAL_FUNC(dial_edit_page_add_cb), pd);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(dial_edit_page_add_cb), pd);
 	gtk_widget_show(button);
 
-	pd->clist = ui_edit_clist_new(hbox, titles, 4);
-	gtk_signal_connect(GTK_OBJECT(pd->clist), "select_row",
-			   GTK_SIGNAL_FUNC(dial_edit_page_clist_cb), pd);
+	store = gtk_list_store_new(5, G_TYPE_POINTER, GDK_TYPE_PIXBUF, G_TYPE_STRING,
+				      G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
+	pd->list = ui_edit_list_new(hbox, store,
+				    G_CALLBACK(dial_edit_page_list_cb), pd);
+	g_object_unref(store);
+
+	ui_edit_list_add_column(pd->list, _("Image"), DIAL_COLUMN_IMAGE, TRUE, FALSE);
+	ui_edit_list_add_column(pd->list, _("Key"), DIAL_COLUMN_KEY, FALSE, FALSE);
+	ui_edit_list_add_column(pd->list, _("Press"), DIAL_COLUMN_PRESS, FALSE, FALSE);
+	ui_edit_list_add_column(pd->list, _("Prelight"), DIAL_COLUMN_PRELIGHT, FALSE, FALSE);
 
 	gtk_widget_show(hbox);
 
@@ -685,17 +706,24 @@ static void dial_edit_page_add(GtkWidget *widget, gpointer data)
 {
 	DialListData *dd = data;
 	DialPage* pd;
-	gchar *buf[5];
+	GtkListStore *store;
+	GtkTreeIter iter;
+	GdkPixbuf *pixbuf;
 
-	pd = gtk_object_get_data(GTK_OBJECT(widget), "page");
+	pd = g_object_get_data(G_OBJECT(widget), "page");
+	store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(pd->list)));
 
-	buf[0] = "";
-	buf[1] = dd->key;
-	buf[2] = ui_edit_bool_to_text(dd->has_press);
-	buf[3] = ui_edit_bool_to_text(dd->has_prelight);
-	buf[4] = NULL;
+	pixbuf = ui_edit_list_pixbuf_from_file(dd->image);
 
-	ui_edit_clist_append(pd->clist, buf, dd->image, dd);
+	gtk_list_store_append(store, &iter);
+	gtk_list_store_set(store, &iter,
+			   DIAL_COLUMN_POINTER, dd,
+			   DIAL_COLUMN_IMAGE, pixbuf,
+			   DIAL_COLUMN_KEY, dd->key,
+			   DIAL_COLUMN_PRESS, dd->has_press,
+			   DIAL_COLUMN_PRELIGHT, dd->has_prelight, -1);
+
+	if (pixbuf) gdk_pixbuf_unref(pixbuf);
 }
 
 void dial_type_init_edit(WidgetObjectData *od)
