@@ -192,15 +192,18 @@ void ui_display_sync_shape(UIData *ui)
 {
 	if (!ui->skin) return;
 
-	gtk_drawing_area_size(GTK_DRAWING_AREA(ui->display), ui->skin->width, ui->skin->height);
-
 	if (ui->window)
 		{
 		if (slik_allow_shapes)
 			{
 			gtk_widget_shape_combine_mask(ui->window, ui->skin->mask_buffer, 0, 0);
 			}
-		gtk_widget_set_usize(ui->window, ui->skin->width, ui->skin->height);
+		gtk_widget_set_size_request(ui->display, ui->skin->width, ui->skin->height);
+		gtk_window_resize(GTK_WINDOW(ui->window), ui->skin->width, ui->skin->height);
+
+		/* wonder why this is here? Try removing it and changing skin to a new size */
+		gdk_window_resize(ui->display->window, ui->skin->width, ui->skin->height);
+		gdk_window_resize(ui->window->window, ui->skin->width, ui->skin->height);
 		}
 	else
 		{
@@ -208,7 +211,7 @@ void ui_display_sync_shape(UIData *ui)
 			{
 			gtk_widget_shape_combine_mask(ui->display, ui->skin->mask_buffer, 0, 0);
 			}
-		gtk_widget_set_usize(ui->display, ui->skin->width, ui->skin->height);
+		gtk_widget_set_size_request(ui->display, ui->skin->width, ui->skin->height);
 		}
 }
 
@@ -635,11 +638,35 @@ static gint ui_display_key_press(GtkWidget *w, GdkEventKey *event, gpointer data
 			}
 		}
 
+#if 0
 	if (ret) gtk_signal_emit_stop_by_name(GTK_OBJECT(w), "key_press_event");
+#endif
 
 	return ret;
 }
 
+static gint ui_display_scrolled(GtkWidget *widget, GdkEventScroll *event, gpointer data)
+{
+	UIData *ui = data;
+	gint button = -1;
+
+	if (event->direction == GDK_SCROLL_UP)
+		{
+		button = 4;
+		}
+	else if (event->direction == GDK_SCROLL_DOWN)
+		{
+		button = 5;
+		}
+
+	if (ui->click_func && button > 0)
+		{
+		ui->click_func(ui, button, event->time, ui->click_data);
+		}
+
+	return TRUE;
+}
+
 static gint ui_display_focus_in(GtkWidget *widget, GdkEventFocus *event, gpointer data)
 {
 	UIData *ui = data;
@@ -877,34 +904,36 @@ void ui_display_events_init(UIData *ui)
 	gtk_widget_set_events(ui->display, GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK |
 			      GDK_POINTER_MOTION_MASK | 
 			      GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
-	gtk_signal_connect(GTK_OBJECT(ui->display),"motion_notify_event",
-			   GTK_SIGNAL_FUNC(ui_display_motion), ui);
-	gtk_signal_connect(GTK_OBJECT(ui->display),"button_press_event",
-			   GTK_SIGNAL_FUNC(ui_display_pressed), ui);
-	gtk_signal_connect(GTK_OBJECT(ui->display),"button_release_event",
-			   GTK_SIGNAL_FUNC(ui_display_released), ui);
-	gtk_signal_connect(GTK_OBJECT(ui->display),"leave_notify_event",
-			   GTK_SIGNAL_FUNC(ui_display_leave), ui);
+	g_signal_connect(G_OBJECT(ui->display),"motion_notify_event",
+			 G_CALLBACK(ui_display_motion), ui);
+	g_signal_connect(G_OBJECT(ui->display),"button_press_event",
+			 G_CALLBACK(ui_display_pressed), ui);
+	g_signal_connect(G_OBJECT(ui->display),"button_release_event",
+			 G_CALLBACK(ui_display_released), ui);
+	g_signal_connect(G_OBJECT(ui->display),"leave_notify_event",
+			 G_CALLBACK(ui_display_leave), ui);
 
-	gtk_signal_connect(GTK_OBJECT(ui->display),"key_press_event",
-			   GTK_SIGNAL_FUNC(ui_display_key_press), ui);
+	g_signal_connect(G_OBJECT(ui->display),"key_press_event",
+			 G_CALLBACK(ui_display_key_press), ui);
+	g_signal_connect(G_OBJECT(ui->display),"scroll_event",
+			 G_CALLBACK(ui_display_scrolled), ui);
 
-	gtk_signal_connect(GTK_OBJECT(ui->display),"focus_in_event",
-			   GTK_SIGNAL_FUNC(ui_display_focus_in), ui);
-	gtk_signal_connect(GTK_OBJECT(ui->display),"focus_out_event",
-			   GTK_SIGNAL_FUNC(ui_display_focus_out), ui);
+	g_signal_connect(G_OBJECT(ui->display),"focus_in_event",
+			 G_CALLBACK(ui_display_focus_in), ui);
+	g_signal_connect(G_OBJECT(ui->display),"focus_out_event",
+			 G_CALLBACK(ui_display_focus_out), ui);
 
 	ui->active_widget = NULL;
 	ui->in_press = FALSE;
 	ui->in_move = FALSE;
 
 	/* the expose event */
-	gtk_signal_connect(GTK_OBJECT(ui->display), "expose_event",
-			   GTK_SIGNAL_FUNC(ui_display_expose), ui);
+	g_signal_connect(GTK_OBJECT(ui->display), "expose_event",
+			   G_CALLBACK(ui_display_expose), ui);
 	if (ui->window)
 		{
-		gtk_signal_connect(GTK_OBJECT(ui->window), "configure_event",
-				   GTK_SIGNAL_FUNC(ui_display_move), ui);
+		g_signal_connect(GTK_OBJECT(ui->window), "configure_event",
+				   G_CALLBACK(ui_display_move), ui);
 		}
 }
 
