@@ -19,8 +19,8 @@ GtkWidget *ui_edit_vframe_new(GtkWidget *box, gint has_frame, const gchar *text)
 
 GtkWidget *ui_edit_label_new(GtkWidget *box, const gchar *text);
 
-GtkWidget *ui_edit_pixmap_new(GtkWidget *box);
-void ui_edit_pixmap_blank(GtkWidget *pmap);
+GtkWidget *ui_edit_image_new(GtkWidget *box);
+void ui_edit_image_blank(GtkWidget *image);
 
 GtkWidget *ui_edit_toggle_new(GtkWidget *box, const gchar *text);
 void ui_edit_toggle_set(GtkWidget *button, gint active);
@@ -30,7 +30,7 @@ gint ui_edit_toggle_get(GtkWidget *button);
 GtkWidget *ui_edit_font_entry_new(GtkWidget *box, const gchar *text);
 
 GtkWidget *ui_edit_path_entry_new(GtkWidget *box, const gchar *text, const gchar *history_key);
-void ui_edit_path_entry_connect_pixmap(GtkWidget *entry, GtkWidget *pmap);
+void ui_edit_path_entry_connect_image(GtkWidget *entry, GtkWidget *image);
 
 GtkWidget *ui_edit_key_entry_new(GtkWidget *box, UIData *ui, WidgetType type);
 
@@ -44,8 +44,12 @@ void ui_edit_spin_set(GtkWidget *spin, gint value);
 void ui_edit_spin_set_blocking(GtkWidget *spin, gint val, gpointer block_data);
 gint ui_edit_spin_get(GtkWidget *spin);
 
-GtkWidget *ui_edit_clist_new(GtkWidget *box, gchar *titles[], gint columns);
-gint ui_edit_clist_append(GtkWidget *clist, gchar *buf[], const gchar *image, gpointer data);
+GtkWidget *ui_edit_list_new(GtkWidget *box, GtkListStore *store,
+                            GtkSignalFunc changed_func, gpointer changed_data);
+void ui_edit_list_add_column(GtkWidget *treeview, const gchar *title, gint column_id,
+			     gint image, gint right_justify);
+GdkPixbuf *ui_edit_list_pixbuf_from_file(const gchar *image);
+
 gchar *ui_edit_bool_to_text(gint enable);
 gchar *ui_edit_int_to_text(gint value);
 
