@@ -80,7 +80,7 @@ ItemData *item_new_from_file(const gchar *file, gint x, gint y, gint sections)
 {
 	GdkPixbuf *pb;
 
-	pb = gdk_pixbuf_new_from_file(file);
+	pb = util_pixbuf_new_from_file(file);
 
 	return item_new(pb, x, y, sections);
 }
