@@ -28,12 +28,16 @@ struct _ItemData
 };
 
 
-ItemData *item_new(GdkPixbuf *pb, gint sections, gint x, gint y);
-ItemData *item_new_from_data(gchar **data, gint sections, gint x, gint y);
-ItemData *item_new_from_file(const gchar *file, gint sections, gint x, gint y);
+ItemData *item_new(GdkPixbuf *pb, gint x, gint y, gint sections);
+ItemData *item_new_from_data(gchar **data, gint x, gint y, gint sections);
+ItemData *item_new_from_file(const gchar *file, gint x, gint y, gint sections);
 void item_free(ItemData *item);
 
 WidgetData *item_register(SkinData *skin, ItemData *item, const gchar *key, const gchar *text_id);
+WidgetData *item_register_to_skin(const gchar *key, gchar **data, gint x, gint y,
+				  gint sections,
+				  SkinData *skin, const gchar *text_id);
+
 RegisterData *item_register_key(const gchar *key, UIData *ui,
 				gint (*status_get_func)(ItemData *item, const gchar *key, gpointer data), gpointer status_get_data);
 
