@@ -228,7 +228,7 @@ void list_free(ListData *ld)
 
 	if (!ld) return;
 
-	if (ld->timeout_id != -1) gtk_timeout_remove(ld->timeout_id);
+	if (ld->timeout_id != -1) g_source_remove(ld->timeout_id);
 	if (ld->scroll_idle_id != -1) gtk_idle_remove(ld->scroll_idle_id);
 
 	if (ld->overlay) gdk_pixbuf_unref(ld->overlay);
@@ -1041,6 +1041,7 @@ static gint list_press(gpointer data, const gchar *key, gint x, gint y, GdkPixbu
 	if (list_test_proximity(ld, x, y))
 		{
 		ListRowData *rd;
+		GdkEvent *event;
 		guint32 t;
 		gint row;
 
@@ -1052,7 +1053,17 @@ static gint list_press(gpointer data, const gchar *key, gint x, gint y, GdkPixbu
 		ld->press_y = y;
 		ld->in_drag = FALSE;
 
-		t = gdk_time_get();
+		/* peek at current event's time */
+		event = gtk_get_current_event();
+		if (event)
+			{
+			t = gdk_event_get_time(event);
+			gdk_event_free(event);
+			}
+		else
+			{
+			t = 0;
+			}
 
 		rd = g_list_nth_data(ld->row_list, row - ld->row_start);
 		if (rd)
@@ -1461,26 +1472,26 @@ static WidgetData *list_parse(SkinData *skin, GList *list, const gchar *skin_dir
 
 	util_color(&r, &g, &b, NULL);
 
-	ld = list_new(gdk_pixbuf_new_from_file(filename), x, y, w, h, sizeable, columns,
+	ld = list_new(util_pixbuf_new_from_file(filename), x, y, w, h, sizeable, columns,
 		      border_top, border_right, border_bottom, border_left, center_stretch);
 	if (ld)
 		{
 		gint i;
 
-		list_image_row(ld, gdk_pixbuf_new_from_file(row_filename), row_press, row_prelight,
+		list_image_row(ld, util_pixbuf_new_from_file(row_filename), row_press, row_prelight,
 			       row_border_left, row_border_right, row_stretch,
-			       divider_filename ? gdk_pixbuf_new_from_file(divider_filename) : NULL);
+			       divider_filename ? util_pixbuf_new_from_file(divider_filename) : NULL);
 
 		if (text_filename)
 			{
-			list_set_font(ld, NULL, gdk_pixbuf_new_from_file(text_filename), text_extended, r, g, b, a);
+			list_set_font(ld, NULL, util_pixbuf_new_from_file(text_filename), text_extended, r, g, b, a);
 			}
 		else
 			{
 			list_set_font(ld, font_desc, NULL, FALSE, r, g, b, a);
 			}
 
-		if (flag_filename) list_image_row_flag(ld, gdk_pixbuf_new_from_file(flag_filename), flag_sections, flag_column);
+		if (flag_filename) list_image_row_flag(ld, util_pixbuf_new_from_file(flag_filename), flag_sections, flag_column);
 
 		list_set_column_justify(ld, columns_right_justify);
 
@@ -1771,7 +1782,7 @@ static void list_scroll_timeout_cancel(ListData *ld)
 {
 	if (ld->timeout_id != -1)
 		{
-		gtk_timeout_remove(ld->timeout_id);
+		g_source_remove(ld->timeout_id);
 		ld->timeout_id = -1;
 		}
 	ld->scroll_count = 0;
@@ -1788,7 +1799,8 @@ static gint list_scroll_button_down_delay(gpointer data)
 		ld->scroll_count++;
 		if (ld->scroll_count >= UI2_LIST_SCROLL_SPEEDUP)
 			{
-			ld->timeout_id = gtk_timeout_add(UI2_LIST_SCROLL_DELAY_FAST, list_scroll_button_down_delay, ld);
+			ld->timeout_id = g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, UI2_LIST_SCROLL_DELAY_FAST,
+							    list_scroll_button_down_delay, ld, NULL);
 			return FALSE;
 			}
 		}
@@ -1802,7 +1814,8 @@ static void list_scroll_button_down_press(ButtonData *button, const gchar *key,
 
 	list_row_scroll_by_row(ld, skin_get_pixbuf(ld->ui->skin), ld->ui, ld->wd->key, 1);
 	list_scroll_timeout_cancel(ld);
-	ld->timeout_id = gtk_timeout_add(UI2_LIST_SCROLL_DELAY, list_scroll_button_down_delay, ld);
+	ld->timeout_id = g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, UI2_LIST_SCROLL_DELAY,
+					    list_scroll_button_down_delay, ld, NULL);
 }
 
 static void list_scroll_button_down_release(ButtonData *button, const gchar *key, gpointer data)
@@ -1823,7 +1836,8 @@ static gint list_scroll_button_up_delay(gpointer data)
 		ld->scroll_count++;
 		if (ld->scroll_count >= UI2_LIST_SCROLL_SPEEDUP)
 			{
-			ld->timeout_id = gtk_timeout_add(UI2_LIST_SCROLL_DELAY_FAST, list_scroll_button_up_delay, ld);
+			ld->timeout_id = g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, UI2_LIST_SCROLL_DELAY_FAST,
+							    list_scroll_button_up_delay, ld, NULL);
 			return FALSE;
 			}
 		}
@@ -1837,7 +1851,8 @@ static void list_scroll_button_up_press(ButtonData *button, const gchar *key, gp
 
 	list_row_scroll_by_row(ld, skin_get_pixbuf(ld->ui->skin), ld->ui, ld->wd->key, -1);
 	list_scroll_timeout_cancel(ld);
-	ld->timeout_id = gtk_timeout_add(UI2_LIST_SCROLL_DELAY, list_scroll_button_up_delay, ld);
+	ld->timeout_id = g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, UI2_LIST_SCROLL_DELAY,
+					    list_scroll_button_up_delay, ld, NULL);
 }
 
 static void list_scroll_button_up_release(ButtonData *button, const gchar *key, gpointer data)
