@@ -16,17 +16,36 @@
 #include "ui2_list_edit.h"
 
 #include "ui2_editor.h"
+#include "ui2_util.h"
 #include "ui2_widget.h"
-#include "ui_clist_edit.h"
 #include "ui_fileops.h"
 #include "ui_pixbuf_ops.h"
 #include "ui_tabcomp.h"
 #include "ui_utildlg.h"
+#include "ui_tree_edit.h"
 
 #include "ui2_button.h"
 #include "ui2_slider.h"
 
 
+enum {
+	LIST_COLUMN_POINTER = 0,
+	LIST_COLUMN_IMAGE,
+	LIST_COLUMN_KEY,
+	LIST_COLUMN_FLAG,
+	LIST_COLUMN_COUNT
+};
+
+enum {
+	COL_COLUMN_NUMBER = 0,
+	COL_COLUMN_KEY,
+	COL_COLUMN_WIDTH,
+	COL_COLUMN_DYNAMIC,
+	COL_COLUMN_JUSTIFY,
+	COL_COLUMN_COUNT
+};
+
+
 typedef struct _ListDetail ListDetail;
 struct _ListDetail
 {
@@ -68,7 +87,7 @@ struct _ListDetail
 	GtkWidget *height_spin;
 
 	GtkWidget *column_count_spin;
-	GtkWidget *column_clist;
+	GtkWidget *column_list;
 	GtkWidget *columns_right_toggle;
 
 	WidgetData *wd;
@@ -144,7 +163,7 @@ struct _ListPage
 	GtkWidget *text_id_entry;
 	GtkWidget *data_entry;
 
-	GtkWidget *clist;
+	GtkWidget *list;
 
 	GList *column_list;		/* list of column attributes ListPageColumn pointers */
 
@@ -396,15 +415,12 @@ static void list_details_pack(ListDetail *dt, GtkWidget *vbox, gint add_page)
 	GtkWidget *page;
 	GtkWidget *label;
 	GtkWidget *hbox;
-	GtkWidget *hbox2;
 	GtkWidget *vbox2;
-	GtkWidget *scrolled;
-	GtkWidget *pixmap;
-	gint i;
-	gchar *clist_titles[] = { _("#"), _("Key"), _("Width"), _("Dynamic"), _("Justify"), NULL };
+	GtkWidget *image;
+	GtkListStore *store;
 
 	notebook = gtk_notebook_new();
-	gtk_box_pack_start(GTK_BOX(vbox), notebook, FALSE, FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(vbox), notebook, TRUE, TRUE, 5);
 
 	page = gtk_vbox_new(FALSE, 5);
 	gtk_container_set_border_width(GTK_CONTAINER(page), 5);
@@ -412,8 +428,8 @@ static void list_details_pack(ListDetail *dt, GtkWidget *vbox, gint add_page)
 	if (add_page)
 		{
 		dt->image_entry = ui_edit_path_entry_new(page, _("Image:"), "SLIK_list_image");
-		pixmap = ui_edit_pixmap_new(page);
-		ui_edit_path_entry_connect_pixmap(dt->image_entry, pixmap);
+		image = ui_edit_image_new(page);
+		ui_edit_path_entry_connect_image(dt->image_entry, image);
 		}
 
 	hbox = ui_edit_frame_new(page, FALSE, NULL);
@@ -443,8 +459,8 @@ static void list_details_pack(ListDetail *dt, GtkWidget *vbox, gint add_page)
 	gtk_container_set_border_width(GTK_CONTAINER(page), 5);
 
 	dt->row_image_entry = ui_edit_path_entry_new(page, _("Image:"), "SLIK_list_row_image");
-	pixmap = ui_edit_pixmap_new(page);
-	ui_edit_path_entry_connect_pixmap(dt->row_image_entry, pixmap);
+	image = ui_edit_image_new(page);
+	ui_edit_path_entry_connect_image(dt->row_image_entry, image);
 
 	hbox = ui_edit_frame_new(page, TRUE, _("Border"));
 
@@ -463,20 +479,19 @@ static void list_details_pack(ListDetail *dt, GtkWidget *vbox, gint add_page)
 	page = gtk_vbox_new(FALSE, 5);
 	gtk_container_set_border_width(GTK_CONTAINER(page), 5);
 
-	hbox = ui_edit_vframe_new(page, FALSE, NULL);
-	dt->text_font_entry = ui_edit_font_entry_new(hbox, _("Font:"));
-	dt->text_image_entry = ui_edit_path_entry_new(hbox, _("Image:"), "SLIK_list_text_image");
-	pixmap = ui_edit_pixmap_new(hbox);
-	ui_edit_path_entry_connect_pixmap(dt->text_image_entry, pixmap);
+	dt->text_font_entry = ui_edit_font_entry_new(page, _("Font:"));
+	dt->text_image_entry = ui_edit_path_entry_new(page, _("Image:"), "SLIK_list_text_image");
+	image = ui_edit_image_new(page);
+	ui_edit_path_entry_connect_image(dt->text_image_entry, image);
 
-	dt->text_extended_button = ui_edit_toggle_new(hbox, _("Extended"));
+	dt->text_extended_button = ui_edit_toggle_new(page, _("Extended"));
 
-	hbox2 = ui_edit_frame_new(hbox, TRUE, _("Color:"));
-	dt->text_font_r = ui_edit_spin_new(hbox2, _("Red:"), 0, 255, NULL);
-	dt->text_font_g = ui_edit_spin_new(hbox2, _("Green:"), 0, 255, NULL);
-	dt->text_font_b = ui_edit_spin_new(hbox2, _("Blue:"), 0, 255, NULL);
+	hbox = ui_edit_frame_new(page, TRUE, _("Color:"));
+	dt->text_font_r = ui_edit_spin_new(hbox, _("Red:"), 0, 255, NULL);
+	dt->text_font_g = ui_edit_spin_new(hbox, _("Green:"), 0, 255, NULL);
+	dt->text_font_b = ui_edit_spin_new(hbox, _("Blue:"), 0, 255, NULL);
 
-	dt->text_font_a = ui_edit_spin_new(hbox, _("Alpha:"), 0, 255, NULL);
+	dt->text_font_a = ui_edit_spin_new(page, _("Alpha:"), 0, 255, NULL);
 
 	label = gtk_label_new(_("Text"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), page, label);
@@ -487,18 +502,16 @@ static void list_details_pack(ListDetail *dt, GtkWidget *vbox, gint add_page)
 
 	dt->column_count_spin = ui_edit_spin_new(page, _("Columns:"), 1, 20, NULL);
 
-	scrolled = gtk_scrolled_window_new(NULL, NULL);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_box_pack_start(GTK_BOX(page), scrolled, TRUE, TRUE, 0);
-	gtk_widget_show(scrolled);
+	store = gtk_list_store_new(5, G_TYPE_INT, G_TYPE_STRING, G_TYPE_INT,
+				      G_TYPE_BOOLEAN, G_TYPE_STRING);
+	dt->column_list = ui_edit_list_new(page, store, NULL, dt);
+	g_object_unref(store);
 
-	dt->column_clist = gtk_clist_new_with_titles(5, clist_titles);
-	for (i = 0; i < 5; i++)
-		{
-		gtk_clist_set_column_auto_resize(GTK_CLIST(dt->column_clist), i, TRUE);
-		}
-	gtk_container_add(GTK_CONTAINER(scrolled), dt->column_clist);
-	gtk_widget_show(dt->column_clist);
+	ui_edit_list_add_column(dt->column_list, _("#"), COL_COLUMN_NUMBER, FALSE, FALSE);
+	ui_edit_list_add_column(dt->column_list, _("Key"), COL_COLUMN_KEY, FALSE, FALSE);
+	ui_edit_list_add_column(dt->column_list, _("Width"), COL_COLUMN_WIDTH, FALSE, FALSE);
+	ui_edit_list_add_column(dt->column_list, _("Dynamic"), COL_COLUMN_DYNAMIC, FALSE, FALSE);
+	ui_edit_list_add_column(dt->column_list, _("Justify"), COL_COLUMN_JUSTIFY, FALSE, FALSE);
 
 	dt->flag_column_spin = ui_edit_spin_new(page, _("Flag column:"), 0, 19, NULL);
 	dt->columns_right_toggle = ui_edit_toggle_new(page, _("Right justify"));
@@ -512,13 +525,13 @@ static void list_details_pack(ListDetail *dt, GtkWidget *vbox, gint add_page)
 
 	hbox = ui_edit_vframe_new(page, TRUE, _("Column divider"));
 	dt->divider_image_entry = ui_edit_path_entry_new(hbox, _("Image:"), "SLIK_list_divider_image");
-	pixmap = ui_edit_pixmap_new(hbox);
-	ui_edit_path_entry_connect_pixmap(dt->divider_image_entry, pixmap);
+	image = ui_edit_image_new(hbox);
+	ui_edit_path_entry_connect_image(dt->divider_image_entry, image);
 
 	hbox = ui_edit_vframe_new(page, TRUE, _("Flags"));
 	dt->flag_image_entry = ui_edit_path_entry_new(hbox, _("Image:"), "SLIK_list_flag_image");
-	pixmap = ui_edit_pixmap_new(hbox);
-	ui_edit_path_entry_connect_pixmap(dt->flag_image_entry, pixmap);
+	image = ui_edit_image_new(hbox);
+	ui_edit_path_entry_connect_image(dt->flag_image_entry, image);
 
 	dt->flag_sections_spin = ui_edit_spin_new(hbox, _("Sections:"), 1, 100, NULL);
 
@@ -530,54 +543,45 @@ static void list_details_pack(ListDetail *dt, GtkWidget *vbox, gint add_page)
 }
 
 
-static void list_props_clist_update(ListDetail *dt, gint row)
+static void list_props_list_update(ListDetail *dt, gint row)
 {
-	gchar *buf;
+	GtkTreeModel *store;
+	GtkTreeIter iter;
+
+	store = gtk_tree_view_get_model(GTK_TREE_VIEW(dt->column_list));
+	if (row >= dt->ld->column_count ||
+	    !gtk_tree_model_iter_nth_child(store, &iter, NULL, row)) return;
+
+	gtk_list_store_set(GTK_LIST_STORE(store), &iter,
+			   COL_COLUMN_NUMBER, row,
+			   COL_COLUMN_KEY, dt->ld->column_keys[row],
+			   COL_COLUMN_WIDTH, dt->ld->column_widths[row],
+			   COL_COLUMN_DYNAMIC, (dt->ld->column_flags[row] & UI_LIST_COLUMN_SIZE_PROPORTIONAL),
+			   COL_COLUMN_JUSTIFY, (dt->ld->column_flags[row] & UI_LIST_COLUMN_JUSTIFY_RIGHT) ? _("right") : _("left"), -1);
+}
+
+static void list_props_list_append(ListDetail *dt, gint row)
+{
+	GtkTreeModel *store;
+	GtkTreeIter iter;
 
 	if (row >= dt->ld->column_count) return;
 
-	buf = ui_edit_int_to_text(row);
-	gtk_clist_set_text(GTK_CLIST(dt->column_clist), row, 0, buf);
-	g_free(buf);
+	store = gtk_tree_view_get_model(GTK_TREE_VIEW(dt->column_list));
+	gtk_list_store_append(GTK_LIST_STORE(store), &iter);
 
-	gtk_clist_set_text(GTK_CLIST(dt->column_clist), row, 1,
-			   dt->ld->column_keys[row] ? dt->ld->column_keys[row] : "");
-
-	buf = ui_edit_int_to_text(dt->ld->column_widths[row]);
-	gtk_clist_set_text(GTK_CLIST(dt->column_clist), row, 2, buf);
-	g_free(buf);
-
-	gtk_clist_set_text(GTK_CLIST(dt->column_clist), row, 3,
-			   ui_edit_bool_to_text(dt->ld->column_flags[row] & UI_LIST_COLUMN_SIZE_PROPORTIONAL));
-
-	if (dt->ld->column_flags[row] & UI_LIST_COLUMN_JUSTIFY_RIGHT)
-		buf = _("right");
-	else
-		buf = _("left");
-	gtk_clist_set_text(GTK_CLIST(dt->column_clist), row, 4, buf);
+	list_props_list_update(dt, row);
 }
 
-static void list_props_clist_append(ListDetail *dt, gint row)
+static void list_props_list_populate(ListDetail *dt)
 {
-	gchar *buf[6];
+	GtkTreeModel *store;
 	gint i;
 
-	if (row >= dt->ld->column_count) return;
+	store = gtk_tree_view_get_model(GTK_TREE_VIEW(dt->column_list));
+	gtk_list_store_clear(GTK_LIST_STORE(store));
 
-	for (i = 0; i < 5; i++) buf[i] = "";
-	buf[5] = NULL;
-
-	row = gtk_clist_append(GTK_CLIST(dt->column_clist), buf);
-
-	list_props_clist_update(dt, row);
-}
-
-static void list_props_clist_populate(ListDetail *dt)
-{
-	gint i;
-
-	gtk_clist_clear(GTK_CLIST(dt->column_clist));
-	for (i = 0; i < dt->ld->column_count; i++) list_props_clist_append(dt, i);
+	for (i = 0; i < dt->ld->column_count; i++) list_props_list_append(dt, i);
 }
 
 static void list_edit_props_sync(ListDetail *dt)
@@ -625,7 +629,7 @@ static void list_edit_props_sync(ListDetail *dt)
 	ui_edit_spin_set_blocking(dt->column_count_spin, ld->column_count, dt);
 	ui_edit_spin_set_blocking(dt->flag_column_spin, ld->flag_column, dt);
 
-	list_props_clist_populate(dt);
+	list_props_list_populate(dt);
 }
 
 static void list_props_clamp_borders(ListDetail *dt)
@@ -825,91 +829,113 @@ static void list_props_column_count_cb(GtkAdjustment *adj, gpointer data)
 	ListDetail *dt = data;
 
 	list_sync_column_count(dt->ld, ui_edit_spin_get(dt->column_count_spin));
-	list_props_clist_populate(dt);
+	list_props_list_populate(dt);
 
 	dt->ld->force_sync = TRUE;
 
 	ui_edit_widget_resync(dt->ui, dt->wd, TRUE, 0, 0);
 }
 
-static gint list_props_column_key_cb(ClistEditData *ced,
+static gint list_props_column_key_cb(TreeEditData *ted,
 				     const gchar *old_text, const gchar *new_text, gpointer data)
 {
 	ListDetail *dt = data;
 	ListData *ld = dt->ld;
 	GList *work;
+	gint row;
 
-	if (ced->row >= ld->column_count) return FALSE;
+	row = tree_path_to_row(ted->path);
+	if (row >= ld->column_count) return FALSE;
 	if (strlen(new_text) == 0) new_text = NULL;
 
-	g_free(ld->column_keys[ced->row]);
-	ld->column_keys[ced->row] = g_strdup(new_text);
+	g_free(ld->column_keys[row]);
+	ld->column_keys[row] = g_strdup(new_text);
 
 	/* clear all text for this column */
 	work = ld->row_list;
 	while (work)
 		{
 		ListRowData *rd = work->data;
-		list_row_text_set(rd, ced->row, NULL);
+		list_row_text_set(rd, row, NULL);
 		work = work->next;
 		}
 
+	list_props_list_update(dt, row);
 	ui_edit_widget_resync(dt->ui, dt->wd, TRUE, 0, 0);
 
-	return TRUE;
+	return FALSE;
 }
 
-static gint list_props_column_width_cb(ClistEditData *ced,
+static gint list_props_column_width_cb(TreeEditData *ted,
 				       const gchar *old_text, const gchar *new_text, gpointer data)
 {
 	ListDetail *dt = data;
 	ListData *ld = dt->ld;
 	gint n;
 	gint val;
+	gint row;
 
-	if (ced->row >= ld->column_count ||
+	row = tree_path_to_row(ted->path);
+	if (row >= ld->column_count ||
 	    strlen(new_text) == 0) return FALSE;
 
-	n = (ld->column_flags[ced->row] & UI_LIST_COLUMN_SIZE_PROPORTIONAL) ? 100 : SKIN_SIZE_MAX;
+	n = (ld->column_flags[row] & UI_LIST_COLUMN_SIZE_PROPORTIONAL) ? 100 : SKIN_SIZE_MAX;
 
 	val = (gint)strtol(new_text, NULL, 10);
 	if (val < 1) return FALSE;
-	ld->column_widths[ced->row] = MIN(val, n);
+	ld->column_widths[row] = MIN(val, n);
 
-	list_props_clist_update(dt, ced->row);
+	list_props_list_update(dt, row);
 	ld->force_sync = TRUE;
 	ui_edit_widget_resync(dt->ui, dt->wd, TRUE, 0, 0);
 
 	return FALSE;
 }
 
-static gint list_props_column_clist_cb(GtkWidget *widget, GdkEventButton *event, gpointer data)
+static gint list_props_column_list_cb(GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
 	ListDetail *dt = data;
+	GtkTreePath *tpath = NULL;
+	GtkTreeViewColumn *tcolumn;
 	gint row = -1;
 	gint column = -1;
 	gint update = FALSE;
 	ListData *ld;
 	gint n;
 
-	gtk_clist_get_selection_info(GTK_CLIST(dt->column_clist), event->x, event->y, &row, &column);
-	if (row == -1 || column == -1) return FALSE;
+	if (gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(widget), event->x, event->y,
+					  &tpath, &tcolumn, NULL, NULL))
+		{
+		GList *list;
+
+		row = tree_path_to_row(tpath);
+
+		list = gtk_tree_view_get_columns(GTK_TREE_VIEW(widget));
+		column = g_list_index(list, tcolumn);
+		g_list_free(list);
+		}
+
+	if (row == -1 || column == -1 ||
+	    row >= dt->ld->column_count)
+		{
+		if (tpath) gtk_tree_path_free(tpath);
+		return FALSE;
+		}
 
-	if (row >= dt->ld->column_count) return FALSE;
 	ld = dt->ld;
 
 	switch (column)
 		{
-		case 1:	/* key */
+		case COL_COLUMN_KEY:
 			if (event->button != 1) break;
-			clist_edit_by_row(GTK_CLIST(dt->column_clist), row, column,
+			tree_edit_by_path(GTK_TREE_VIEW(dt->column_list), tpath, column, NULL,
 					  list_props_column_key_cb, dt);
 			break;
-		case 2:	/* width */
+		case COL_COLUMN_WIDTH:
 			n = (ld->column_flags[row] & UI_LIST_COLUMN_SIZE_PROPORTIONAL) ? 100 : SKIN_SIZE_MAX;
 			if (event->button == 1)
 				{
-				clist_edit_by_row(GTK_CLIST(dt->column_clist), row, column,
+				tree_edit_by_path(GTK_TREE_VIEW(dt->column_list), tpath, column, NULL,
 						  list_props_column_width_cb, dt);
 				}
 			else if (event->button == 2 || event->button == 5)
@@ -925,7 +951,7 @@ static gint list_props_column_clist_cb(GtkWidget *widget, GdkEventButton *event,
 				ld->column_widths[row] = CLAMP(ld->column_widths[row] + 1, 1, n);
 				}
 			break;
-		case 3:	/* dynamic (proportional) */
+		case COL_COLUMN_DYNAMIC:
 			if (event->button != 1) break;
 			ld->force_sync = TRUE;
 			update = TRUE;
@@ -941,7 +967,7 @@ static gint list_props_column_clist_cb(GtkWidget *widget, GdkEventButton *event,
 				ld->column_widths[row] = CLAMP(ld->column_widths[row], 1, 100);
 				}
 			break;
-		case 4:	/* justify */
+		case COL_COLUMN_JUSTIFY:
 			if (event->button != 1) break;
 			update = TRUE;
 			if (ld->column_flags[row] & UI_LIST_COLUMN_JUSTIFY_RIGHT)
@@ -953,9 +979,11 @@ static gint list_props_column_clist_cb(GtkWidget *widget, GdkEventButton *event,
 			break;
 		}
 
+	if (tpath) gtk_tree_path_free(tpath);
+
 	if (update)
 		{
-		list_props_clist_update(dt, row);
+		list_props_list_update(dt, row);
 		ui_edit_widget_resync(dt->ui, dt->wd, TRUE, 0, 0);
 		return TRUE;
 		}
@@ -1004,32 +1032,32 @@ static void list_props_connect_spin(GtkWidget *spin, ListDetail *dt, GtkSignalFu
 	GtkAdjustment *adj;
 
 	adj = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(spin));
-	gtk_signal_connect(GTK_OBJECT(adj), "value_changed", func, dt);
+	g_signal_connect(G_OBJECT(adj), "value_changed", func, dt);
 }
 
 static void list_props_signals(ListDetail *dt)
 {
-	list_props_connect_spin(dt->width_spin, dt, GTK_SIGNAL_FUNC(list_props_geometry_cb));
-	list_props_connect_spin(dt->height_spin, dt, GTK_SIGNAL_FUNC(list_props_geometry_cb));
-	gtk_signal_connect(GTK_OBJECT(dt->sizeable_button), "clicked",
-			   GTK_SIGNAL_FUNC(list_props_sizeable_cb) , dt);
+	list_props_connect_spin(dt->width_spin, dt, G_CALLBACK(list_props_geometry_cb));
+	list_props_connect_spin(dt->height_spin, dt, G_CALLBACK(list_props_geometry_cb));
+	g_signal_connect(G_OBJECT(dt->sizeable_button), "clicked",
+			 G_CALLBACK(list_props_sizeable_cb) , dt);
 
-	list_props_connect_spin(dt->border_top_spin, dt, GTK_SIGNAL_FUNC(list_props_border_cb));
-	list_props_connect_spin(dt->border_left_spin, dt, GTK_SIGNAL_FUNC(list_props_border_cb));
-	list_props_connect_spin(dt->border_right_spin, dt, GTK_SIGNAL_FUNC(list_props_border_cb));
-	list_props_connect_spin(dt->border_bottom_spin, dt, GTK_SIGNAL_FUNC(list_props_border_cb));
-	gtk_signal_connect(GTK_OBJECT(dt->border_stretch_button), "clicked",
-			   GTK_SIGNAL_FUNC(list_props_border_cb) , dt);
+	list_props_connect_spin(dt->border_top_spin, dt, G_CALLBACK(list_props_border_cb));
+	list_props_connect_spin(dt->border_left_spin, dt, G_CALLBACK(list_props_border_cb));
+	list_props_connect_spin(dt->border_right_spin, dt, G_CALLBACK(list_props_border_cb));
+	list_props_connect_spin(dt->border_bottom_spin, dt, G_CALLBACK(list_props_border_cb));
+	g_signal_connect(G_OBJECT(dt->border_stretch_button), "clicked",
+			 G_CALLBACK(list_props_border_cb) , dt);
 
-	gtk_signal_connect(GTK_OBJECT(dt->stretch_button), "clicked",
-			   GTK_SIGNAL_FUNC(list_props_border_cb) , dt);
+	g_signal_connect(G_OBJECT(dt->stretch_button), "clicked",
+			 G_CALLBACK(list_props_border_cb) , dt);
 
 	ui_edit_frame_sensitive(dt->row_image_entry, FALSE, TRUE);
 
-	list_props_connect_spin(dt->row_border_left_spin, dt, GTK_SIGNAL_FUNC(list_props_row_cb));
-	list_props_connect_spin(dt->row_border_right_spin, dt, GTK_SIGNAL_FUNC(list_props_row_cb));
-	gtk_signal_connect(GTK_OBJECT(dt->row_stretch_button), "clicked",
-			   GTK_SIGNAL_FUNC(list_props_row_cb) , dt);
+	list_props_connect_spin(dt->row_border_left_spin, dt, G_CALLBACK(list_props_row_cb));
+	list_props_connect_spin(dt->row_border_right_spin, dt, G_CALLBACK(list_props_row_cb));
+	g_signal_connect(G_OBJECT(dt->row_stretch_button), "clicked",
+			 G_CALLBACK(list_props_row_cb) , dt);
 
 	ui_edit_frame_sensitive(dt->row_has_press_button, FALSE, TRUE);
 	ui_edit_frame_sensitive(dt->row_has_prelight_button, FALSE, TRUE);
@@ -1041,23 +1069,23 @@ static void list_props_signals(ListDetail *dt)
 
 	ui_edit_frame_sensitive(dt->text_font_entry, FALSE, TRUE);
 
-	list_props_connect_spin(dt->text_font_r, dt, GTK_SIGNAL_FUNC(list_props_text_color_cb));
-	list_props_connect_spin(dt->text_font_g, dt, GTK_SIGNAL_FUNC(list_props_text_color_cb));
-	list_props_connect_spin(dt->text_font_b, dt, GTK_SIGNAL_FUNC(list_props_text_color_cb));
-	list_props_connect_spin(dt->text_font_a, dt, GTK_SIGNAL_FUNC(list_props_text_color_cb));
+	list_props_connect_spin(dt->text_font_r, dt, G_CALLBACK(list_props_text_color_cb));
+	list_props_connect_spin(dt->text_font_g, dt, G_CALLBACK(list_props_text_color_cb));
+	list_props_connect_spin(dt->text_font_b, dt, G_CALLBACK(list_props_text_color_cb));
+	list_props_connect_spin(dt->text_font_a, dt, G_CALLBACK(list_props_text_color_cb));
 
 	ui_edit_frame_sensitive(dt->flag_image_entry, FALSE, FALSE);
 	ui_edit_frame_sensitive(dt->flag_sections_spin, FALSE, TRUE);
 
-	list_props_connect_spin(dt->column_count_spin, dt, GTK_SIGNAL_FUNC(list_props_column_count_cb));
+	list_props_connect_spin(dt->column_count_spin, dt, G_CALLBACK(list_props_column_count_cb));
 
-	gtk_signal_connect(GTK_OBJECT(dt->column_clist), "button_press_event",
-			   GTK_SIGNAL_FUNC(list_props_column_clist_cb), dt);
+	g_signal_connect(G_OBJECT(dt->column_list), "button_press_event",
+			 G_CALLBACK(list_props_column_list_cb), dt);
 
-	list_props_connect_spin(dt->flag_column_spin, dt, GTK_SIGNAL_FUNC(list_props_flag_column_cb));
+	list_props_connect_spin(dt->flag_column_spin, dt, G_CALLBACK(list_props_flag_column_cb));
 
-	gtk_signal_connect(GTK_OBJECT(dt->columns_right_toggle), "clicked",
-			   GTK_SIGNAL_FUNC(list_props_column_right_cb), dt);
+	g_signal_connect(G_OBJECT(dt->columns_right_toggle), "clicked",
+			 G_CALLBACK(list_props_column_right_cb), dt);
 }
 
 static gpointer list_edit_props(UIData *ui, WidgetData *wd, GtkWidget *vbox, gpointer detail)
@@ -1128,7 +1156,7 @@ static void list_edit_page_add_cb(GtkWidget *widget, gpointer data)
 		return;
 		}
 
-	ld = list_new(gdk_pixbuf_new_from_file(image),
+	ld = list_new(util_pixbuf_new_from_file(image),
 		      0, 0, ui_edit_spin_get(dt->width_spin), ui_edit_spin_get(dt->height_spin),
 		      ui_edit_toggle_get(dt->sizeable_button), ui_edit_spin_get(dt->column_count_spin),
 		      ui_edit_spin_get(dt->border_top_spin), ui_edit_spin_get(dt->border_right_spin),
@@ -1142,9 +1170,9 @@ static void list_edit_page_add_cb(GtkWidget *widget, gpointer data)
 		WidgetData *wd;
 		guint8 r, g, b, a;
 
-		if (divider_image) pb = gdk_pixbuf_new_from_file(divider_image);
+		if (divider_image) pb = util_pixbuf_new_from_file(divider_image);
 
-		list_image_row(ld, gdk_pixbuf_new_from_file(row_image),
+		list_image_row(ld, util_pixbuf_new_from_file(row_image),
 			       ui_edit_toggle_get(dt->row_has_press_button),
 			       ui_edit_toggle_get(dt->row_has_prelight_button),
 			       ui_edit_spin_get(dt->row_border_left_spin),
@@ -1162,7 +1190,7 @@ static void list_edit_page_add_cb(GtkWidget *widget, gpointer data)
 			}
 		else if (text_image)
 			{
-			list_set_font(ld, NULL, gdk_pixbuf_new_from_file(text_image), 
+			list_set_font(ld, NULL, util_pixbuf_new_from_file(text_image), 
 				      ui_edit_toggle_get(dt->text_extended_button), r, g, b, a);
 			}
 
@@ -1176,7 +1204,7 @@ static void list_edit_page_add_cb(GtkWidget *widget, gpointer data)
 		list_set_column_justify(ld, ui_edit_toggle_get(dt->columns_right_toggle));
 
 		pb = NULL;
-		if (flag_image) pb = gdk_pixbuf_new_from_file(flag_image);
+		if (flag_image) pb = util_pixbuf_new_from_file(flag_image);
 
 		list_image_row_flag(ld, pb, ui_edit_spin_get(dt->flag_sections_spin),
 				    ui_edit_spin_get(dt->flag_column_spin));
@@ -1240,16 +1268,17 @@ static void list_edit_page_free_columns(ListPage *pd)
 	pd->column_list = NULL;
 }
 
-static void list_edit_page_clist_sync(ListPage *pd)
+static void list_edit_page_list_sync(ListPage *pd)
 {
 	ListDetail *dt;
+	GtkListStore *store;
 	GList *work;
 	gint n;
-	gchar *buf[6];
 
 	dt = (ListDetail *)pd;
-	gtk_clist_freeze(GTK_CLIST(dt->column_clist));
-	gtk_clist_clear(GTK_CLIST(dt->column_clist));
+
+	store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(dt->column_list)));
+	gtk_list_store_clear(store);
 
 	n = 0;
 	
@@ -1257,23 +1286,19 @@ static void list_edit_page_clist_sync(ListPage *pd)
 	while (work)
 		{
 		ListPageColumn *c = work->data;
+		GtkTreeIter iter;
 
-		buf[0] = ui_edit_int_to_text(n);
-		buf[1] = c->key ? c->key : "";
-		buf[2] = ui_edit_int_to_text(c->width);
-		buf[3] = ui_edit_bool_to_text(c->flags & UI_LIST_COLUMN_SIZE_PROPORTIONAL);
-		buf[4] = (c->flags * UI_LIST_COLUMN_JUSTIFY_RIGHT) ? _("right") : _("left");
-		buf[5] = NULL;
-
-		gtk_clist_append(GTK_CLIST(dt->column_clist), buf);
-
-		g_free(buf[0]);
-		g_free(buf[2]);
+		gtk_list_store_append(store, &iter);
+		gtk_list_store_set(store, &iter,
+				   COL_COLUMN_NUMBER, n,
+				   COL_COLUMN_KEY, c->key,
+				   COL_COLUMN_WIDTH, c->width,
+				   COL_COLUMN_DYNAMIC, (c->flags & UI_LIST_COLUMN_SIZE_PROPORTIONAL),
+				   COL_COLUMN_JUSTIFY, (c->flags * UI_LIST_COLUMN_JUSTIFY_RIGHT) ? _("right") : _("left"), -1 );
 
 		work = work->next;
 		n++;
 		}
-	gtk_clist_thaw(GTK_CLIST(dt->column_clist));
 }
 
 static void list_edit_page_sync(ListPage *pd, ListListData *ll)
@@ -1332,7 +1357,7 @@ static void list_edit_page_sync(ListPage *pd, ListListData *ll)
 	ui_edit_spin_set(dt->flag_column_spin, ll->flag_column);
 	ui_edit_toggle_set(dt->columns_right_toggle, ll->columns_right_justify);
 
-	/* the column clist */
+	/* the column list */
 	list_edit_page_free_columns(pd);
 	for (i = 0; i < ll->column_count; i++)
 		{
@@ -1340,15 +1365,19 @@ static void list_edit_page_sync(ListPage *pd, ListListData *ll)
 			page_column_new(ll->column_keys[i], ll->column_widths[i], ll->column_flags[i]));
 		}
 
-	list_edit_page_clist_sync(pd);
+	list_edit_page_list_sync(pd);
 }
 
-static void list_edit_page_clist_cb(GtkWidget *clist, gint row, gint col, GdkEvent *event, gpointer data)
+static void list_edit_page_list_cb(GtkTreeSelection *selection, gpointer data)
 {
 	ListPage *pd = data;
 	ListListData *ll;
+	GtkTreeModel *store;
+	GtkTreeIter iter;
 
-	ll = gtk_clist_get_row_data(GTK_CLIST(clist), row);
+	if (!gtk_tree_selection_get_selected(selection, &store, &iter)) return;
+
+	gtk_tree_model_get(store, &iter, LIST_COLUMN_POINTER, &ll, -1);
 	list_edit_page_sync(pd, ll);
 }
 
@@ -1387,7 +1416,7 @@ static void list_edit_column_count_cb(GtkObject *object, gpointer data)
 			}
 		}
 
-	list_edit_page_clist_sync(pd);
+	list_edit_page_list_sync(pd);
 }
 
 static void list_edit_font_change_cb(GtkWidget *w, gpointer data)
@@ -1423,7 +1452,7 @@ static GtkWidget *list_edit_page_new(EditData *ed)
 	GtkWidget *button;
 	GtkAdjustment *adj;
 	ListPage *pd;
-	gchar *titles[] = { _("Image"), _("Key"), _("Flag"), NULL };
+	GtkListStore *store;
 
 	pd = g_new0(ListPage, 1);
 	pd->ed = ed;
@@ -1432,9 +1461,9 @@ static GtkWidget *list_edit_page_new(EditData *ed)
 
 	hbox = gtk_hbox_new(FALSE, 5);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
-	gtk_object_set_data(GTK_OBJECT(hbox), "page", pd);
-	gtk_signal_connect(GTK_OBJECT(hbox), "destroy",
-			   GTK_SIGNAL_FUNC(list_edit_page_destroy_cb), pd);
+	g_object_set_data(G_OBJECT(hbox), "page", pd);
+	g_signal_connect(G_OBJECT(hbox), "destroy",
+			 G_CALLBACK(list_edit_page_destroy_cb), pd);
 
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
@@ -1446,8 +1475,8 @@ static GtkWidget *list_edit_page_new(EditData *ed)
 
 	list_details_pack(dt, vbox, TRUE);
 
-	gtk_signal_connect(GTK_OBJECT(dt->text_font_entry), "changed",
-			   GTK_SIGNAL_FUNC(list_edit_font_change_cb), pd);
+	g_signal_connect(G_OBJECT(dt->text_font_entry), "changed",
+			 G_CALLBACK(list_edit_font_change_cb), pd);
 
 	ui_edit_entry_set(dt->text_font_entry, SLIK_DEFAULT_X_FONT);
 	ui_edit_spin_set(dt->text_font_r, 0);
@@ -1456,22 +1485,28 @@ static GtkWidget *list_edit_page_new(EditData *ed)
 	ui_edit_spin_set(dt->text_font_a, 255);
 
 	adj = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(dt->column_count_spin));
-        gtk_signal_connect(GTK_OBJECT(adj), "value_changed",
-			   GTK_SIGNAL_FUNC(list_edit_column_count_cb), pd);
+        g_signal_connect(G_OBJECT(adj), "value_changed",
+			 G_CALLBACK(list_edit_column_count_cb), pd);
 
 	button = gtk_button_new_with_label(_("Add"));
 	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			   GTK_SIGNAL_FUNC(list_edit_page_add_cb), pd);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(list_edit_page_add_cb), pd);
 	gtk_widget_show(button);
 
-	pd->clist = ui_edit_clist_new(hbox, titles, 3);
-	gtk_signal_connect(GTK_OBJECT(pd->clist), "select_row",
-			   GTK_SIGNAL_FUNC(list_edit_page_clist_cb), pd);
+	store = gtk_list_store_new(4, G_TYPE_POINTER, GDK_TYPE_PIXBUF, G_TYPE_STRING,
+				      G_TYPE_BOOLEAN);
+	pd->list = ui_edit_list_new(hbox, store,
+				    G_CALLBACK(list_edit_page_list_cb), pd);
+	g_object_unref(store);
 
+	ui_edit_list_add_column(pd->list, _("Image"), LIST_COLUMN_IMAGE, TRUE, FALSE);
+	ui_edit_list_add_column(pd->list, _("Key"), LIST_COLUMN_KEY, FALSE, FALSE);
+	ui_edit_list_add_column(pd->list, _("Flag"), LIST_COLUMN_FLAG, FALSE, FALSE);
+	
 	pd->column_list = g_list_append(pd->column_list,
-		page_column_new("column_1", 10, UI_LIST_COLUMN_SIZE_FIXED));
-	list_edit_page_clist_sync(pd);
+					page_column_new("column_1", 10, UI_LIST_COLUMN_SIZE_FIXED));
+	list_edit_page_list_sync(pd);
 
 	gtk_widget_show(hbox);
 
@@ -1482,16 +1517,23 @@ static void list_edit_page_add(GtkWidget *widget, gpointer data)
 {
 	ListListData *ll = data;
 	ListPage *pd;
-	gchar *buf[4];
+	GtkListStore *store;
+	GtkTreeIter iter;
+	GdkPixbuf *pixbuf;
 
-	pd = gtk_object_get_data(GTK_OBJECT(widget), "page");
+	pd = g_object_get_data(G_OBJECT(widget), "page");
+	store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(pd->list)));
 
-	buf[0] = "";
-	buf[1] = ll->key;
-	buf[2] = ui_edit_bool_to_text((ll->flag_image != NULL));
-	buf[3] = NULL;
+	pixbuf = ui_edit_list_pixbuf_from_file(ll->image);
 
-	ui_edit_clist_append(pd->clist, buf, ll->image, ll);
+	gtk_list_store_append(store, &iter);
+	gtk_list_store_set(store, &iter,
+			   LIST_COLUMN_POINTER, ll,
+			   LIST_COLUMN_IMAGE, pixbuf,
+			   LIST_COLUMN_KEY, ll->key,
+			   LIST_COLUMN_FLAG, (ll->flag_image != NULL), -1);
+
+	if (pixbuf) gdk_pixbuf_unref(pixbuf);
 }
 
 void list_type_init_edit(WidgetObjectData *od)
