@@ -21,7 +21,7 @@
 #include "ui2_widget.h"
 #include "ui_fileops.h"
 
-#include "ui2_logo.xpm"
+#include "ui2_logo.h"
 
 /* these two includes are _only_ used in ui_iconify() */
 #include <gdk/gdkx.h>
@@ -67,38 +67,41 @@ static GList *slik_ui_list = NULL;
  *-------------
  */
 
-void window_set_icon(GtkWidget *window, const char **icon, const gchar *file)
+void window_set_icon(GtkWidget *window, const char **icon, const gchar *file, GdkPixbuf *pixbuf)
 {
 	GdkPixbuf *pb;
-	GdkPixmap *pixmap;
-	GdkBitmap *mask;
-
-	if (!icon && !file) return;
 
 	if (icon)
 		{
 		pb = gdk_pixbuf_new_from_xpm_data(icon);
 		}
+	else if (file)
+		{
+		pb = util_pixbuf_new_from_file(file);
+		}
 	else
 		{
-		pb = gdk_pixbuf_new_from_file(file);
+		pb = pixbuf;
+		if (pb)
+			{
+			gdk_pixbuf_ref(pb);
+			}
+		else
+			{
+			pb = ui_slik_logo();
+			}
 		}
 
 	if (!pb) return;
-
-	gdk_pixbuf_render_pixmap_and_mask(pb, &pixmap, &mask, 128);
+	gtk_window_set_icon(GTK_WINDOW(window), pb);
 	gdk_pixbuf_unref(pb);
-
-	if (!GTK_WIDGET_REALIZED(window)) gtk_widget_realize(window);
-	gdk_window_set_icon(window->window, NULL, pixmap, mask);
-	/* apparently, gdk_window_set_icon does not ref the pixmap and mask, so don't unref it (leak?) */
 }
 
-void ui_set_icon(UIData *ui, const char **icon, const gchar *file)
+void ui_set_icon(UIData *ui, const char **icon, const gchar *file, GdkPixbuf *pixbuf)
 {
 	if (!ui || !ui->window) return;
 
-	window_set_icon(ui->window, icon, file);
+	window_set_icon(ui->window, icon, file, pixbuf);
 }
 
 void ui_iconify(UIData *ui)
@@ -436,8 +439,8 @@ static void ui_show_cb(GtkWidget *widget, gpointer data)
 		}
 
 	/* only do this once */
-	gtk_signal_disconnect_by_func(GTK_OBJECT(widget),
-				      GTK_SIGNAL_FUNC(ui_show_cb), data);
+	g_signal_handlers_disconnect_matched(G_OBJECT(widget), G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
+					     0, 0, NULL, G_CALLBACK(ui_show_cb), data);
 }
 
 static void ui_hide_cb(GtkWidget *widget, gpointer data)
@@ -482,19 +485,17 @@ static UIData *ui_real_new(const gchar *class, const gchar *key,
 	ui->children = NULL;
 
 	ui->window = gtk_window_new(type);
-	gtk_window_set_policy(GTK_WINDOW(ui->window), FALSE, FALSE, TRUE);
-	gtk_container_border_width (GTK_CONTAINER(ui->window), 0);
+	gtk_window_set_resizable(GTK_WINDOW(ui->window), FALSE);
+	gtk_container_set_border_width(GTK_CONTAINER(ui->window), 0);
 	gtk_window_set_wmclass(GTK_WINDOW(ui->window), ui->key, ui->class);
 	gtk_window_set_title(GTK_WINDOW(ui->window), title);
 
-	gtk_signal_connect(GTK_OBJECT(ui->window), "show",
-			   GTK_SIGNAL_FUNC(ui_show_cb), ui);
-	gtk_signal_connect(GTK_OBJECT(ui->window), "hide",
-			   GTK_SIGNAL_FUNC(ui_hide_cb), ui);
-	gtk_signal_connect(GTK_OBJECT(ui->window), "destroy",
-			   GTK_SIGNAL_FUNC(ui_destroy_cb), ui);
-
-	gtk_widget_realize(ui->window);
+	g_signal_connect(G_OBJECT(ui->window), "show",
+			 G_CALLBACK(ui_show_cb), ui);
+	g_signal_connect(G_OBJECT(ui->window), "hide",
+			 G_CALLBACK(ui_hide_cb), ui);
+	g_signal_connect(G_OBJECT(ui->window), "destroy",
+			 G_CALLBACK(ui_destroy_cb), ui);
 
 	ui->display = gtk_drawing_area_new();
 	ui_display_events_init(ui);
@@ -503,11 +504,9 @@ static UIData *ui_real_new(const gchar *class, const gchar *key,
 
 	if (GTK_WIDGET_CAN_FOCUS(ui->display)) gtk_widget_grab_focus(ui->display);
 
-	gtk_widget_realize(ui->display);
-
 	if (type != GTK_WINDOW_POPUP && !ui->decorations)
 		{
-		gdk_window_set_decorations(ui->window->window, 0);
+		gtk_window_set_decorated(GTK_WINDOW(ui->window), 0);
 		}
 
 	/* add the default reserved keys */
@@ -525,7 +524,12 @@ UIData *ui_new(const gchar *class, const gchar *subclass, gint decorations, cons
 
 UIData *ui_new_dialog(const gchar *class, const gchar *subclass, gint decorations, const gchar *title)
 {
-	return ui_real_new(class, subclass, decorations, title, GTK_WINDOW_DIALOG);
+	UIData *ui;
+
+	ui = ui_real_new(class, subclass, decorations, title, GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_type_hint(GTK_WINDOW(ui->window), GDK_WINDOW_TYPE_HINT_DIALOG);
+
+	return ui;
 }
 
 UIData *ui_new_into_container(const gchar *class, const gchar *key, GtkWidget *widget)
@@ -549,8 +553,8 @@ UIData *ui_new_into_container(const gchar *class, const gchar *key, GtkWidget *w
 	ui->window = NULL;
 
 	ui->display = gtk_drawing_area_new();
-	gtk_signal_connect(GTK_OBJECT(ui->display), "destroy",
-			   GTK_SIGNAL_FUNC(ui_destroy_cb), ui);
+	g_signal_connect(G_OBJECT(ui->display), "destroy",
+			 G_CALLBACK(ui_destroy_cb), ui);
 
 	ui_display_events_init(ui);
 	if (widget)
@@ -1016,7 +1020,7 @@ SkinData *ui_skin_load_default(UIData *ui, const gchar *key)
 		/* well, return something! */
 		skin = skin_new();
 
-		skin->real_overlay = gdk_pixbuf_new_from_xpm_data(ui_slik_logo());
+		skin->real_overlay = ui_slik_logo();
 		skin->width = gdk_pixbuf_get_width(skin->real_overlay);
 		skin->height = gdk_pixbuf_get_height(skin->real_overlay);
 
@@ -1238,9 +1242,9 @@ UIData *ui_group_get_parent(UIData *ui)
  *-------------
  */
 
-const char **ui_slik_logo(void)
+GdkPixbuf *ui_slik_logo(void)
 {
-	return (const char **)slik_xpm;
+	return gdk_pixbuf_new_from_inline(-1, icon_slik_logo, FALSE, NULL);
 }
 
 static GtkWidget *slik_about = NULL;
@@ -1274,12 +1278,8 @@ static void ui_slik_about(void)
 	GtkWidget *hbox;
 	GtkWidget *label;
 	GtkWidget *button;
-	GtkWidget *pixmap;
-
-	GtkStyle *style;
-	GdkPixmap *pmap;
-	GdkBitmap *mask;
-
+	GtkWidget *image;
+	GdkPixbuf *pixbuf;
 	gchar *buf;
 
 	if (slik_about)
@@ -1289,36 +1289,39 @@ static void ui_slik_about(void)
 		}
 
 	slik_about = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-	gtk_signal_connect(GTK_OBJECT(slik_about), "delete_event",
-			   GTK_SIGNAL_FUNC(ui_slik_about_delete_cb), NULL);
+	gtk_window_set_type_hint(GTK_WINDOW(slik_about), GDK_WINDOW_TYPE_HINT_DIALOG);
+	g_signal_connect(G_OBJECT(slik_about), "delete_event",
+			 G_CALLBACK(ui_slik_about_delete_cb), NULL);
 	gtk_window_set_wmclass(GTK_WINDOW(slik_about), "about", "SLIK");
 	gtk_window_set_title(GTK_WINDOW(slik_about), _("About - SLIK"));
-	gtk_container_border_width(GTK_CONTAINER(slik_about), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(slik_about), 5);
 
 	frame = gtk_frame_new(NULL);
-	gtk_container_border_width(GTK_CONTAINER(frame), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 5);
 	gtk_container_add(GTK_CONTAINER(slik_about), frame);
 	gtk_widget_show(frame);
 
 	vbox = gtk_vbox_new(FALSE, 0);
-	gtk_container_border_width(GTK_CONTAINER(vbox), 5);
+	gtk_container_set_border_width(GTK_CONTAINER(vbox), 5);
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 	gtk_widget_show(vbox);
 	gtk_widget_realize(slik_about);
 
-	style = gtk_widget_get_style(slik_about);
-	pmap = gdk_pixmap_create_from_xpm_d(slik_about->window, &mask,
-		&style->bg[GTK_STATE_NORMAL], (gchar **)ui_slik_logo());
-	pixmap = gtk_pixmap_new(pmap, mask);
-	gdk_pixmap_unref(pmap);
-	if (mask) gdk_bitmap_unref(mask);
+	pixbuf = ui_slik_logo();
+	image = gtk_image_new_from_pixbuf(pixbuf);
+	gdk_pixbuf_unref(pixbuf);
 
-	gtk_box_pack_start(GTK_BOX(vbox), pixmap, FALSE, FALSE, 0);
-	gtk_widget_show(pixmap);
+	gtk_box_pack_start(GTK_BOX(vbox), image, FALSE, FALSE, 0);
+	gtk_widget_show(image);
 
-	buf = g_strdup_printf(_("SLIK\nSimpLIstic sKin interface\nversion %s\nCopyright (c) 2003 by John Ellis\nhttp://gqmpeg.sourceforge.net\ngqview@users.sourceforge.net\n\nReleased under the GNU General Public License"), SLIK_VERSION);
+	buf = g_strdup_printf(_("SLIK\nSimpLIstic sKin interface\n%s\nCopyright (c) %s John Ellis\nwebsite: %s\nemail: %s\n\nReleased under the GNU General Public License"),
+			      SLIK_VERSION,
+			      "2004",
+			      "gqmpeg.sourceforge.net",
+			      "gqview@users.sourceforge.net");
 	label = gtk_label_new(buf);
 	g_free(buf);
+	gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
 	gtk_widget_show (label);
 
@@ -1327,22 +1330,23 @@ static void ui_slik_about(void)
 	gtk_widget_show(hbox);
 
 	button = gtk_toggle_button_new();
-	gtk_widget_set_usize(button, 8, 8);
+	gtk_widget_set_size_request(button, 8, 8);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), debug_mode);
-	gtk_signal_connect(GTK_OBJECT(button), "toggled",
-			   GTK_SIGNAL_FUNC(slik_about_toggle_cb), &debug_mode);
+	g_signal_connect(G_OBJECT(button), "toggled",
+			 G_CALLBACK(slik_about_toggle_cb), &debug_mode);
 	gtk_box_pack_end(GTK_BOX(hbox), button, FALSE, FALSE, 4);
 	gtk_widget_show(button);
 
 	button = gtk_toggle_button_new();
-	gtk_widget_set_usize(button, 8, 8);
+	gtk_widget_set_size_request(button, 8, 8);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), debug_skin);
-	gtk_signal_connect(GTK_OBJECT(button), "toggled",
-			   GTK_SIGNAL_FUNC(slik_about_toggle_cb), &debug_skin);
+	g_signal_connect(G_OBJECT(button), "toggled",
+			 G_CALLBACK(slik_about_toggle_cb), &debug_skin);
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 4);
 	gtk_widget_show(button);
 
-	window_set_icon(slik_about, ui_slik_logo(), NULL);
+	window_set_icon(slik_about, NULL, NULL, NULL);
+
 	gtk_widget_show(slik_about);
 }
 
@@ -1351,34 +1355,26 @@ GtkWidget *ui_slik_credit(void)
 	GtkWidget *frame;
 	GtkWidget *hbox;
 	GtkWidget *label;
-	GtkWidget *pixmap;
-
+	GtkWidget *image;
 	GdkPixbuf *pb;
-	GdkPixmap *pmap;
-	GdkBitmap *mask;
-
 	gchar *buf;
 
 	frame = gtk_button_new();
 	gtk_button_set_relief(GTK_BUTTON(frame), GTK_RELIEF_NONE);
-	gtk_container_border_width(GTK_CONTAINER(frame), 10);
-	gtk_signal_connect(GTK_OBJECT(frame), "clicked",
-			   GTK_SIGNAL_FUNC(ui_slik_about), NULL);
+	gtk_container_set_border_width(GTK_CONTAINER(frame), 10);
+	g_signal_connect(G_OBJECT(frame), "clicked",
+			 G_CALLBACK(ui_slik_about), NULL);
 
 	hbox = gtk_hbox_new(FALSE, 5);
 	gtk_container_add(GTK_CONTAINER(frame), hbox);
 	gtk_widget_show(hbox);
 
-	pb = gdk_pixbuf_new_from_xpm_data(ui_slik_logo());
-	gdk_pixbuf_render_pixmap_and_mask(pb, &pmap, &mask, 128);
+	pb = ui_slik_logo();
+	image = gtk_image_new_from_pixbuf(pb);
 	gdk_pixbuf_unref(pb);
 
-	pixmap = gtk_pixmap_new(pmap, mask);
-	gdk_pixmap_unref(pmap);
-	if (mask) gdk_bitmap_unref(mask);
-
-	gtk_box_pack_start(GTK_BOX(hbox), pixmap, FALSE, FALSE, 0);
-	gtk_widget_show(pixmap);
+	gtk_box_pack_start(GTK_BOX(hbox), image, FALSE, FALSE, 0);
+	gtk_widget_show(image);
 
 	buf = g_strdup_printf(_("utilizes SLIK %s\nSimpLIstic sKin interface"), SLIK_VERSION);
 	label = gtk_label_new(buf);
