@@ -638,10 +638,10 @@ static void ui_menu_submenu_activate(UIMenuData *md, MenuItemData *mi,
 		const gchar *key = NULL;
 
 		ui_menu_submenu_new(mi, md->ui->class, mi->path);
-		gtk_signal_connect(GTK_OBJECT(mi->ui->window), "delete_event",
-				   GTK_SIGNAL_FUNC(ui_menu_submenu_delete_cb), mi);
-		gtk_signal_connect(GTK_OBJECT(mi->ui->window), "hide",
-				   GTK_SIGNAL_FUNC(ui_menu_submenu_hide_cb), mi);
+		g_signal_connect(G_OBJECT(mi->ui->window), "delete_event",
+				 G_CALLBACK(ui_menu_submenu_delete_cb), mi);
+		g_signal_connect(G_OBJECT(mi->ui->window), "hide",
+				 G_CALLBACK(ui_menu_submenu_hide_cb), mi);
 
 		if (mi->parent)
 			{
@@ -732,13 +732,13 @@ static UIData *ui_menu_submenu_new(MenuItemData *mi, const gchar *class, const g
 	ui_focus_set(ui, TRUE);
 
 #if 0
-	gtk_signal_connect(GTK_OBJECT(ui->display), "button_press_event",
-			   GTK_SIGNAL_FUNC(ui_menu_press_cb), mi);
+	g_signal_connect(G_OBJECT(ui->display), "button_press_event",
+			 G_CALLBACK(ui_menu_press_cb), mi);
 #endif
-	gtk_signal_connect(GTK_OBJECT(ui->display), "button_release_event",
-			   GTK_SIGNAL_FUNC(ui_menu_release_cb), mi);
-	gtk_signal_connect(GTK_OBJECT(ui->display), "key_press_event",
-			   GTK_SIGNAL_FUNC(ui_menu_key_cb), mi);
+	g_signal_connect(G_OBJECT(ui->display), "button_release_event",
+			 G_CALLBACK(ui_menu_release_cb), mi);
+	g_signal_connect(G_OBJECT(ui->display), "key_press_event",
+			 G_CALLBACK(ui_menu_key_cb), mi);
 
 	/* set it up */
 	list_register_key("menu", ui,
@@ -778,12 +778,12 @@ UIMenuData *ui_menu_new(const gchar *class, const gchar *key)
 	md->submenu_list = g_list_append(md->submenu_list, mi);
 	md->ui = ui_menu_submenu_new(mi, class, key);
 
-	gtk_signal_connect(GTK_OBJECT(mi->ui->window), "destroy",
-			   GTK_SIGNAL_FUNC(ui_menu_destroy), md);
-	gtk_signal_connect(GTK_OBJECT(mi->ui->window), "delete_event",
-			   GTK_SIGNAL_FUNC(ui_menu_delete_cb), md);
-	gtk_signal_connect(GTK_OBJECT(mi->ui->window), "hide",
-			   GTK_SIGNAL_FUNC(ui_menu_hide_cb), mi->ui);
+	g_signal_connect(G_OBJECT(mi->ui->window), "destroy",
+			 G_CALLBACK(ui_menu_destroy), md);
+	g_signal_connect(G_OBJECT(mi->ui->window), "delete_event",
+			 G_CALLBACK(ui_menu_delete_cb), md);
+	g_signal_connect(G_OBJECT(mi->ui->window), "hide",
+			 G_CALLBACK(ui_menu_hide_cb), mi->ui);
 
 	return md;
 }
@@ -802,7 +802,9 @@ static void ui_menu_submenu_show(UIMenuData *md, MenuItemData *mi, gint x, gint
 	mi->y = y;
 	ui_menu_calc_size(mi);
 
-	gtk_widget_popup(mi->ui->window, mi->x, mi->y);
+	if (!GTK_WIDGET_REALIZED(mi->ui->window)) gtk_widget_realize(mi->ui->window);
+	gdk_window_move(mi->ui->window->window, mi->x, mi->y);
+	gtk_widget_show(mi->ui->window);
 
 	mi->md->selection_done = FALSE;
 }
