@@ -70,7 +70,7 @@ DigitData *digit_new_from_file(const gchar *file)
 {
 	GdkPixbuf *pb;
 
-	pb = gdk_pixbuf_new_from_file(file);
+	pb = util_pixbuf_new_from_file(file);
 
 	return digit_new(pb);
 }
