@@ -19,13 +19,13 @@
 
 #include "skin_compat.h"
 #include "skin_wamp.h"
-#include "ui_fileops.h"
 
 /* GQmpeg compatibility end */
 
 #include "ui2_skin.h"
 #include "ui2_util.h"
 #include "ui2_widget.h"
+#include "ui_fileops.h"
 
 
 static gint vector_length(gchar **vector)
@@ -175,7 +175,7 @@ static gint skin_parse_main(SkinData *s, GList *list, const gchar *skin_dir, gin
 	mask = key_list_read_path(list, "mask", skin_dir);
 	s->transparent = key_list_read_bool(list, "transparent");
 
-	s->real_overlay = util_size_pixbuf(gdk_pixbuf_new_from_file(filename), TRUE);
+	s->real_overlay = util_size_pixbuf(util_pixbuf_new_from_file(filename), TRUE);
 
 	if (s->real_overlay)
 		{
@@ -192,7 +192,7 @@ static gint skin_parse_main(SkinData *s, GList *list, const gchar *skin_dir, gin
 
 	if (mask)
 		{
-		s->mask = util_size_pixbuf(gdk_pixbuf_new_from_file(mask), FALSE);
+		s->mask = util_size_pixbuf(util_pixbuf_new_from_file(mask), FALSE);
 		if (s->mask && edit) s->background_mask_filename = g_strdup(mask);
 		g_free(mask);
 		}
@@ -275,7 +275,7 @@ static gint skin_parse_main(SkinData *s, GList *list, const gchar *skin_dir, gin
 	filename = key_list_read_path(list, "focus", skin_dir);
 	if (filename && !s->focus_overlay)
 		{
-		s->focus_overlay = util_size_pixbuf(gdk_pixbuf_new_from_file(filename), TRUE);
+		s->focus_overlay = util_size_pixbuf(util_pixbuf_new_from_file(filename), TRUE);
 
 		if (!s->focus_overlay) printf("failed to load file \"%s\"\n", filename);
 		if (edit) s->focus_filename = g_strdup(filename);
@@ -375,8 +375,11 @@ SkinData *skin_parse(const gchar *skin_dir, const gchar *datafile, gint edit)
 	GList *list;
 	gchar *section;
 	gint fail = 0;
+	gchar *pathl;
 
-	f = fopen(datafile, "r");
+	pathl = path_from_utf8(datafile);
+	f = fopen(pathl, "r");
+	g_free(pathl);
 	if (!f)
 		{
 
