@@ -22,6 +22,8 @@
 #include "ui2_widget.h"
 #include "ui_pixbuf_ops.h"
 
+#include <gdk/gdkkeysyms.h> /* for key values */
+
 
 /*
  *-------------
@@ -237,7 +239,10 @@ gint skin_widget_for_each_key(UIData *ui, const gchar *key, WidgetType type,
 	 */
 	if (parent != ui && count > 0) return count;
 
-	count += skin_widget_for_each_do(parent, key, type, func, data);
+	if (parent != ui)
+		{
+		count += skin_widget_for_each_do(parent, key, type, func, data);
+		}
 
 	work = parent->children;
 	while (work)
@@ -324,6 +329,11 @@ SkinData *skin_new(void)
 	skin->focus_box_g = 0;
 	skin->focus_box_b = 0;
 
+	skin->scratch_pixbuf = NULL;
+	skin->scratch_pixmap = NULL;
+
+	skin->resize_idle_id = -1;
+
 	return skin;
 }
 
@@ -331,7 +341,9 @@ void skin_free(SkinData *skin)
 {
 	if (!skin) return;
 
-	while(skin->widget_list)
+	if (skin->resize_idle_id != -1) gtk_idle_remove(skin->resize_idle_id);
+
+	while (skin->widget_list)
 		{
 		WidgetData *wd = skin->widget_list->data;
 		skin->widget_list = g_list_remove(skin->widget_list, wd);
@@ -348,6 +360,9 @@ void skin_free(SkinData *skin)
 
 	if (skin->focus_overlay) gdk_pixbuf_unref(skin->focus_overlay);
 
+	if (skin->scratch_pixbuf) gdk_pixbuf_unref(skin->scratch_pixbuf);
+	if (skin->scratch_pixmap) gdk_pixmap_unref(skin->scratch_pixmap);
+
 	g_free(skin->background_filename);
 	g_free(skin->background_mask_filename);
 	g_free(skin->focus_filename);
@@ -355,6 +370,40 @@ void skin_free(SkinData *skin)
 	g_free(skin);
 }
 
+void skin_get_scratch(SkinData *skin, gint w, gint h, GdkPixbuf **pixbuf, GdkPixmap **pixmap)
+{
+	gint old_w, old_h;
+
+	if (skin->scratch_pixbuf)
+		{
+		old_w = gdk_pixbuf_get_width(skin->scratch_pixbuf);
+		old_h = gdk_pixbuf_get_height(skin->scratch_pixbuf);
+		}
+	else
+		{
+		old_w = 0;
+		old_h = 0;
+		}
+
+	if (w > old_w || h > old_h)
+		{
+		/* scratch buffer dimensions can only grow,
+		 * to reduce needing to recreate for each widget size
+		 */
+		if (old_w > w) w = old_w;
+		if (old_h > h) h = old_h;
+
+		if (skin->scratch_pixbuf) gdk_pixbuf_unref(skin->scratch_pixbuf);
+		skin->scratch_pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB, FALSE, 8, w, h);
+
+		if (skin->scratch_pixmap) gdk_pixmap_unref(skin->scratch_pixmap);
+		skin->scratch_pixmap = gdk_pixmap_new(skin->ui->display->window, w, h, -1);
+		}
+
+	if (pixbuf) *pixbuf = skin->scratch_pixbuf;
+	if (pixmap) *pixmap = skin->scratch_pixmap;
+}
+
 GdkPixmap *skin_get_buffer(SkinData *skin)
 {
 	return skin->buffer;
@@ -367,6 +416,7 @@ GdkPixbuf *skin_get_pixbuf(SkinData *skin)
 
 UIData *skin_get_ui(SkinData *skin)
 {
+	if (!skin) return NULL;
 	return skin->ui;
 }
 
@@ -553,32 +603,45 @@ static void skin_move_anchored(SkinData *skin, gint move_w, gint move_h)
 
 void skin_resize(UIData *ui, gint w, gint h)
 {
+	SkinData *skin;
 	gint x, y;
 	gint dw, dh;
 
+	skin = ui->skin;
+
+	if (skin->resize_idle_id != -1)
+		{
+		gtk_idle_remove(skin->resize_idle_id);
+		skin->resize_idle_id = -1;
+		}
+
 	if (w > SKIN_SIZE_MAX) w = SKIN_SIZE_MAX;
 	if (h > SKIN_SIZE_MAX) h = SKIN_SIZE_MAX;
 	if (w < SKIN_SIZE_MIN) w = SKIN_SIZE_MIN;
 	if (h < SKIN_SIZE_MIN) h = SKIN_SIZE_MIN;
 
-	if (w == ui->skin->width && h == ui->skin->height) return;
+	/* keyboard resize expects this to be in sync */
+	skin->resize_idle_width = w;
+	skin->resize_idle_height = h;
+
+	if (w == skin->width && h == skin->height) return;
 	if (w < 4 || h < 4) return;
 
 	x = y = 0;
 
-	if (ui->window) gdk_window_get_position(ui->window->window, &x, &y);
+	if (ui->window && ui->window->window) gdk_window_get_position(ui->window->window, &x, &y);
 
-	dw = w - ui->skin->width;
-	dh = h - ui->skin->height;
+	dw = w - skin->width;
+	dh = h - skin->height;
 
-	ui->skin->width = w;
-	ui->skin->height = h;
+	skin->width = w;
+	skin->height = h;
 
-	skin_move_anchored(ui->skin, dw, dh);
+	skin_move_anchored(skin, dw, dh);
 
 	ui_display_sync_all(ui);
 
-	if (ui->window) gdk_window_move(ui->window->window, x, y);
+	if (ui->window && ui->window->window) gdk_window_move(ui->window->window, x, y);
 }
 
 /*
@@ -614,6 +677,23 @@ void skin_widgets_init(SkinData *skin, UIData *ui)
  */
 
 static void (*skin_size_func_motion)(gpointer, const gchar *, gint, gint, GdkPixbuf *, UIData *) = NULL;
+static gint (*skin_size_func_key)(gpointer widget, const gchar *key, GdkEventKey *event, GdkPixbuf *pb, UIData *ui) = NULL;
+
+static gint skin_resize_idle_cb(gpointer data)
+{
+	SkinData *skin = data;
+
+	if (skin->resize_idle_id == -1) return FALSE;
+
+	skin->resize_idle_id = -1;
+
+	skin->ui->press_x += skin->resize_idle_width - skin->width;
+	skin->ui->press_y += skin->resize_idle_height - skin->height;
+
+	skin_resize(skin->ui, skin->resize_idle_width, skin->resize_idle_height);
+
+	return FALSE;
+}
 
 static void skin_resize_real_motion(gpointer widget, const gchar *key, gint x, gint y, GdkPixbuf *pb, UIData *ui)
 {
@@ -655,11 +735,9 @@ static void skin_resize_real_motion(gpointer widget, const gchar *key, gint x, g
 		    button->y + h >= 0)
 			{
 			/* resize it */
-			skin_resize(ui, nw, nh);
-
-			/* remember last event */
-			ui->press_x += w;
-			ui->press_y += h;
+			skin->resize_idle_width = nw;
+			skin->resize_idle_height = nh;
+			if (skin->resize_idle_id == -1) skin->resize_idle_id = gtk_idle_add(skin_resize_idle_cb, skin);
 			}
 		}
 
@@ -668,6 +746,99 @@ static void skin_resize_real_motion(gpointer widget, const gchar *key, gint x, g
 	if (skin_size_func_motion) skin_size_func_motion(widget, key, x, y, ui->skin->pixbuf, ui);
 }
 
+static gint skin_resize_real_key(gpointer widget, const gchar *key, GdkEventKey *event, GdkPixbuf *pb, UIData *ui)
+{
+	SkinData *skin;
+	gint nw, nh;
+	gint ret = TRUE;
+
+	if (!ui->skin->sizeable || !ui->skin->real_overlay ||
+	    !(event->state & GDK_SHIFT_MASK))
+		{
+		if (skin_size_func_key)
+			{
+			/* pass key press on to button */
+			return skin_size_func_key(widget, key, event, ui->skin->pixbuf, ui);
+			}
+		return FALSE;
+		}
+
+	skin = ui->skin;
+
+	if (skin->resize_idle_width < 4 || skin->resize_idle_height < 4)
+		{
+		/* probably default skin size, hence no skin_resize has been called yet */
+		nw = skin->width;
+		nh = skin->height;
+		}
+	else
+		{
+		nw = skin->resize_idle_width;
+		nh = skin->resize_idle_height;
+		}
+
+	switch (event->keyval)
+		{
+		case GDK_Up:
+		case GDK_KP_Up:
+			nh -= skin->height_inc;
+			break;
+		case GDK_Down:
+		case GDK_KP_Down:
+			nh += skin->height_inc;
+			break;
+		case GDK_Left:
+		case GDK_KP_Left:
+			nw -= skin->width_inc;
+			break;
+		case GDK_Right:
+		case GDK_KP_Right:
+			nw += skin->width_inc;
+			break;
+		case GDK_Page_Up:
+		case GDK_KP_Page_Up:
+			nw = skin->width_min;
+			nh = skin->height_min;
+			break;
+		case GDK_Page_Down:
+		case GDK_KP_Page_Down:
+			nw = skin->width_max;
+			nh = skin->height_max;
+			break;
+		case GDK_Home:
+		case GDK_KP_Home:
+			nw = skin->width_def;
+			nh = skin->height_def;
+			break;
+		default:
+			ret = FALSE;
+			break;
+		}
+
+	if (ret)
+		{
+		if (nw < skin->width_min) nw = skin->width_min;
+		if (nw > skin->width_max) nw = skin->width_max;
+		if (nh < skin->height_min) nh = skin->height_min;
+		if (nh > skin->height_max) nh = skin->height_max;
+
+		if (nw != skin->resize_idle_width || nh != skin->resize_idle_height)
+			{
+			skin->resize_idle_width = nw;
+			skin->resize_idle_height = nh;
+			if (skin->resize_idle_id == -1) skin->resize_idle_id = gtk_idle_add(skin_resize_idle_cb, skin);
+			}
+		}
+
+	/* if not handled, pass it on to the button */
+	if (!ret && skin_size_func_key)
+		{
+		return skin_size_func_key(widget, key, event, ui->skin->pixbuf, ui);
+		}
+	
+	return ret;
+}
+
 static void skin_resize_setup_cb(WidgetData *wd, gpointer data)
 {
 	static WidgetObjectData *od = NULL;
@@ -678,8 +849,12 @@ static void skin_resize_setup_cb(WidgetData *wd, gpointer data)
 	if (!od)
 		{
 		od = ui_widget_object_copy(ui_widget_object_by_type(button_type_id()));
+
 		skin_size_func_motion = od->func_motion;
 		od->func_motion = skin_resize_real_motion;
+
+		skin_size_func_key = od->func_focus_key_event;
+		od->func_focus_key_event = skin_resize_real_key;
 		}
 
 	if (od && wd->od)
@@ -698,4 +873,3 @@ void skin_finalize(SkinData *skin)
 	skin_widget_for_each_key_simple(skin, "skin_size", button_type_id(),
 					skin_resize_setup_cb, skin);
 }
-
