@@ -154,7 +154,7 @@ SliderData *slider_new_from_file(const gchar *file, gint x, gint y,
 {
 	GdkPixbuf *pb;
 
-	pb = gdk_pixbuf_new_from_file(file);
+	pb = util_pixbuf_new_from_file(file);
 
 	return slider_new(pb, x, y, length, vertical, reversed, has_press, prelight, item_key);
 }
