@@ -24,6 +24,17 @@
 #include "ui_utildlg.h"
 
 
+enum {
+	SLIDER_COLUMN_POINTER = 0,
+	SLIDER_COLUMN_IMAGE,
+	SLIDER_COLUMN_KEY,
+	SLIDER_COLUMN_VERTICAL,
+	SLIDER_COLUMN_PRESS,
+	SLIDER_COLUMN_PRELIGHT,
+	SLIDER_COLUMN_COUNT
+};
+
+
 typedef struct _SliderDetail SliderDetail;
 struct _SliderDetail
 {
@@ -93,8 +104,8 @@ struct _SliderPage
 
 	GtkWidget *item_key_entry;
 
-	GtkWidget *clist;
-	GtkWidget *pixmap;
+	GtkWidget *list;
+	GtkWidget *image;
 
 	EditData *ed;
 };
@@ -363,34 +374,34 @@ static gpointer slider_edit_props(UIData *ui, WidgetData *wd, GtkWidget *vbox, g
 		hbox = ui_edit_frame_new(vbox2, FALSE, NULL);
 
 		sd->real_length_spin = ui_edit_spin_new(hbox, _("Length:"), 1, SKIN_SIZE_MAX, &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(slider_edit_props_real_length_cb), sd);
+		g_signal_connect(adj, "value_changed",
+				   G_CALLBACK(slider_edit_props_real_length_cb), sd);
 
 		sd->stretch_button = ui_edit_toggle_new(hbox, _("Stretch"));
-		gtk_signal_connect(GTK_OBJECT(sd->stretch_button), "clicked",
-				   GTK_SIGNAL_FUNC(slider_edit_props_stretch_cb), sd);
+		g_signal_connect(G_OBJECT(sd->stretch_button), "clicked",
+				 G_CALLBACK(slider_edit_props_stretch_cb), sd);
 
 		hbox = ui_edit_frame_new(vbox2, FALSE, NULL);
 
 		sd->border_1_spin = ui_edit_spin_new(hbox, _("Border 1:"), 0, SKIN_SIZE_MAX, &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(slider_edit_props_border_1_cb), sd);
+		g_signal_connect(adj, "value_changed",
+				   G_CALLBACK(slider_edit_props_border_1_cb), sd);
 
 		sd->border_2_spin = ui_edit_spin_new(hbox, _("Border 2:"), 0, SKIN_SIZE_MAX, &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(slider_edit_props_border_2_cb), sd);
+		g_signal_connect(adj, "value_changed",
+				   G_CALLBACK(slider_edit_props_border_2_cb), sd);
 
 		sd->sizeable_button = ui_edit_toggle_new(vbox, _("Dynamic size"));
-		gtk_signal_connect(GTK_OBJECT(sd->sizeable_button), "clicked",
-				   GTK_SIGNAL_FUNC(slider_edit_props_sizeable_cb), sd);
+		g_signal_connect(G_OBJECT(sd->sizeable_button), "clicked",
+				 G_CALLBACK(slider_edit_props_sizeable_cb), sd);
 
 		sd->reverse_button = ui_edit_toggle_new(vbox, _("Reverse"));
-		gtk_signal_connect(GTK_OBJECT(sd->reverse_button), "clicked",
-				   GTK_SIGNAL_FUNC(slider_edit_props_reversed_cb), sd);
+		g_signal_connect(G_OBJECT(sd->reverse_button), "clicked",
+				 G_CALLBACK(slider_edit_props_reversed_cb), sd);
 
 		sd->item_key_entry = ui_edit_entry_new(vbox, _("Item link key:") );
-		gtk_signal_connect(GTK_OBJECT(sd->item_key_entry), "changed",
-				   GTK_SIGNAL_FUNC(slider_edit_props_item_key_cb), sd);
+		g_signal_connect(G_OBJECT(sd->item_key_entry), "changed",
+				 G_CALLBACK(slider_edit_props_item_key_cb), sd);
 		}
 
 	sd->slider = slider;
@@ -485,12 +496,16 @@ static void slider_edit_page_sync(SliderPage *pd, SliderListData *sd)
 	ui_edit_entry_set(pd->item_key_entry, sd->item_key);
 }
 
-static void slider_edit_page_clist_cb(GtkWidget *clist, gint row, gint col, GdkEvent *event, gpointer data)
+static void slider_edit_page_list_cb(GtkTreeSelection *selection, gpointer data)
 {
 	SliderPage *pd = data;
 	SliderListData *sd;
+	GtkTreeModel *store;
+	GtkTreeIter iter;
 
-	sd = gtk_clist_get_row_data(GTK_CLIST(clist), row);
+	if (!gtk_tree_selection_get_selected(selection, &store, &iter)) return;
+
+	gtk_tree_model_get(store, &iter, SLIDER_COLUMN_POINTER, &sd, -1);
 	slider_edit_page_sync(pd, sd);
 }
 
@@ -509,16 +524,16 @@ static GtkWidget *slider_edit_page_new(EditData *ed)
 	GtkWidget *vbox2;
 	GtkWidget *button;
 	SliderPage *pd;
-	gchar *titles[] = { _("Image"), _("Key"), _("Vertical"), _("Press"), _("Prelight"), NULL };
+	GtkListStore *store;
 
 	pd = g_new0(SliderPage, 1);
 	pd->ed = ed;
 
 	hbox = gtk_hbox_new(FALSE, 5);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
-	gtk_object_set_data(GTK_OBJECT(hbox), "page", pd);
-	gtk_signal_connect(GTK_OBJECT(hbox), "destroy",
-			   GTK_SIGNAL_FUNC(slider_edit_page_destroy_cb), pd);
+	g_object_set_data(G_OBJECT(hbox), "page", pd);
+	g_signal_connect(G_OBJECT(hbox), "destroy",
+			 G_CALLBACK(slider_edit_page_destroy_cb), pd);
 
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
@@ -547,20 +562,28 @@ static GtkWidget *slider_edit_page_new(EditData *ed)
 	pd->length_spin = ui_edit_spin_new(vbox, _("Trough length:"), 1, SKIN_SIZE_MAX, NULL);
 
 	pd->image_entry = ui_edit_path_entry_new(vbox, _("Image:"), "SLIK_slider_image");
-	pd->pixmap = ui_edit_pixmap_new(vbox);
-	ui_edit_path_entry_connect_pixmap(pd->image_entry, pd->pixmap);
+	pd->image = ui_edit_image_new(vbox);
+	ui_edit_path_entry_connect_image(pd->image_entry, pd->image);
 
 	pd->item_key_entry = ui_edit_entry_new(vbox, _("Item link key:"));
 
 	button = gtk_button_new_with_label(_("Add"));
 	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			   GTK_SIGNAL_FUNC(slider_edit_page_add_cb), pd);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(slider_edit_page_add_cb), pd);
 	gtk_widget_show(button);
 
-	pd->clist = ui_edit_clist_new(hbox, titles, 5);
-	gtk_signal_connect(GTK_OBJECT(pd->clist), "select_row",
-			   GTK_SIGNAL_FUNC(slider_edit_page_clist_cb), pd);
+	store = gtk_list_store_new(6, G_TYPE_POINTER, GDK_TYPE_PIXBUF, G_TYPE_STRING,
+				      G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN);
+	pd->list = ui_edit_list_new(hbox, store,
+				    G_CALLBACK(slider_edit_page_list_cb), pd);
+	g_object_unref(store);
+
+	ui_edit_list_add_column(pd->list, _("Image"), SLIDER_COLUMN_IMAGE, TRUE, FALSE);
+	ui_edit_list_add_column(pd->list, _("Key"), SLIDER_COLUMN_KEY, FALSE, FALSE);
+	ui_edit_list_add_column(pd->list, _("Vertical"), SLIDER_COLUMN_VERTICAL, FALSE, FALSE);
+	ui_edit_list_add_column(pd->list, _("Press"), SLIDER_COLUMN_PRESS, FALSE, FALSE);
+	ui_edit_list_add_column(pd->list, _("Prelight"), SLIDER_COLUMN_PRELIGHT, FALSE, FALSE);
 
 	gtk_widget_show(hbox);
 
@@ -571,18 +594,25 @@ static void slider_edit_page_add(GtkWidget *widget, gpointer data)
 {
 	SliderListData *sd = data;
 	SliderPage *pd;
-	gchar *buf[6];
+	GtkListStore *store;
+	GtkTreeIter iter;
+	GdkPixbuf *pixbuf;
 
-	pd = gtk_object_get_data(GTK_OBJECT(widget), "page");
+	pd = g_object_get_data(G_OBJECT(widget), "page");
+	store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(pd->list)));
 
-	buf[0] = "";
-	buf[1] = sd->key;
-	buf[2] = ui_edit_bool_to_text(sd->vertical);
-	buf[3] = ui_edit_bool_to_text(sd->has_press);
-	buf[4] = ui_edit_bool_to_text(sd->has_prelight);
-	buf[5] = NULL;
+	pixbuf = ui_edit_list_pixbuf_from_file(sd->image);
 
-	ui_edit_clist_append(pd->clist, buf, sd->image, sd);
+	gtk_list_store_append(store, &iter);
+	gtk_list_store_set(store, &iter,
+			   SLIDER_COLUMN_POINTER, sd,
+			   SLIDER_COLUMN_IMAGE, pixbuf,
+			   SLIDER_COLUMN_KEY, sd->key,
+			   SLIDER_COLUMN_VERTICAL, sd->vertical,
+			   SLIDER_COLUMN_PRESS, sd->has_press,
+			   SLIDER_COLUMN_PRELIGHT, sd->has_prelight, -1);
+
+	if (pixbuf) gdk_pixbuf_unref(pixbuf);
 }
 
 void slider_type_init_edit(WidgetObjectData *od)
