@@ -111,7 +111,7 @@ FontData *font_new_from_file(const gchar *file, gint extended)
 {
 	GdkPixbuf *pb;
 
-	pb = gdk_pixbuf_new_from_file(file);
+	pb = util_pixbuf_new_from_file(file);
 
 	return font_new(pb, extended);
 }
@@ -203,7 +203,7 @@ static void font_draw_char(FontData *font, guint8 c,
 		{
 		if (c >= 32 && c < 128)
 			c -= 32;
-		else if (c >= 160 && c < 256)
+		else if (c >= 160 && c < 255)
 			c -= 64;
 		else
 			c = 0;
@@ -212,7 +212,7 @@ static void font_draw_char(FontData *font, guint8 c,
 		{
 		if (c >= 32 && c < 128)
 			c -= 32;
-		else if (c >= 160 && c < 256)
+		else if (c >= 160 && c < 255)
 			/* translate to a limited set */
 			c = iso_ascii[c - 160] - 32;
 		else
@@ -974,11 +974,12 @@ static void text_scroll_update_set(TextData *text, gint enable)
 {
 	if (enable && text->scroll_cb_id == -1)
 		{
-		text->scroll_cb_id = gtk_timeout_add(1000 / text->autoscroll_delay, text_scroll_update_cb, text);
+		text->scroll_cb_id = g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, 1000 / text->autoscroll_delay,
+							text_scroll_update_cb, text, NULL);
 		}
 	else if (!enable && text->scroll_cb_id != -1)
 		{
-		gtk_timeout_remove(text->scroll_cb_id);
+		g_source_remove(text->scroll_cb_id);
 		text->scroll_cb_id = -1;
 		}
 }
