@@ -189,6 +189,15 @@ void font_type_init_edit(WidgetObjectData *od)
  */
 
 
+enum {
+	TEXT_COLUMN_POINTER = 0,
+	TEXT_COLUMN_IMAGE,
+	TEXT_COLUMN_KEY,
+	TEXT_COLUMN_EXTENDED,
+	TEXT_COLUMN_COUNT
+};
+
+
 typedef struct _TextDetail TextDetail;
 struct _TextDetail
 {
@@ -232,8 +241,8 @@ struct _TextPage
 	GtkWidget *blue_spin;
 	GtkWidget *alpha_spin;
 
-	GtkWidget *clist;
-	GtkWidget *pixmap;
+	GtkWidget *list;
+	GtkWidget *image;
 
 	GtkWidget *font_key_entry;
 
@@ -465,18 +474,18 @@ static gpointer text_edit_props(UIData *ui, WidgetData *wd, GtkWidget *vbox, gpo
 		gtk_widget_set_sensitive(td->extended_button, FALSE);
 
 		td->sizeable_button = ui_edit_toggle_new(vbox, _("Dynamic size"));
-		gtk_signal_connect(GTK_OBJECT(td->sizeable_button), "clicked",
-				   GTK_SIGNAL_FUNC(text_edit_props_sizeable_cb), td);
+		g_signal_connect(G_OBJECT(td->sizeable_button), "clicked",
+				 G_CALLBACK(text_edit_props_sizeable_cb), td);
 
 		hbox = ui_edit_frame_new(vbox, FALSE, NULL);
 		td->spin_width = ui_edit_spin_new(hbox, _("Width:"), 1, 2000, &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(text_edit_props_width_cb), td);
+		g_signal_connect(adj, "value_changed",
+				   G_CALLBACK(text_edit_props_width_cb), td);
 		td->spin_rotation = ui_edit_spin_new(hbox, _("Rotation:"), 0, 270, &adj);
 		GTK_ADJUSTMENT(adj)->step_increment = 90.0;
 		gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(td->spin_rotation), TRUE);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(text_edit_props_rotation_cb), td);
+		g_signal_connect(adj, "value_changed",
+				   G_CALLBACK(text_edit_props_rotation_cb), td);
 
 		td->font_entry = ui_edit_entry_new(vbox, _("Font:"));
 		ui_edit_frame_sensitive(td->font_entry, FALSE, TRUE);
@@ -484,18 +493,18 @@ static gpointer text_edit_props(UIData *ui, WidgetData *wd, GtkWidget *vbox, gpo
 		hbox = ui_edit_frame_new(vbox, TRUE, _("Color"));
 
 		td->red_spin = ui_edit_spin_new(hbox, _("Red:"), 0, 255, &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(text_edit_props_color_cb), td);
+		g_signal_connect(adj, "value_changed",
+				   G_CALLBACK(text_edit_props_color_cb), td);
 		td->green_spin = ui_edit_spin_new(hbox, _("Green:"), 0, 255, &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(text_edit_props_color_cb), td);
+		g_signal_connect(adj, "value_changed",
+				   G_CALLBACK(text_edit_props_color_cb), td);
 		td->blue_spin = ui_edit_spin_new(hbox, _("Blue:"), 0, 255, &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(text_edit_props_color_cb), td);
+		g_signal_connect(adj, "value_changed",
+				   G_CALLBACK(text_edit_props_color_cb), td);
 
 		td->alpha_spin = ui_edit_spin_new(vbox, _("Alpha:"), 0, 255, &adj);
-		gtk_signal_connect(adj, "value_changed",
-				   GTK_SIGNAL_FUNC(text_edit_props_color_cb), td);
+		g_signal_connect(adj, "value_changed",
+				   G_CALLBACK(text_edit_props_color_cb), td);
 
 		hbox = ui_edit_frame_new(vbox, FALSE, NULL);
 
@@ -666,12 +675,16 @@ static void text_edit_page_sync(TextPage *pd, FontListData *fd)
 	ui_edit_toggle_set(pd->extended_button, fd->extended);
 }
 
-static void text_edit_page_clist_cb(GtkWidget *clist, gint row, gint col, GdkEvent *event, gpointer data)
+static void text_edit_page_list_cb(GtkTreeSelection *selection, gpointer data)
 {
 	TextPage *pd = data;
 	FontListData *fd;
+	GtkTreeModel *store;
+	GtkTreeIter iter;
 
-	fd = gtk_clist_get_row_data(GTK_CLIST(clist), row);
+	if (!gtk_tree_selection_get_selected(selection, &store, &iter)) return;
+
+	gtk_tree_model_get(store, &iter, TEXT_COLUMN_POINTER, &fd, -1);
 	text_edit_page_sync(pd, fd);
 }
 
@@ -704,16 +717,16 @@ static GtkWidget *text_edit_page_new(EditData *ed)
 	GtkWidget *sep;
 	GtkObject *adj;
 	TextPage *pd;
-	gchar *titles[] = { _("Image"), _("Key"), _("Extended"), NULL };
+	GtkListStore *store;
 
 	pd = g_new0(TextPage, 1);
 	pd->ed = ed;
 
 	hbox = gtk_hbox_new(FALSE, 5);
 	gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
-	gtk_object_set_data(GTK_OBJECT(hbox), "page", pd);
-	gtk_signal_connect(GTK_OBJECT(hbox), "destroy",
-			   GTK_SIGNAL_FUNC(text_edit_page_destroy_cb), pd);
+	g_object_set_data(G_OBJECT(hbox), "page", pd);
+	g_signal_connect(G_OBJECT(hbox), "destroy",
+			 G_CALLBACK(text_edit_page_destroy_cb), pd);
 
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
@@ -735,16 +748,16 @@ static GtkWidget *text_edit_page_new(EditData *ed)
 	gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(pd->spin_rotation), TRUE);
 
 	pd->font_id_entry = ui_edit_entry_new(vbox, _("Font key:"));
-	gtk_signal_connect(GTK_OBJECT(pd->font_id_entry), "changed",
-			   GTK_SIGNAL_FUNC(text_edit_page_font_cb), pd);
+	g_signal_connect(G_OBJECT(pd->font_id_entry), "changed",
+			 G_CALLBACK(text_edit_page_font_cb), pd);
 
 	pd->font_entry = ui_edit_font_entry_new(vbox, _("Font:"));
-	gtk_signal_connect(GTK_OBJECT(pd->font_entry), "changed",
-			   GTK_SIGNAL_FUNC(text_edit_page_font_cb), pd);
+	g_signal_connect(G_OBJECT(pd->font_entry), "changed",
+			 G_CALLBACK(text_edit_page_font_cb), pd);
 
 	pd->image_entry = ui_edit_path_entry_new(vbox, _("Image:"), "SLIK_text_image");
-	pd->pixmap = ui_edit_pixmap_new(vbox);
-	ui_edit_path_entry_connect_pixmap(pd->image_entry, pd->pixmap);
+	pd->image = ui_edit_image_new(vbox);
+	ui_edit_path_entry_connect_image(pd->image_entry, pd->image);
 
 	frame = ui_edit_frame_new(vbox, TRUE, _("Color"));
 	pd->red_spin = ui_edit_spin_new(frame, _("Red:"), 0, 255, NULL);
@@ -755,8 +768,8 @@ static GtkWidget *text_edit_page_new(EditData *ed)
 
 	button = gtk_button_new_with_label(_("Add"));
 	gtk_box_pack_start(GTK_BOX(vbox), button, FALSE, FALSE, 0);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			   GTK_SIGNAL_FUNC(text_edit_page_add_cb), pd);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(text_edit_page_add_cb), pd);
 	gtk_widget_show(button);
 
 	sep = gtk_hseparator_new();
@@ -768,13 +781,19 @@ static GtkWidget *text_edit_page_new(EditData *ed)
 
 	button = gtk_button_new_with_label(_("Add"));
 	gtk_box_pack_end(GTK_BOX(frame), button, FALSE, FALSE, 0);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			   GTK_SIGNAL_FUNC(text_edit_page_font_add_cb), pd);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(text_edit_page_font_add_cb), pd);
 	gtk_widget_show(button);
 
-	pd->clist = ui_edit_clist_new(hbox, titles, 3);
-	gtk_signal_connect(GTK_OBJECT(pd->clist), "select_row",
-			   GTK_SIGNAL_FUNC(text_edit_page_clist_cb), pd);
+	store = gtk_list_store_new(4, G_TYPE_POINTER, GDK_TYPE_PIXBUF, G_TYPE_STRING,
+				      G_TYPE_BOOLEAN);
+	pd->list = ui_edit_list_new(hbox, store,
+				    G_CALLBACK(text_edit_page_list_cb), pd);
+	g_object_unref(store);
+
+	ui_edit_list_add_column(pd->list, _("Image"), TEXT_COLUMN_IMAGE, TRUE, FALSE);
+	ui_edit_list_add_column(pd->list, _("Key"), TEXT_COLUMN_KEY, FALSE, FALSE);
+	ui_edit_list_add_column(pd->list, _("Extended"), TEXT_COLUMN_EXTENDED, FALSE, FALSE);
 
 	gtk_widget_show(hbox);
 
@@ -794,16 +813,23 @@ static void text_edit_page_add(GtkWidget *widget, gpointer data)
 {
 	FontListData *fd = data;
 	TextPage *pd;
-	gchar *buf[4];
+	GtkListStore *store;
+	GtkTreeIter iter;
+	GdkPixbuf *pixbuf;
 
-	pd = gtk_object_get_data(GTK_OBJECT(widget), "page");
+	pd = g_object_get_data(G_OBJECT(widget), "page");
+	store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(pd->list)));
 
-	buf[0] = "";
-	buf[1] = fd->key;
-	buf[2] = ui_edit_bool_to_text(fd->extended);
-	buf[3] = NULL;
+	pixbuf = ui_edit_list_pixbuf_from_file(fd->image);
 
-	ui_edit_clist_append(pd->clist, buf, fd->image, fd);
+	gtk_list_store_append(store, &iter);
+	gtk_list_store_set(store, &iter,
+			   TEXT_COLUMN_POINTER, fd,
+			   TEXT_COLUMN_IMAGE, pixbuf,
+			   TEXT_COLUMN_KEY, fd->key,
+			   TEXT_COLUMN_EXTENDED, fd->extended, -1);
+
+	if (pixbuf) gdk_pixbuf_unref(pixbuf);
 }
 
 void text_type_init_edit(WidgetObjectData *od)
