@@ -19,7 +19,7 @@
  *-------------------------------------
  */
 
-#define SLIK_VERSION "0.13.0"
+#define SLIK_VERSION "0.90.0"
 
 #define SKIN_SIZE_MIN 4
 #define SKIN_SIZE_MAX 2000
@@ -269,7 +269,7 @@ struct _EditData
 
 	WidgetData *info_widget;
 
-	GtkWidget *widget_clist;
+	GtkWidget *widget_list;
 	GtkWidget *spin_x;
 	GtkWidget *spin_y;
 	GtkWidget *description;
@@ -277,7 +277,7 @@ struct _EditData
 	GtkWidget *data_entry;
 	GtkWidget *text_id_entry;
 	GtkWidget *image_entry;
-	GtkWidget *widget_pixmap;
+	GtkWidget *widget_image;
 	GtkWidget *clip_mask_entry;
 
 	GtkWidget *anchor_right_button;
