@@ -138,6 +138,129 @@ void pixbuf_copy_area_alpha(GdkPixbuf *src, gint sx, gint sy,
 	_pixbuf_copy_area_alpha(src, sx, sy, dest, dx, dy, w, h, TRUE, alpha_modifier, FALSE);
 }
 
+/*
+ *  like above, but uses a clip region and/or mask
+ */
+void pixbuf_copy_area_alpha_with_clipping(GdkPixbuf *src, gint sx, gint sy,
+					  GdkPixbuf *dest, gint dx, gint dy,
+					  gint w, gint h, gint alpha_modifier,
+					  gint clip_x, gint clip_y, gint clip_w, gint clip_h, GdkPixbuf *clip_pb)
+{
+	gint s_alpha;
+	gint d_alpha;
+	gint sw, sh, srs, s_step;
+	gint dw, dh, drs, d_step;
+	guchar *s_pix;
+	guchar *d_pix;
+	guchar *sp;
+	guchar *dp;
+	guchar *clip_pix;
+	gint clip_rs;
+	gint cx, cy;
+	guchar *cp;
+	guchar r, g, b, a;
+	gint i, j;
+	gint clip_x2, clip_y2;
+
+	if (!src || !dest) return;
+
+	if (clip_pb && gdk_pixbuf_get_has_alpha(clip_pb))
+		{
+		clip_w = MIN(clip_w, (gdk_pixbuf_get_width(clip_pb)));
+		clip_h = MIN(clip_h, (gdk_pixbuf_get_height(clip_pb)));
+		clip_pix = gdk_pixbuf_get_pixels(clip_pb);
+		clip_rs = gdk_pixbuf_get_rowstride(clip_pb);
+		}
+	else
+		{
+		clip_pix = NULL;
+		clip_rs = 0;
+		}
+
+	sw = gdk_pixbuf_get_width(src);
+	sh = gdk_pixbuf_get_height(src);
+
+	dw = gdk_pixbuf_get_width(dest);
+	dh = gdk_pixbuf_get_height(dest);
+
+	if (sx < 0 || sx + w > sw) return;
+	if (sy < 0 || sy + h > sh) return;
+
+	cx = clip_x;
+	cy = clip_y;
+
+	clip_x = MAX(clip_x, dx);
+	clip_y = MAX(clip_y, dy);
+
+	clip_w -= clip_x - cx;
+	clip_h -= clip_y - cy;
+
+	clip_x2 = MIN((clip_x + clip_w), (dx + w));
+	clip_y2 = MIN((clip_y + clip_h), (dy + h));
+
+	if (clip_x > dw || clip_y > dh || clip_x2 < 0 || clip_y2 < 0) return;
+	
+	if (clip_x < 0) clip_x = 0;
+	if (clip_y < 0) clip_y = 0;
+	if (clip_x2 >= dw) clip_x2 = dw -1;
+	if (clip_y2 >= dh) clip_y2 = dh -1;
+
+	cx = clip_x - cx;
+	cy = clip_y - cy;
+
+	sx += clip_x - dx;
+	sy += clip_y - dy;
+	dx = clip_x;
+	dy = clip_y;
+	w = clip_x2 - clip_x;
+	h = clip_y2 - clip_y;
+
+	if (sx < 0 || sx + w > sw) return;
+	if (sy < 0 || sy + h > sh) return;
+
+	s_alpha = gdk_pixbuf_get_has_alpha(src);
+	d_alpha = gdk_pixbuf_get_has_alpha(dest);
+	srs = gdk_pixbuf_get_rowstride(src);
+	drs = gdk_pixbuf_get_rowstride(dest);
+	s_pix = gdk_pixbuf_get_pixels(src);
+	d_pix = gdk_pixbuf_get_pixels(dest);
+
+	s_step = (s_alpha) ? 4 : 3;
+	d_step = (d_alpha) ? 4 : 3;
+
+	cp = 0;
+
+	for (i = 0; i < h; i++)
+		{
+		sp = s_pix + (sy + i) * srs + sx * s_step;
+		dp = d_pix + (dy + i) * drs + (dx * d_step);
+		if (clip_pix) cp = clip_pix + (cy + i) * clip_rs + cx * 4;
+		for (j = 0; j < w; j++)
+			{
+			if (!clip_pix || *(cp+3) )
+				{
+				r = *(sp++);
+				g = *(sp++);
+				b = *(sp++);
+				a = (s_alpha) ? ((*(sp++) * alpha_modifier) >> 8) : 255;
+				*dp = (r * a + *dp * (256-a)) >> 8;
+				dp++;
+				*dp = (g * a + *dp * (256-a)) >> 8;
+				dp++;
+				*dp = (b * a + *dp * (256-a)) >> 8;
+				dp++;
+				if (d_alpha) dp++;
+				}
+			else
+				{
+				sp += s_step;
+				dp += d_step;
+				}
+			cp += 4;
+			}
+		}
+}
+
 /*
  * Copies src to dest, filling area by tiling ot stretching if dest size > src size
  */
@@ -803,6 +926,196 @@ void pixbuf_copy_rotate_alpha_with_clipping(GdkPixbuf *src, gint offset_x, gint
 		}
 }
 
+/*
+ * These rotate in increments of 90 degrees, and are analogous to the non
+ * rotated pixbuf_copy_area{_alpha} utils.
+ */
+
+static void _pixbuf_copy_area_alpha_rotate_90(GdkPixbuf *src, gint sx, gint sy,
+					      GdkPixbuf *dest, gint dx, gint dy,
+					      gint w, gint h, gint apply_alpha,
+					      gint alpha_modifier, gint alpha_too, gint rotation)
+{
+	gint s_alpha, s_step;
+	gint d_alpha, d_step;
+	gint sw, sh, srs;
+	gint dw, dh, drs;
+	guchar *s_pix;
+	guchar *d_pix;
+	guchar *sp;
+	guchar *dp;
+	gint i, j;
+
+	if (!src || !dest) return;
+
+	sw = gdk_pixbuf_get_width(src);
+	sh = gdk_pixbuf_get_height(src);
+
+	if (sx < 0 || sx + w > sw) return;
+	if (sy < 0 || sy + h > sh) return;
+
+	dw = gdk_pixbuf_get_width(dest);
+	dh = gdk_pixbuf_get_height(dest);
+
+	if (rotation == 90 || rotation == 270)
+		{
+		if (dx < 0 || dx + h > dw) return;
+		if (dy < 0 || dy + w > dh) return;
+		}
+	else
+		{
+		if (dx < 0 || dx + w > dw) return;
+		if (dy < 0 || dy + h > dh) return;
+		}
+
+	s_alpha = gdk_pixbuf_get_has_alpha(src);
+	d_alpha = gdk_pixbuf_get_has_alpha(dest);
+	srs = gdk_pixbuf_get_rowstride(src);
+	drs = gdk_pixbuf_get_rowstride(dest);
+	s_pix = gdk_pixbuf_get_pixels(src);
+	d_pix = gdk_pixbuf_get_pixels(dest);
+
+	s_step = s_alpha ? 4 : 3;
+	d_step = d_alpha ? 4 : 3;
+
+	if (s_alpha && apply_alpha)
+		{
+		guchar a;
+		switch (rotation)
+			{
+			case 90:
+				for (i = 0; i < w; i++)
+					{
+					sp = s_pix + sy * srs + (sx + i) * s_step;
+					dp = d_pix + (dy + i) * drs + (dx + h - 1) * d_step;
+					for (j = 0; j < h; j++)
+						{
+						a = (*(sp+3) * alpha_modifier) >> 8;
+						*dp = (*sp * a + *dp * (256-a)) >> 8;
+						*(dp+1) = (*(sp+1) * a + *(dp+1) * (256-a)) >> 8;
+						*(dp+2) = (*(sp+2) * a + *(dp+2) * (256-a)) >> 8;
+						sp += srs;
+						dp -= d_step;
+						}
+					}
+				break;
+			case 180:
+				for (i = 0; i < h; i++)
+					{
+					sp = s_pix + (sy + i) * srs + sx * s_step;
+					dp = d_pix + (dy + h - i - 1) * drs + (dx + w - 1) * d_step;
+					for (j = 0; j < w; j++)
+						{
+						a = (*(sp+3) * alpha_modifier) >> 8;
+						*dp = (*sp * a + *dp * (256-a)) >> 8;
+						*(dp+1) = (*(sp+1) * a + *(dp+1) * (256-a)) >> 8;
+						*(dp+2) = (*(sp+2) * a + *(dp+2) * (256-a)) >> 8;
+						sp += s_step;
+						dp -= d_step;
+						}
+					}
+				break;
+			case 270:
+				for (i = 0; i < w; i++)
+					{
+					sp = s_pix + sy * srs + (sx + i) * s_step;
+					dp = d_pix + (dy + w - i - 1) * drs + dx * d_step;
+					for (j = 0; j < h; j++)
+						{
+						a = (*(sp+3) * alpha_modifier) >> 8;
+						*dp = (*sp * a + *dp * (256-a)) >> 8;
+						*(dp+1) = (*(sp+1) * a + *(dp+1) * (256-a)) >> 8;
+						*(dp+2) = (*(sp+2) * a + *(dp+2) * (256-a)) >> 8;
+						sp += srs;
+						dp += d_step;
+						}
+					}
+				break;
+			}
+		}
+	else
+		{
+		alpha_too = (alpha_too && s_alpha && d_alpha);
+
+		switch (rotation)
+			{
+			case 90:
+				for (i = 0; i < w; i++)
+					{
+					sp = s_pix + sy * srs + (sx + i) * s_step;
+					dp = d_pix + (dy + i) * drs + (dx + h - 1) * d_step;
+					for (j = 0; j < h; j++)
+						{
+						*(dp) = *(sp);		/* r */
+						*(dp+1) = *(sp+1);	/* g */
+						*(dp+2) = *(sp+2);	/* b */
+						if (alpha_too)		/* a ? */
+							{
+							*(dp+3) = *(sp+3);
+							}
+						sp += srs;
+						dp -= d_step;
+						}
+					}
+				break;
+			case 180:
+				for (i = 0; i < h; i++)
+					{
+					sp = s_pix + (sy + i) * srs + sx * s_step;
+					dp = d_pix + (dy + h - i - 1) * drs + (dx + w - 1) * d_step;
+					for (j = 0; j < w; j++)
+						{
+						*(dp) = *(sp);		/* r */
+						*(dp+1) = *(sp+1);	/* g */
+						*(dp+2) = *(sp+2);	/* b */
+						if (alpha_too)		/* a ? */
+							{
+							*(dp+3) = *(sp+3);
+							}
+						sp += s_step;
+						dp -= d_step;
+						}
+					}
+				break;
+			case 270:
+				for (i = 0; i < w; i++)
+					{
+					sp = s_pix + sy * srs + (sx + i) * s_step;
+					dp = d_pix + (dy + w - i - 1) * drs + dx * d_step;
+					for (j = 0; j < h; j++)
+						{
+						*(dp) = *(sp);		/* r */
+						*(dp+1) = *(sp+1);	/* g */
+						*(dp+2) = *(sp+2);	/* b */
+						if (alpha_too)		/* a ? */
+							{
+							*(dp+3) = *(sp+3);
+							}
+						sp += srs;
+						dp += d_step;
+						}
+					}
+				break;
+			}
+		}
+}
+
+void pixbuf_copy_area_rotate_90(GdkPixbuf *src, gint sx, gint sy,
+				GdkPixbuf *dest, gint dx, gint dy,
+				gint w, gint h, gint alpha_too, gint rotation)
+{
+	_pixbuf_copy_area_alpha_rotate_90(src, sx, sy, dest, dx, dy,
+					  w, h, FALSE, 0, alpha_too, rotation);
+}
+
+void pixbuf_copy_area_rotate_90_alpha(GdkPixbuf *src, gint sx, gint sy,
+				      GdkPixbuf *dest, gint dx, gint dy,
+				      gint w, gint h, gint alpha_modifier, gint rotation)
+{
+	_pixbuf_copy_area_alpha_rotate_90(src, sx, sy, dest, dx, dy,
+					  w, h, TRUE, alpha_modifier, FALSE, rotation);
+}
+
 
 /*
  * Fills region of pixbuf at x,y over w,h
@@ -1051,6 +1364,3 @@ void pixbuf_copy_line(GdkPixbuf *src, gint sx1, gint sy1, gint sx2, gint sy2,
 		j += xstep;
 		}
 }
-
-
-
