@@ -1,6 +1,6 @@
 /*
  * (SLIK) SimpLIstic sKin functions
- * (C) 2002 John Ellis
+ * (C) 2004 John Ellis
  *
  * Author: John Ellis
  *
@@ -27,15 +27,18 @@
 
 #include "ui_tabcomp.h"
 
+#include "ui_bookmark.h"
 #include "ui_fileops.h"
+#include "ui_spinner.h"
 
 #include <gdk/gdkkeysyms.h> /* for key values */
 
-#include "ui_tabcomp.xpm"
 
 /* define this to enable a pop-up menu that shows possible matches
  * #define TAB_COMPLETION_ENABLE_POPUP_MENU
  */
+#define TAB_COMPLETION_ENABLE_POPUP_MENU 1
+#define TAB_COMP_POPUP_MAX 500
 
 #ifdef TAB_COMPLETION_ENABLE_POPUP_MENU
 #include "ui_menu.h"
@@ -65,254 +68,6 @@ struct _TabCompData
 	gint history_levels;
 };
 
-typedef struct _HistoryData HistoryData;
-struct _HistoryData
-{
-	gchar *key;
-	GList *list;
-};
-
-static GList *history_list = NULL;
-
-
-static gchar *quoted_from_text(const gchar *text)
-{
-	const gchar *ptr;
-	gint c = 0;
-	gint l = strlen(text);
-
-	if (l == 0) return NULL;
-
-	while (c < l && text[c] !='"') c++;
-	if (text[c] == '"')
-		{
-		gint e;
-		c++;
-		ptr = text + c;
-		e = c;
-		while (e < l && text[e] !='"') e++;
-		if (text[e] == '"')
-			{
-			if (e - c > 0)
-				{
-				return g_strndup(ptr, e - c);
-				}
-			}
-		}
-	return NULL;
-}
-
-/*
- *-----------------------------------------------------------------------------
- * history lists
- *-----------------------------------------------------------------------------
- */
-
-gint history_list_load(const gchar *path)
-{
-	FILE *f;
-	gchar *key = NULL;
-	gchar s_buf[1024];
-
-	f = fopen(path, "r");
-	if (!f) return FALSE;
-
-	/* first line must start with History comment */
-	if (!fgets(s_buf,1024,f) ||
-	    strncmp(s_buf, "#History", 8) != 0)
-		{
-		fclose(f);
-		return FALSE;
-		}
-
-	while (fgets(s_buf,1024,f))
-		{
-		if (s_buf[0]=='#') continue;
-		if (s_buf[0]=='[')
-			{
-			gint c;
-			gchar *ptr;
-
-			ptr = s_buf + 1;
-			c = 0;
-			while(ptr[c] != ']' && ptr[c] != '\n' && ptr[c] != '\0') c++;
-
-			g_free(key);
-			key = g_strndup(ptr, c);
-			}
-		else
-			{
-			gchar *value;
-
-			value = quoted_from_text(s_buf);
-			if (value && key)
-				{
-				history_list_add_to_key(key, value, 0);
-				}
-			g_free(value);
-			}
-		}
-
-	fclose(f);
-
-	g_free(key);
-
-	return TRUE;
-}
-
-gint history_list_save(const gchar *path)
-{
-	FILE *f;
-	GList *list;
-
-	f = fopen(path, "w");
-	if (!f)
-		{
-		printf(_("Unable to write history lists to: %s\n"), path);
-		return FALSE;
-		}
-
-	fprintf(f, "#History lists\n");
-	fprintf(f, "\n");
-
-	list = g_list_last(history_list);
-	while(list)
-		{
-		HistoryData *hd;
-		GList *work;
-
-		hd = list->data;
-		list = list->prev;
-
-		fprintf(f, "[%s]\n", hd->key);
-
-		/* save them inverted (oldest to newest)
-		 * so that when reading they are added correctly
-		 */
-		work = g_list_last(hd->list);
-		while(work)
-			{
-			fprintf(f, "\"%s\"\n", (gchar *)work->data);
-			work = work->prev;
-			}
-		fprintf(f, "\n");
-		}
-
-	fprintf(f, "#end\n");
-
-	fclose(f);
-
-	return TRUE;
-}
-
-static void history_list_free(HistoryData *hd)
-{
-	GList *work;
-
-	if (!hd) return;
-
-	work = hd->list;
-	while(work)
-		{
-		g_free(work->data);
-		work = work->next;
-		}
-
-	g_free(hd->key);
-	g_free(hd);
-}
-
-static HistoryData *history_list_find_by_key(const gchar* key)
-{
-	GList *work = history_list;
-	while(work)
-		{
-		HistoryData *hd = work->data;
-		if (strcmp(hd->key, key) == 0) return hd;
-		work = work->next;
-		}
-	return NULL;
-}
-
-static const gchar *history_list_find_last_path_by_key(const gchar* key)
-{
-	HistoryData *hd;
-	hd = history_list_find_by_key(key);
-	if (!hd || !hd->list) return NULL;
-
-	return hd->list->data;
-}
-
-void history_list_free_key(const gchar *key)
-{
-	HistoryData *hd;
-	hd = history_list_find_by_key(key);
-	if (!hd) return;
-
-	history_list = g_list_remove(history_list, hd);
-	history_list_free(hd);
-}
-
-void history_list_add_to_key(const gchar *key, const gchar *path, gint max)
-{
-	HistoryData *hd;
-	GList *work;
-
-	if (!key || !path) return;
-
-	hd = history_list_find_by_key(key);
-	if (!hd)
-		{
-		hd = g_new(HistoryData, 1);
-		hd->key = g_strdup(key);
-		hd->list = NULL;
-		history_list = g_list_prepend(history_list, hd);
-		}
-
-	/* if already in the list, simply move it to the top */
-	work = hd->list;
-	while(work)
-		{
-		gchar *buf = work->data;
-		work = work->next;
-		if (strcmp(buf, path) == 0)
-			{
-			hd->list = g_list_remove(hd->list, buf);
-			hd->list = g_list_prepend(hd->list, buf);
-			return;
-			}
-		}
-
-	hd->list = g_list_prepend(hd->list, g_strdup(path));
-
-	if (max > 0)
-		{
-		while(hd->list && g_list_length(hd->list) > max)
-			{
-			GList *work = g_list_last(hd->list);
-			gchar *buf = work->data;
-			hd->list = g_list_remove(hd->list, buf);
-			g_free(buf);
-			}
-		}
-}
-
-GList *history_list_get_by_key(const gchar *key)
-{
-	HistoryData *hd;
-
-	hd = history_list_find_by_key(key);
-	if (!hd) return NULL;
-
-	return hd->list;
-}
-
-/*
- *-----------------------------------------------------------------------------
- * tab completion entry
- *-----------------------------------------------------------------------------
- */
-
 static void tab_completion_free_list(TabCompData *td)
 {
 	GList *list;
@@ -337,10 +92,14 @@ static void tab_completion_read_dir(TabCompData *td, const gchar *path)
         DIR *dp;
         struct dirent *dir;
         GList *list = NULL;
+	gchar *pathl;
 
 	tab_completion_free_list(td);
 
-        if((dp = opendir(path))==NULL)
+	pathl = path_from_utf8(path);
+        dp = opendir(pathl);
+	g_free(pathl);
+	if (!dp)
                 {
                 /* dir not found */
                 return;
@@ -353,7 +112,7 @@ static void tab_completion_read_dir(TabCompData *td, const gchar *path)
 			gchar *name = dir->d_name;
 			if (strcmp(name, ".") != 0 && strcmp(name, "..") != 0)
 				{
-				list = g_list_prepend(list, g_strdup(name));
+				list = g_list_prepend(list, path_to_utf8(name));
 				}
                         }
 		}
@@ -371,10 +130,10 @@ static void tab_completion_destroy(GtkWidget *widget, gpointer data)
 	g_free(td);
 }
 
-static void tab_completion_emit_enter_signal(TabCompData *td)
+static gint tab_completion_emit_enter_signal(TabCompData *td)
 {
 	gchar *text;
-	if (!td->enter_func) return;
+	if (!td->enter_func) return FALSE;
 
 	text = g_strdup(gtk_entry_get_text(GTK_ENTRY(td->entry)));
 
@@ -387,6 +146,8 @@ static void tab_completion_emit_enter_signal(TabCompData *td)
 
 	td->enter_func(text, td->enter_data);
 	g_free(text);
+
+	return TRUE;
 }
 
 static void tab_completion_emit_tab_signal(TabCompData *td)
@@ -420,9 +181,12 @@ static gint tab_completion_popup_key_press(GtkWidget *widget, GdkEventKey *event
 		if (event->keyval >= 0x20 && event->keyval <= 0xFF)
 			{
 			gchar buf[2];
+			gint p = -1;
+
 			buf[0] = event->keyval;
 			buf[1] = '\0';
-			gtk_entry_append_text(GTK_ENTRY(td->entry), buf);
+			gtk_editable_insert_text(GTK_EDITABLE(td->entry), buf, 1, &p);
+			gtk_editable_set_position(GTK_EDITABLE(td->entry), -1);
 			}
 
 		/*close the menu */
@@ -443,38 +207,39 @@ static void tab_completion_popup_cb(GtkWidget *widget, gpointer data)
 	gchar *buf;
 	gchar *ptr;
 
-	td = gtk_object_get_data(GTK_OBJECT(widget), "tab_completion_data");
+	td = g_object_get_data(G_OBJECT(widget), "tab_completion_data");
 	if (!td) return;
 
 	ptr = td->dir_path + strlen(td->dir_path) - 1;
 	buf = g_strconcat(td->dir_path, (ptr[0] == '/') ? "" : "/", name, NULL);
 	gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
-	gtk_entry_set_position(GTK_ENTRY(td->entry), strlen(buf));
+	gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(buf));
 	g_free(buf);
 
 	tab_completion_emit_tab_signal(td);
 }
 
-/*
- * MAGIC_OFFSET: No simple way to determine frame size of menu.
- * MAX: Limit popup menu items to a sane number, will be fixed when a list is used instead.
- */
-
-#define TAB_COMP_POPUP_MAGIC_OFFSET 3
-#define TAB_COMP_POPUP_MAX 64
-
-static void tab_completion_popup_pos_cb(GtkMenu *menu, gint *x, gint *y, gpointer data)
+static void tab_completion_popup_pos_cb(GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer data)
 {
 	TabCompData *td = data;
 	gint height;
+	PangoLayout *layout;
+	PangoRectangle strong_pos, weak_pos;
+	gint length;
+	gint xoffset, yoffset;
+							
 
 	gdk_window_get_origin(td->entry->window, x, y);
 
 	height = MIN(td->entry->requisition.height, td->entry->allocation.height);
 	*y += height;
 
-	*x += GTK_ENTRY(td->entry)->char_offset[GTK_EDITABLE(td->entry)->current_pos];
-	*x -= GTK_ENTRY(td->entry)->scroll_offset + TAB_COMP_POPUP_MAGIC_OFFSET;
+	length = strlen(gtk_entry_get_text(GTK_ENTRY(td->entry)));
+	gtk_entry_get_layout_offsets(GTK_ENTRY(td->entry), &xoffset, &yoffset);
+
+	layout = gtk_entry_get_layout(GTK_ENTRY(td->entry));
+	pango_layout_get_cursor_pos(layout, length, &strong_pos, &weak_pos);
+	*x += strong_pos.x / PANGO_SCALE + xoffset;
 }
 
 static void tab_completion_popup_list(TabCompData *td, GList *list)
@@ -488,12 +253,14 @@ static void tab_completion_popup_list(TabCompData *td, GList *list)
 
 	if (!list) return;
 
+#if 0
 	/*
 	 * well, the menu would be too long anyway...
 	 * (listing /dev causes gtk+ window allocation errors, -> too big a window)
-	 * this is why menu popups are disabled, this really should be a popup scrollable clist.
+	 * this is why menu popups are disabled, this really should be a popup scrollable listview.
 	 */
 	if (g_list_length(list) > 200) return;
+#endif
 
 	menu = popup_menu_short_lived();
 
@@ -503,15 +270,15 @@ static void tab_completion_popup_list(TabCompData *td, GList *list)
 		gchar *name = work->data;
 		GtkWidget *item;
 
-		item = menu_item_add(menu, name, GTK_SIGNAL_FUNC(tab_completion_popup_cb), name);
-		gtk_object_set_data(GTK_OBJECT(item), "tab_completion_data", td);
+		item = menu_item_add_simple(menu, name, G_CALLBACK(tab_completion_popup_cb), name);
+		g_object_set_data(G_OBJECT(item), "tab_completion_data", td);
 
 		work = work->next;
 		count++;
 		}
 
-	gtk_signal_connect(GTK_OBJECT(menu), "key_press_event",
-			   GTK_SIGNAL_FUNC(tab_completion_popup_key_press), td);
+	g_signal_connect(G_OBJECT(menu), "key_press_event",
+			 G_CALLBACK(tab_completion_popup_key_press), td);
 
 	/* peek at the current event to get the time, etc. */
 	event = gtk_get_current_event();
@@ -519,28 +286,33 @@ static void tab_completion_popup_list(TabCompData *td, GList *list)
 	if (event && event->type == GDK_BUTTON_RELEASE)
 		{
 		ebutton = event->button.button;
-		etime = event->button.time;
-		}
-	else if (event && event->type == GDK_KEY_PRESS)
-		{
-		ebutton = 0;
-		etime = event->key.time;
 		}
 	else
 		{
 		ebutton = 0;
-		etime = gdk_time_get();
 		}
 
-	if (event) gdk_event_free(event);
+	if (event)
+		{
+		etime = gdk_event_get_time(event);
+		gdk_event_free(event);
+		}
+	else
+		{
+		etime = 0;
+		}
 
 	gtk_menu_popup(GTK_MENU(menu), NULL, NULL,
 		       tab_completion_popup_pos_cb, td, ebutton, etime);
 }
 
+#ifndef CASE_SORT
+#define CASE_SORT strcmp
+#endif
+
 static gint simple_sort(gconstpointer a, gconstpointer b)
 {
-        return strcmp((gchar *)a, (gchar *)b);
+        return CASE_SORT((gchar *)a, (gchar *)b);
 }
 
 #endif
@@ -571,7 +343,7 @@ static gint tab_completion_do(TabCompData *td)
 		if (home_exp)
 			{
 			gtk_entry_set_text(GTK_ENTRY(td->entry), entry_dir);
-			gtk_entry_set_position(GTK_ENTRY(td->entry), strlen(entry_dir));
+			gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(entry_dir));
 			}
 		g_free(entry_dir);
 		return home_exp;
@@ -584,15 +356,34 @@ static gint tab_completion_do(TabCompData *td)
 			if (home_exp)
 				{
 				gtk_entry_set_text(GTK_ENTRY(td->entry), entry_dir);
-				gtk_entry_set_position(GTK_ENTRY(td->entry), strlen(entry_dir));
+				gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(entry_dir));
+				}
+
+			tab_completion_read_dir(td, entry_dir);
+			td->file_list = g_list_sort(td->file_list, simple_sort);
+			if (td->file_list && !td->file_list->next)
+				{
+				gchar *buf;
+				const gchar *file;
+
+				file = td->file_list->data;
+				buf = g_strconcat(entry_dir, file, NULL);
+				if (isdir(buf))
+					{
+					g_free(buf);
+					buf = g_strconcat(entry_dir, file, "/", NULL);
+					}
+				gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
+				gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(buf));
+				g_free(buf);
 				}
 
 #ifdef TAB_COMPLETION_ENABLE_POPUP_MENU
 
-			tab_completion_read_dir(td, entry_dir);
-			td->file_list = g_list_sort(td->file_list, simple_sort);
-			tab_completion_popup_list(td, td->file_list);
-
+			else
+				{
+				tab_completion_popup_list(td, td->file_list);
+				}
 #endif
 
 			g_free(entry_dir);
@@ -602,7 +393,7 @@ static gint tab_completion_do(TabCompData *td)
 			{
 			gchar *buf = g_strconcat(entry_dir, "/", NULL);
 			gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
-			gtk_entry_set_position(GTK_ENTRY(td->entry), strlen(buf));
+			gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(buf));
 			g_free(buf);
 			g_free(entry_dir);
 			return TRUE;
@@ -658,7 +449,7 @@ static gint tab_completion_do(TabCompData *td)
 					buf = g_strconcat(entry_dir, "/", file, "/", NULL);
 					}
 				gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
-				gtk_entry_set_position(GTK_ENTRY(td->entry), strlen(buf));
+				gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(buf));
 				g_free(buf);
 				g_list_free(poss);
 				g_free(entry_dir);
@@ -694,7 +485,7 @@ static gint tab_completion_do(TabCompData *td)
 					file[c] = '\0';
 					buf = g_strconcat(entry_dir, "/", file, NULL);
 					gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
-					gtk_entry_set_position(GTK_ENTRY(td->entry), strlen(buf));
+					gtk_editable_set_position(GTK_EDITABLE(td->entry), strlen(buf));
 
 #ifdef TAB_COMPLETION_ENABLE_POPUP_MENU
 
@@ -727,27 +518,28 @@ static gint tab_completion_key_pressed(GtkWidget *widget, GdkEventKey *event, gp
 	switch (event->keyval)
 		{
                 case GDK_Tab:
-			if (tab_completion_do(td))
+			if (!(event->state & GDK_CONTROL_MASK))
 				{
-				tab_completion_emit_tab_signal(td);
+				if (tab_completion_do(td))
+					{
+					tab_completion_emit_tab_signal(td);
+					}
+				stop_signal = TRUE;
 				}
-			stop_signal = TRUE;
 			break;
 		case GDK_Return: case GDK_KP_Enter:
-			tab_completion_emit_enter_signal(td);
-			stop_signal = TRUE;
+			if (tab_completion_emit_enter_signal(td))
+				{
+				stop_signal = TRUE;
+				}
 			break;
 		default:
 			break;
 		}
 
-	if (stop_signal)
-		{
-		if (stop_signal) gtk_signal_emit_stop_by_name(GTK_OBJECT(widget), "key_press_event");
-		return TRUE;
-		}
+	if (stop_signal) g_signal_stop_emission_by_name(G_OBJECT(widget), "key_press_event");
 
-	return FALSE;
+	return (stop_signal);
 }
 
 static void tab_completion_button_pressed(GtkWidget *widget, gpointer data)
@@ -755,7 +547,7 @@ static void tab_completion_button_pressed(GtkWidget *widget, gpointer data)
 	TabCompData *td;
 	GtkWidget *entry = data;
 
-	td = gtk_object_get_data(GTK_OBJECT(entry), "tab_completion_data");
+	td = g_object_get_data(G_OBJECT(entry), "tab_completion_data");
 
 	if (!td) return;
 
@@ -770,30 +562,41 @@ static void tab_completion_button_pressed(GtkWidget *widget, gpointer data)
 		}
 }
 
+static void tab_completion_button_size_allocate(GtkWidget *button, GtkAllocation *allocation, gpointer data)
+{
+	GtkWidget *entry = data;
+
+	if (allocation->height > entry->requisition.height)
+		{
+		GtkAllocation button_allocation;
+
+		button_allocation = button->allocation;
+		button_allocation.height = entry->requisition.height;
+		button_allocation.y = entry->allocation.y +
+			(entry->allocation.height - entry->requisition.height) / 2;
+		gtk_widget_size_allocate(button, &button_allocation);
+		}
+}
+
 static GtkWidget *tab_completion_create_complete_button(GtkWidget *entry)
 {
 	GtkWidget *button;
 	GtkWidget *icon;
-	GdkPixmap *pixmap = NULL;
-	GdkBitmap *mask = NULL;
 	GdkPixbuf *pixbuf;
 
-	pixbuf = gdk_pixbuf_new_from_xpm_data((const char **)ui_tabcomp_xpm);
-	gdk_pixbuf_render_pixmap_and_mask(pixbuf, &pixmap, &mask, 128);
-	gdk_pixbuf_unref(pixbuf);
-
 	button = gtk_button_new();
 	GTK_WIDGET_UNSET_FLAGS(button, GTK_CAN_FOCUS);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			   GTK_SIGNAL_FUNC(tab_completion_button_pressed), entry);
-	
-	icon = gtk_pixmap_new(pixmap, mask);
+	g_signal_connect(G_OBJECT(button), "size_allocate",
+			 G_CALLBACK(tab_completion_button_size_allocate), entry);
+	g_signal_connect(G_OBJECT(button), "clicked",
+			 G_CALLBACK(tab_completion_button_pressed), entry);
+
+	pixbuf = gdk_pixbuf_new_from_inline(-1, icon_tabcomp, FALSE, NULL);
+	icon = gtk_image_new_from_pixbuf(pixbuf);
+	gdk_pixbuf_unref(pixbuf);
 	gtk_container_add(GTK_CONTAINER(button), icon);
 	gtk_widget_show(icon);
 
-	gdk_pixmap_unref(pixmap);
-	if (mask) gdk_bitmap_unref(mask);
-
 	return button;
 }
 
@@ -809,10 +612,11 @@ GtkWidget *tab_completion_new_with_history(GtkWidget **entry, const gchar *text,
 {
 	GtkWidget *combo;
 	GtkWidget *button;
-	HistoryData *hd;
+	GList *list;
 	TabCompData *td;
 
 	combo = gtk_combo_new();
+	gtk_combo_set_case_sensitive(GTK_COMBO(combo), TRUE);
 	gtk_combo_set_use_arrows(GTK_COMBO(combo), FALSE);
 
 	button = tab_completion_create_complete_button(GTK_COMBO(combo)->entry);
@@ -822,7 +626,7 @@ GtkWidget *tab_completion_new_with_history(GtkWidget **entry, const gchar *text,
 	
 	tab_completion_add_to_entry(GTK_COMBO(combo)->entry, enter_func, data);
 
-	td = gtk_object_get_data(GTK_OBJECT(GTK_COMBO(combo)->entry), "tab_completion_data");
+	td = g_object_get_data(G_OBJECT(GTK_COMBO(combo)->entry), "tab_completion_data");
 	if (!td) return NULL; /* this should never happen! */
 
 	td->combo = combo;
@@ -830,10 +634,10 @@ GtkWidget *tab_completion_new_with_history(GtkWidget **entry, const gchar *text,
 	td->history_key = g_strdup(history_key);
 	td->history_levels = max_levels;
 
-	hd = history_list_find_by_key(td->history_key);
-	if (hd && hd->list)
+	list = history_list_get_by_key(td->history_key);
+	if (list)
 		{
-		gtk_combo_set_popdown_strings(GTK_COMBO(combo), hd->list);
+		gtk_combo_set_popdown_strings(GTK_COMBO(combo), list);
 		}
 
 	if (text) gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(combo)->entry), text);
@@ -844,7 +648,7 @@ GtkWidget *tab_completion_new_with_history(GtkWidget **entry, const gchar *text,
 
 const gchar *tab_completion_set_to_last_history(GtkWidget *entry)
 {
-	TabCompData *td = gtk_object_get_data(GTK_OBJECT(entry), "tab_completion_data");
+	TabCompData *td = g_object_get_data(G_OBJECT(entry), "tab_completion_data");
 	const gchar *buf;
 
 	if (!td || !td->has_history) return NULL;
@@ -860,21 +664,21 @@ const gchar *tab_completion_set_to_last_history(GtkWidget *entry)
 
 void tab_completion_append_to_history(GtkWidget *entry, const gchar *path)
 {
-	TabCompData *td = gtk_object_get_data(GTK_OBJECT(entry), "tab_completion_data");
-	HistoryData *hd;
+	TabCompData *td = g_object_get_data(G_OBJECT(entry), "tab_completion_data");
+	GList *list;
 
 	if (!path) return;
 
 	if (!td || !td->has_history) return;
 
 	history_list_add_to_key(td->history_key, path, td->history_levels);
-	hd = history_list_find_by_key(td->history_key);
-	if (hd && hd->list)
+	list = history_list_get_by_key(td->history_key);
+	if (list)
 		{
 		gchar *buf;
 
 		buf = g_strdup(gtk_entry_get_text(GTK_ENTRY(td->entry)));
-		gtk_combo_set_popdown_strings(GTK_COMBO(td->combo), hd->list);
+		gtk_combo_set_popdown_strings(GTK_COMBO(td->combo), list);
 		if (strcmp(buf, gtk_entry_get_text(GTK_ENTRY(td->entry))) != 0)
 			{
 			gtk_entry_set_text(GTK_ENTRY(td->entry), buf);
@@ -929,17 +733,17 @@ void tab_completion_add_to_entry(GtkWidget *entry, void (*enter_func)(const gcha
 	td->history_key = NULL;
 	td->history_levels = 0;
 
-	gtk_object_set_data(GTK_OBJECT(td->entry), "tab_completion_data", td);
+	g_object_set_data(G_OBJECT(td->entry), "tab_completion_data", td);
 
-	gtk_signal_connect(GTK_OBJECT(entry), "key_press_event",
-			   GTK_SIGNAL_FUNC(tab_completion_key_pressed), td);
-	gtk_signal_connect(GTK_OBJECT(entry), "destroy",
-			   GTK_SIGNAL_FUNC(tab_completion_destroy), td);
+	g_signal_connect(G_OBJECT(entry), "key_press_event",
+			 G_CALLBACK(tab_completion_key_pressed), td);
+	g_signal_connect(G_OBJECT(entry), "destroy",
+			 G_CALLBACK(tab_completion_destroy), td);
 }
 
 void tab_completion_add_tab_func(GtkWidget *entry, void (*tab_func)(const gchar *, gpointer), gpointer data)
 {
-	TabCompData *td = gtk_object_get_data(GTK_OBJECT(entry), "tab_completion_data");
+	TabCompData *td = g_object_get_data(G_OBJECT(entry), "tab_completion_data");
 
 	if (!td) return;
 
